@@ -1,4 +1,4 @@
-static char const rcsid[] = "@(#) $Id: htmlwidget.c,v 1.1.1.1 2002/06/20 21:19:34 joye Exp $";
+static char const rcsid[] = "@(#) $Id: htmlwidget.c,v 1.4 2005/11/09 00:06:09 joye Exp $";
 /*
 ** The main routine for the HTML widget for Tcl/Tk
 **
@@ -1427,6 +1427,13 @@ int HtmlGetColorByName(HtmlWidget *htmlPtr, char *zColor){
   ** compatibility.
   */
   n = strlen(zColor);
+
+  /* trucate any spaces on the end */
+  while (n>0 && zColor[n-1]==' ') {
+    zColor[n-1] = '\0';
+    n--;
+  }
+
   if( n==6 || n==3 || n==9 || n==12 ){
     for(i=0; i<n; i++){
       if( !isxdigit(zColor[i]) ) break;
@@ -1545,21 +1552,35 @@ LOCAL int GetColorByValue(HtmlWidget *htmlPtr, XColor *pRef){
   float dist;
   float closestDist;
   int closest;
+  /*
   int r, g, b;
 # define COLOR_MASK  0xf800
+  */
+
+  XColor* q;
+  q = Tk_GetColorByValue(htmlPtr->clipwin, pRef);
 
   /* Search for an exact match */
+  /*
   r = pRef->red &= COLOR_MASK;
   g = pRef->green &= COLOR_MASK;
   b = pRef->blue &= COLOR_MASK;
+  */
   for(i=0; i<N_COLOR; i++){
     XColor *p = htmlPtr->apColor[i];
+    /*
     if( p && (p->red & COLOR_MASK)==r && (p->green & COLOR_MASK)==g 
     && (p->blue & COLOR_MASK)==b ){
+    */
+    if (p && (q->red == p->red) 
+	&& (q->green == p->green) 
+	&& (q->blue == p->blue)) {
       htmlPtr->colorUsed |= (1<<i);
+      Tk_FreeColor(q);
       return i;
     }
   }
+  Tk_FreeColor(q);
 
   /* No exact matches.  Look for a completely unused slot */
   for(i=N_PREDEFINED_COLOR; i<N_COLOR; i++){
@@ -1722,7 +1743,7 @@ static struct HtmlSubcommand {
   { "resolve",   0,         2, 0, "?URI ...?",           HtmlResolveCmd },
   { "selection", "clear",   3, 3, 0,                     HtmlSelectionClearCmd},
   { 0,           "set",     5, 5, "START END",           HtmlSelectionSetCmd },
-  { "text",      "ascii",   5, 5, "START END",           0 },
+  { "text",      "ascii",   5, 5, "START END",           HtmlTextAsciiCmd},
   { 0,           "delete",  5, 5, "START END",           0 },
   { 0,           "html",    5, 5, "START END",           0 },
   { 0,           "insert",  5, 5, "INDEX TEXT",          0 },
