@@ -1,5 +1,6 @@
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <sys/errno.h>
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -291,6 +292,9 @@ register XimDataPtr xim;
 	if (listen (s, MAXCONN) < 0)
 	    goto err;
 
+	/* make sure we close on exec */
+	fcntl(s, F_SETFD, FD_CLOEXEC);
+
 	/* Allocate and fill in i/o channel descriptor. */
 	if (chan = get_iochan(xim)) {
 	    chan->xim = (XtPointer) xim;
@@ -306,15 +310,15 @@ register XimDataPtr xim;
 	    return (chan);
 	}
 err:
+	/*
 	if (errno == EADDRINUSE) {
-	    fprintf (stderr,"ximtool: inet port %d already in use - disabled\n",
+	  fprintf (stderr,"ximtool: inet port %d already in use - disabled\n",
 	        xim->port);
 	} else {
-	  /*
 	    fprintf (stderr, "ximtool: can't open inet socket %d, errno=%d\n",
 	        xim->port, errno);
-	  */
 	}
+	*/
 	xim->port = 0;
 	if (s)
 	    close (s);
@@ -359,6 +363,9 @@ register XimDataPtr xim;
 	if (listen (s, MAXCONN) < 0)
 	    goto err;
 
+	/* make sure we close on exec */
+	fcntl(s, F_SETFD, FD_CLOEXEC);
+
 	/* Allocate and fill in i/o channel descriptor. */
 	if (chan = get_iochan(xim)) {
 	    chan->xim = (XtPointer) xim;
@@ -375,15 +382,15 @@ register XimDataPtr xim;
 	    return (chan);
 	}
 err:
+	/*
 	if (errno == EADDRINUSE) {
 	    fprintf (stderr,"ximtool: unix addr %s already in use - disabled\n",
 	        path);
 	} else {
-	  /*
 	    fprintf (stderr,"ximtool: cannot open unix socket '%s', errno=%d\n",
 	        path, errno);
-	  */
 	}
+	*/
 	strcpy (xim->unixaddr, "none");
 	if (s)
 	    close (s);
@@ -1135,11 +1142,10 @@ void xim_retCursorVal(XimDataPtr xim, float sx, float sy, int frame, int wcs, in
  * pixel value and return a string giving X, Y, and the pixel intensity in
  * world units.
  */
-xim_encodewcs (xim, sx, sy, sz, obuf)
-register XimDataPtr xim;
-float sx, sy;			/* screen (raster) pixel coordinates */
-int sz;				/* screen pixel value */
-char *obuf;			/* receives encoded string */
+void xim_encodewcs (register XimDataPtr xim, float sx, float sy, int sz, char* obuf)
+//float sx, sy;			/* screen (raster) pixel coordinates */
+//int sz;				/* screen pixel value */
+//char *obuf;			/* receives encoded string */
 {
 	register CtranPtr ct;
 	MappingPtr  mp = (MappingPtr) NULL;
