@@ -1,48 +1,59 @@
-// Copyright (C) 1999-2004
+// Copyright (C) 1999-2012
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
 #ifndef __colormap_h__
 #define __colormap_h__
 
-#if __GNUC__ >= 3
+#include <string.h>
+#include <stdlib.h>
+#include <limits.h>
+
 #include <iostream>
 #include <fstream>
 #include <sstream>
+#include <iomanip>
 using namespace std;
-#else
-#include <iostream.h>
-#include <fstream.h>
-#include <strstream.h>
-#endif
 
-#include "itt.h"
+class Colorbar;
 
 // ColorMapInfo
 
 class ColorMapInfo {
 protected:
+  Colorbar* parent_;
+
   int id;
   char* name;
   char* fileName;
-  ColorMapInfo* next;
+  ColorMapInfo* next_;
+  ColorMapInfo* previous_;
 
 public:
-  ColorMapInfo();
+  ColorMapInfo(Colorbar* p);
   virtual ~ColorMapInfo();
 
+  Colorbar* parent() {return parent_;}
+
   const char* getName() {return name;}
   int getID() {return id;}
   void setName(const char*);
   const char* getFileName() {return fileName;}
   void setFileName(const char*);
   
-  ColorMapInfo* getNext() {return next;}
-  void setNext(ColorMapInfo* c) {next = c;}
+  ColorMapInfo* next() 
+  {return next_;}
+  ColorMapInfo* previous()
+  {return previous_;}
+  void setNext(ColorMapInfo* n) 
+  {next_ = n;}
+  void setPrevious(ColorMapInfo* p)
+  {previous_=p;}
 
+  virtual ColorMapInfo* dup() =0;
   virtual int load() =0;
-  virtual int save(const char*) =0;
-  virtual void setITT(ITT* t) {} // most colormaps do not use ITTs
+  virtual int load(const char*) =0;
+  virtual void save(const char*) =0;
 
   virtual unsigned char getRedChar(int, int) =0;
   virtual unsigned char getGreenChar(int, int) =0;
