@@ -30,6 +30,12 @@ public:
     : FitsAlloc(fn), FitsArrStream<FILE*>(flush) {}
 };
 
+class FitsNRRDAlloc : public FitsAlloc, FitsNRRDStream<FILE*> {
+public:
+  FitsNRRDAlloc(const char* fn, FlushMode flush) 
+    : FitsAlloc(fn), FitsNRRDStream<FILE*>(flush) {}
+};
+
 class FitsMosaicAlloc : public FitsAlloc, FitsMosaicStream<FILE*> {
 public:
   FitsMosaicAlloc(const char* fn, FlushMode flush) : 
