@@ -32,6 +32,13 @@ public:
     : FitsChannel(interp, ch, ext), FitsArrStream<Tcl_Channel>(flush) {}
 };
 
+class FitsNRRDChannel : public FitsChannel, FitsNRRDStream<Tcl_Channel> {
+public:
+  FitsNRRDChannel(Tcl_Interp* interp, const char* ch, const char* ext, 
+		 FlushMode flush)
+    : FitsChannel(interp, ch, ext), FitsNRRDStream<Tcl_Channel>(flush) {}
+};
+
 class FitsMosaicChannel : public FitsChannel, FitsMosaicStream<Tcl_Channel> {
 public:
   FitsMosaicChannel(Tcl_Interp* interp, const char* ch, FlushMode flush)
