@@ -21,8 +21,8 @@ class FitsCompress : public FitsFile {
   unsigned int blank_;
   char* zmaskcmp_;
   
-  off_t tilesize_;
-  off_t size_;
+  size_t tilesize_;
+  size_t size_;
 
   FitsColumn* compress_;
   FitsColumn* uncompress_;
