@@ -15,19 +15,19 @@ class FitsHPX : public FitsFile {
   enum Layout {EQUATOR=0, NORTH=1, SOUTH=2};
 
  private:
-  Order order;
-  CoordSys coord;
-  Layout layout;
-  int quad;
+  Order order_;
+  CoordSys coord_;
+  Layout layout_;
+  int quad_;
 
-  int width;
-  int height;
-  off_t size;
+  int width_;
+  int height_;
+  size_t size_;
 
-  FitsBinColumn* col;
+  FitsBinColumn* col_;
 
-  long nside;
-  long nfacet;
+  long nside_;
+  long nfacet_;
 
   void build(FitsFile*);
   int initHeader(FitsFile*);
