@@ -13,8 +13,8 @@ public:
   ~FitsIIS();
 
   void erase();
-  const char* get(int, int);
-  void set(int, int, const char*, int);
+  char* get(int xx, int yy, int dx, int dy);
+  void set(const char* src, int xx, int yy, int dx, int dy);
 };
 
 #endif
