@@ -43,6 +43,11 @@ public:
   FitsArrMap();
 };
 
+class FitsNRRDMap : public virtual FitsMap {
+public:
+  FitsNRRDMap();
+};
+
 class FitsMosaicMap : public virtual FitsMap {
 public:
   FitsMosaicMap();
