@@ -10,16 +10,17 @@
 class FitsMapIncr : public FitsFile {
 protected:
   char* mapdata_;  // mmap segment ptr
-  off_t mapsize_;  // mmap segment size
+  size_t mapsize_;  // mmap segment size
   int page_;       // flag to indicate paging mode
 
-  off_t filesize_; // size of the total segment
-  off_t seek_;     // offset into segment
-  off_t dseek_;    // offset to data segment
-  off_t nseek_;    // offset into next page data segment
+  size_t filesize_; // size of the total segment
+  size_t seek_;     // offset into segment
+  size_t dseek_;    // offset to data segment
+  size_t nseek_;    // offset into next page data segment
 
   FitsHead* headRead();
-  void dataSkip(off_t);
+  void dataSkip(size_t);
+  void dataSkipBlock(size_t);
   void found();
   void error();
 
@@ -27,10 +28,10 @@ public:
   FitsMapIncr();
   virtual ~FitsMapIncr();
 
-  char* page(char*, off_t);
+  char* page(char*, size_t);
   void resetpage();
-  off_t filesize() {return filesize_;}
-  off_t seek() {return seek_;}
+  size_t filesize() {return filesize_;}
+  size_t seek() {return seek_;}
 };
 
 class FitsFitsMapIncr : public virtual FitsMapIncr {
