@@ -29,6 +29,11 @@ public:
   FitsArrMMap(const char* fn) : FitsMMap(fn), FitsArrMap() {}
 };
 
+class FitsNRRDMMap : public FitsMMap, public FitsNRRDMap {
+public:
+  FitsNRRDMMap(const char* fn) : FitsMMap(fn), FitsNRRDMap() {}
+};
+
 class FitsMosaicMMap : public FitsMMap, public FitsMosaicMap {
 public:
   FitsMosaicMMap(const char* fn) : FitsMMap(fn), FitsMosaicMap() {}
