@@ -6,7 +6,6 @@
 #define __outchannel_h__
 
 #include "outfits.h"
-#include "tcl.h"
 
 class OutFitsChannel : public virtual OutFitsStream {
  private:
@@ -15,7 +14,7 @@ class OutFitsChannel : public virtual OutFitsStream {
  public:
   OutFitsChannel(Tcl_Interp*, const char*);
 
-  int write(char*, int);
+  int write(char*, size_t);
 };
 
 #endif
