@@ -5,8 +5,6 @@
 #ifndef __outfile_h__
 #define __outfile_h__
 
-#include <stdio.h>
-
 #include "outfits.h"
 #include "zlib.h"
 
@@ -18,7 +16,7 @@ class OutFitsFile : public virtual OutFitsStream {
   OutFitsFile(const char*);
   ~OutFitsFile();
 
-  int write(char*, int);
+  int write(char*, size_t);
 };
 
 class OutFitsFileGZ : public virtual OutFitsStream {
@@ -29,7 +27,7 @@ class OutFitsFileGZ : public virtual OutFitsStream {
   OutFitsFileGZ(const char*);
   ~OutFitsFileGZ();
 
-  int write(char*, int);
+  int write(char*, size_t);
 };
 
 #endif
