@@ -9,7 +9,8 @@
 
 #include "util.h"
 
-#define STRMREADSIZE 1048576 // 1Mb
+#define B4KB 4096
+#define B1MB 1048576
 
 class OutFitsStream {
  protected:
