@@ -8,8 +8,6 @@
 #include "outfits.h"
 #include "zlib.h"
 
-#define GZBUFSIZE 4096
-
 class OutFitsSocket : public virtual OutFitsStream {
  private:
   int id_;
@@ -24,8 +22,8 @@ class OutFitsSocketGZ : public virtual OutFitsStream {
  private:
   int id_;
   z_stream* stream_;
-  unsigned char buf[GZBUFSIZE];
-  unsigned long crc;
+  unsigned char* buf_;
+  unsigned long crc_;
 
   int deflategz(int);
   void putlong(unsigned long);
