@@ -34,6 +34,11 @@ class FitsArrShare : public virtual FitsMap, public FitsArrMap {
   FitsArrShare() : FitsMap(), FitsArrMap() {}
 };
 
+class FitsNRRDShare : public virtual FitsMap, public FitsNRRDMap {
+ public:
+  FitsNRRDShare() : FitsMap(), FitsNRRDMap() {}
+};
+
 class FitsMosaicShare : public virtual FitsMap, public FitsMosaicMap {
  public:
   FitsMosaicShare() : FitsMap(), FitsMosaicMap() {}
@@ -68,6 +73,18 @@ public:
     : FitsShareKey(key, filter), FitsArrShare() {}
 };
 
+class FitsNRRDShareID : public FitsShareID, public FitsNRRDShare {
+public:
+  FitsNRRDShareID(int shmid, const char* filter)
+    : FitsShareID(shmid, filter), FitsNRRDShare() {}
+};
+
+class FitsNRRDShareKey : public FitsShareKey, public FitsNRRDShare {
+public:
+  FitsNRRDShareKey(int key, const char* filter) 
+    : FitsShareKey(key, filter), FitsNRRDShare() {}
+};
+
 class FitsMosaicShareID : public FitsShareID, public FitsMosaicShare {
 public:
   FitsMosaicShareID(int shmid) : FitsShareID(shmid, ""), FitsMosaicShare() {}
