@@ -10,17 +10,17 @@
 class FitsSMap : public FitsFile {
 protected:
   char* hmapdata_;
-  off_t hmapsize_;
+  size_t hmapsize_;
 
   char* mapdata_;
-  off_t mapsize_;
+  size_t mapsize_;
 
 public:
   FitsSMap();
   virtual ~FitsSMap() {}
 
   char* mapdata() {return mapdata_;}
-  int mapsize() {return mapsize_;}
+  size_t mapsize() {return mapsize_;}
 };
 
 class FitsFitsSMap : public virtual FitsSMap {
