@@ -29,6 +29,12 @@ public:
     : FitsSocket(s, ext), FitsArrStream<int>(flush) {}
 };
 
+class FitsNRRDSocket : public FitsSocket, public FitsNRRDStream<int> {
+public:
+  FitsNRRDSocket(int s, const char* ext, FlushMode flush) 
+    : FitsSocket(s, ext), FitsNRRDStream<int>(flush) {}
+};
+
 class FitsMosaicSocket : public FitsSocket, public FitsMosaicStream<int> {
 public:
   FitsMosaicSocket(int s, FlushMode flush) 
