@@ -33,6 +33,12 @@ public:
     : FitsVar(interp, var, fn), FitsArrMap() {}
 };
 
+class FitsNRRDVar : public FitsVar, public FitsNRRDMap {
+public:
+  FitsNRRDVar(Tcl_Interp* interp, const char* var, const char* fn) 
+    : FitsVar(interp, var, fn), FitsNRRDMap() {}
+};
+
 class FitsMosaicVar : public FitsVar, public FitsMosaicMap {
 public:
   FitsMosaicVar(Tcl_Interp* interp, const char* var, const char* fn) 
