@@ -33,6 +33,10 @@ class Annulus : public BaseEllipse {
   void rotate(const Vector& v, int h) {}
   void rotateEnd() {}
 
+  void analysis(AnalysisTask, int);
+  void analysisRadial(char*, char*, char*, Coord::CoordSystem sys);
+  void analysisStats(Coord::CoordSystem);
+
   void list(ostream&, Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat, int, int);
   void listXML(ostream&, Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat);
   void listCiao(ostream&, Coord::CoordSystem, int);
