@@ -791,6 +791,13 @@ public:
   void loadArrSocketGZCmd(int, const char*, LayerType);
   void loadArrVarCmd(const char*, const char*, LayerType);
 
+  void loadNRRDAllocCmd(const char*, const char*, LayerType);
+  void loadNRRDChannelCmd(const char*, const char*, LayerType);
+  void loadNRRDMMapCmd(const char*, LayerType);
+  void loadNRRDShareCmd(ShmType, int, const char*, LayerType);
+  void loadNRRDSocketCmd(int, const char*, LayerType);
+  void loadNRRDVarCmd(const char*, const char*, LayerType);
+
   virtual void loadPhotoCmd(const char*, const char*);
   virtual void loadSlicePhotoCmd(const char*, const char*);
 
@@ -892,30 +899,77 @@ public:
   virtual void loadRGBImageSocketGZCmd(int, const char*) {}
   virtual void loadRGBImageVarCmd(const char*, const char*, LoadMethod) {}
 
-  virtual void loadArrRGBCubeAllocCmd(const char*, const char*) {}
-  virtual void loadArrRGBCubeAllocGZCmd(const char*, const char*) {}
-  virtual void loadArrRGBCubeChannelCmd(const char*, const char*) {}
-  virtual void loadArrRGBCubeMMapCmd(const char*) {}
-  virtual void loadArrRGBCubeMMapIncrCmd(const char*) {}
-  virtual void loadArrRGBCubeShareCmd(ShmType, int, const char*) {}
-  virtual void loadArrRGBCubeSocketCmd(int, const char*) {}
-  virtual void loadArrRGBCubeSocketGZCmd(int, const char*) {}
-  virtual void loadArrRGBCubeVarCmd(const char*, const char*) {}
+  virtual void loadArrayRGBCubeAllocCmd(const char*, const char*) {}
+  virtual void loadArrayRGBCubeAllocGZCmd(const char*, const char*) {}
+  virtual void loadArrayRGBCubeChannelCmd(const char*, const char*) {}
+  virtual void loadArrayRGBCubeMMapCmd(const char*) {}
+  virtual void loadArrayRGBCubeMMapIncrCmd(const char*) {}
+  virtual void loadArrayRGBCubeShareCmd(ShmType, int, const char*) {}
+  virtual void loadArrayRGBCubeSocketCmd(int, const char*) {}
+  virtual void loadArrayRGBCubeSocketGZCmd(int, const char*) {}
+  virtual void loadArrayRGBCubeVarCmd(const char*, const char*) {}
 
   virtual void savePhotoCmd(const char*) {}
 
-  void saveFitsImageFileCmd(const char*, int);
-  void saveFitsImageChannelCmd(const char*, int);
-  void saveFitsImageSocketCmd(int, int);
-  virtual void saveFitsResampleFileCmd(const char*, int) {}
-  virtual void saveFitsResampleChannelCmd(const char*, int) {}
-  virtual void saveFitsResampleSocketCmd(int, int) {}
-  void saveFitsTableFileCmd(const char*, int);
-  void saveFitsTableChannelCmd(const char*, int);
-  void saveFitsTableSocketCmd(int, int);
+  void saveFits(OutFitsStream&);
+  void saveFitsFileCmd(const char*);
+  void saveFitsChannelCmd(const char*);
+  void saveFitsSocketCmd(int);
+
+  void saveFitsTable(OutFitsStream&);
+  void saveFitsTableFileCmd(const char*);
+  void saveFitsTableChannelCmd(const char*);
+  void saveFitsTableSocketCmd(int);
+
+  void saveFitsSlice(OutFitsStream&);
+  void saveFitsSliceFileCmd(const char*);
+  void saveFitsSliceChannelCmd(const char*);
+  void saveFitsSliceSocketCmd(int);
+
+  void saveFitsExtCube(OutFitsStream&);
+  void saveFitsExtCubeFileCmd(const char*);
+  void saveFitsExtCubeChannelCmd(const char*);
+  void saveFitsExtCubeSocketCmd(int);
+
+  void saveFitsMosaic(OutFitsStream&, int);
+  void saveFitsMosaicFileCmd(const char*, int);
+  void saveFitsMosaicChannelCmd(const char*, int);
+  void saveFitsMosaicSocketCmd(int, int);
+
+  void saveFitsMosaicImage(OutFitsStream&);
+  void saveFitsMosaicImageFileCmd(const char*);
+  void saveFitsMosaicImageChannelCmd(const char*);
+  void saveFitsMosaicImageSocketCmd(int);
+
+  virtual void saveFitsRGBImage(OutFitsStream&) {}
+  virtual void saveFitsRGBImageFileCmd(const char*) {}
+  virtual void saveFitsRGBImageChannelCmd(const char*) {}
+  virtual void saveFitsRGBImageSocketCmd(int) {}
+
+  virtual void saveFitsRGBCube(OutFitsStream&) {}
+  virtual void saveFitsRGBCubeFileCmd(const char*) {}
+  virtual void saveFitsRGBCubeChannelCmd(const char*) {}
+  virtual void saveFitsRGBCubeSocketCmd(int) {}
+
+  virtual void saveFitsResampleFileCmd(const char*) {}
+  virtual void saveFitsResampleChannelCmd(const char*) {}
+  virtual void saveFitsResampleSocketCmd(int) {}
+
+  void saveArray(OutFitsStream&, FitsFile::ArchType);
   void saveArrayFileCmd(const char*, FitsFile::ArchType);
   void saveArrayChannelCmd(const char*, FitsFile::ArchType);
   void saveArraySocketCmd(int, FitsFile::ArchType);
+
+  virtual void saveArrayRGBCube(OutFitsStream&, FitsFile::ArchType) {}
+  virtual void saveArrayRGBCubeFileCmd(const char*, FitsFile::ArchType) {}
+  virtual void saveArrayRGBCubeChannelCmd(const char*, FitsFile::ArchType) {}
+  virtual void saveArrayRGBCubeSocketCmd(int, FitsFile::ArchType) {}
+
+  void saveNRRD(OutFitsStream&, FitsFile::ArchType);
+  void saveNRRDFileCmd(const char*, FitsFile::ArchType);
+  void saveNRRDChannelCmd(const char*, FitsFile::ArchType);
+  void saveNRRDSocketCmd(int, FitsFile::ArchType);
+
   void sliceCmd(int, int);
 
   void updateFitsCmd(int);
