@@ -48,8 +48,11 @@ public:
 
   virtual Marker* dup() =0;
 
-  int isIn(const Vector& vv) {return isIn(vv, Coord::CANVAS);}
-  int isIn(const Vector&, Coord::InternalSystem);
+  int isIn(const Vector& vv) 
+  {return isIn(vv, Coord::CANVAS);}
+  int isIn(const Vector& vv, Coord::InternalSystem sys)
+  {return isIn(vv,sys,numAnnuli_-1);}
+  int isIn(const Vector&, Coord::InternalSystem, int);
 };
 
 #endif
