@@ -23,8 +23,9 @@ public:
   void edit(const Vector&, int);
   void editEnd();
 
-  void analysis(AnalysisMethod, int);
-  void analysisPlot3d(char*, char*);
+  void analysis(AnalysisTask, int);
+  void analysisPlot3d(char*, char*, Coord::CoordSystem, Marker::AnalysisMethod);
+  void analysisStats(Coord::CoordSystem);
 
   void list(ostream&, Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat, int, int);
   void listXML(ostream&, Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat);
