@@ -39,6 +39,10 @@ public:
 
   int addAnnuli(const Vector&);
 
+  void analysis(AnalysisTask, int);
+  void analysisRadial(char*, char*, char*, Coord::CoordSystem sys);
+  void analysisStats(Coord::CoordSystem);
+
   void list(ostream&, Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat, int, int);
   void listXML(ostream&, Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat);
   void listPros(ostream&, Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat, int);
