@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2004
+// Copyright (C) 1999-2012
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -8,20 +8,35 @@
 #include <tcl.h>
 
 class CallBack {
+ public:
+  enum Type {SELECTCB, UNSELECTCB, 
+	     HIGHLITECB, UNHIGHLITECB,
+	     EDITBEGINCB, EDITCB, EDITENDCB, 
+	     MOVEBEGINCB, MOVECB, MOVEENDCB, 
+	     ROTATEBEGINCB, ROTATECB, ROTATEENDCB, 
+	     DELETECB, 
+	     TEXTCB, COLORCB, LINEWIDTHCB, PROPERTYCB, FONTCB, 
+	     KEYCB,
+	     UPDATECB};
+
+ private:
   Tcl_Interp* interp_;
-  char proc_[32];
-  char arg_[64];
+
+  Type type_;
+  char proc_[128];
+  char arg_[256];
 
   CallBack* previous_;
   CallBack* next_;
 
-public:
+ public:
   CallBack(const CallBack&);
-  CallBack(Tcl_Interp*, const char*, const char*);
+  CallBack(Tcl_Interp*, Type, const char*, const char*);
   CallBack& operator=(const CallBack&);
 
   int eval(const char*);
 
+  Type type() {return type_;}
   const char* proc() {return proc_;}
   const char* arg() {return arg_;}
 
