@@ -24,8 +24,9 @@ public:
   void rotate(const Vector& v, int h) {}
   void rotateEnd() {}
 
-  void analysis(AnalysisMethod, int);
-  void analysisPlot3d(char*, char*);
+  void analysis(AnalysisTask, int);
+  void analysisPlot3d(char*, char*, Coord::CoordSystem, Marker::AnalysisMethod);
+  void analysisStats(Coord::CoordSystem);
 
   void list(ostream&, Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat, int, int);
   void listXML(ostream&, Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat);
