@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2004
+// Copyright (C) 1999-2012
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -8,6 +8,8 @@
 #include <tcl.h>
 #include <X11/Xlib.h>
 
+#include "util.h"
+
 class ColorScaleRGB {
 protected:
   int size_;
@@ -28,7 +30,17 @@ public:
 
 class LogScaleRGB : public virtual ColorScaleRGB {
 public:
-  LogScaleRGB(int, int, unsigned char*, int);
+  LogScaleRGB(int, int, unsigned char*, int, double);
+};
+
+class PowScaleRGB : public virtual ColorScaleRGB {
+public:
+  PowScaleRGB(int, int, unsigned char*, int, double);
+};
+
+class SqrtScaleRGB : public virtual ColorScaleRGB {
+public:
+  SqrtScaleRGB(int, int, unsigned char*, int);
 };
 
 class SquaredScaleRGB : public virtual ColorScaleRGB {
@@ -36,9 +48,14 @@ public:
   SquaredScaleRGB(int, int, unsigned char*, int);
 };
 
-class SqrtScaleRGB : public virtual ColorScaleRGB {
+class AsinhScaleRGB : public virtual ColorScaleRGB {
 public:
-  SqrtScaleRGB(int, int, unsigned char*, int);
+  AsinhScaleRGB(int, int, unsigned char*, int);
+};
+
+class SinhScaleRGB : public virtual ColorScaleRGB {
+public:
+  SinhScaleRGB(int, int, unsigned char*, int);
 };
 
 class HistEquScaleRGB : public virtual ColorScaleRGB {
