@@ -109,6 +109,7 @@ class FitsImage {
 
   void process(const char*, int);
   void initCompress();
+  void initNRRD();
   void initHist();
   Vector getHistCenter();
   int initHPX();
@@ -431,33 +432,26 @@ class FitsImage {
   char* getKeyword(const char*);
   int findKeyword(const char*);
 
-  int saveFitsImageFile(const char* fn, int compress)
-  {return image_ ? image_->saveFitsImageFile(fn, compress) : 0;}
+  int saveFitsPrimHeader(OutFitsStream& str)
+  {return image_ ? image_->saveFitsPrimHeader(str) : 0;}
 
-  int saveFitsImageChannel(Tcl_Interp* interp, const char* ch, int compress)
-  {return image_ ? image_->saveFitsImageChannel(interp, ch, compress) : 0;}
+  int saveFitsXtHeader(OutFitsStream& str, int dd)
+  {return image_ ? image_->saveFitsXtHeader(str, dd) : 0;}
 
-  int saveFitsImageSocket(int s, int compress)
-  {return image_ ? image_->saveFitsImageSocket(s, compress) : 0;}
+  int saveFitsHeader(OutFitsStream& str, int dd)
+  {return image_ ? image_->saveFitsHeader(str, dd) : 0;}
 
-  int saveFitsTableFile(const char* fn, int compress)
-  {return fits_ ? fits_->saveFitsTableFile(fn, compress) : 0;}
+  int saveFits(OutFitsStream& str)
+  {return image_ ? image_->saveFits(str) : 0;}
 
-  int saveFitsTableChannel(Tcl_Interp* interp, const char* ch, int compress)
-  {return fits_ ? fits_->saveFitsTableChannel(interp, ch, compress): 0;}
+  int saveFitsPad(OutFitsStream& str, size_t cnt, char fil)
+  {return image_ ? image_->saveFitsPad(str, cnt, fil) : 0;}
 
-  int saveFitsTableSocket(int s, int compress)
-  {return fits_ ? fits_->saveFitsTableSocket(s, compress) : 0;}
+  int saveFitsTable(OutFitsStream& str)
+  {return fits_ ? fits_->saveFitsTable(str) : 0;}
 
-  int saveArrayFile(const char* fn, FitsFile::ArchType endian)
-  {return image_ ? image_->saveArrayFile(fn, endian) : 0;}
-
-  int saveArrayChannel(Tcl_Interp* interp, const char* ch,
-		       FitsFile::ArchType endian)
-  {return image_ ? image_->saveArrayChannel(interp, ch, endian) : 0;}
-
-  int saveArraySocket(int s, FitsFile::ArchType endian)
-  {return image_ ? image_->saveArraySocket(s, endian) : 0;}
+  int saveArray(OutFitsStream& str, FitsFile::ArchType endian)
+  {return image_ ? image_->saveArray(str, endian) : 0;}
 };
 
 // Fits
@@ -637,6 +631,40 @@ public:
   FitsImageArrVar(Base*, Tcl_Interp*, const char*, const char*, int);
 };
 
+// NRRD
+
+class FitsImageNRRDAlloc : public FitsImage {
+public:
+  FitsImageNRRDAlloc(Base*, const char*, const char*, 
+		    FitsFile::FlushMode, int);
+};
+
+class FitsImageNRRDChannel : public FitsImage {
+public:
+  FitsImageNRRDChannel(Base*, Tcl_Interp*, const char*, const char*, 
+		      FitsFile::FlushMode, int);
+};
+
+class FitsImageNRRDMMap : public FitsImage {
+public:
+  FitsImageNRRDMMap(Base*, const char*, int);
+};
+
+class FitsImageNRRDShare : public FitsImage {
+public:
+  FitsImageNRRDShare(Base*, Base::ShmType, int, const char*, int);
+};
+
+class FitsImageNRRDSocket : public FitsImage {
+public:
+  FitsImageNRRDSocket(Base*, int, const char*, FitsFile::FlushMode, int);
+};
+
+class FitsImageNRRDVar : public FitsImage {
+public:
+  FitsImageNRRDVar(Base*, Tcl_Interp*, const char*, const char*, int);
+};
+
 // Photo
 
 class FitsImagePhoto : public FitsImage {
@@ -762,8 +790,8 @@ class FitsImageIIS : public FitsImage {
 public:
   FitsImageIIS(Base*, int, int);
   void iisErase();
-  const char* iisGet(int x, int y);
-  void iisSet(int x, int y, const char* d, int l);
+  char* iisGet(int xx, int yy, int dx, int dy);
+  void iisSet(const char* src, int xx, int yy, int dx, int dy);
   void iisWCS(const Matrix&, const Vector&, int);
 };
 
