@@ -23,7 +23,6 @@ protected:
 
   virtual void rotateMotion() =0;
 
-  void saveFitsResample(OutFitsStream&);
   void saveFitsResampleFits(OutFitsStream&);
   void saveFitsResampleKeyword(OutFitsStream&, FitsHead&);
   void setBinCursor();
@@ -57,9 +56,10 @@ public:
 	       Grid::GridType, const char*, const char*);
 
   // Fits Commands
-  void saveFitsResampleFileCmd(const char*, int);
-  void saveFitsResampleChannelCmd(const char*, int);
-  void saveFitsResampleSocketCmd(int, int);
+  void saveFitsResample(OutFitsStream&);
+  void saveFitsResampleFileCmd(const char*);
+  void saveFitsResampleChannelCmd(const char*);
+  void saveFitsResampleSocketCmd(int);
 
   // IIS Commands
   void iisCursorModeCmd(int);
