@@ -106,15 +106,32 @@ class FrameRGB : public virtual FrameBase {
   void loadRGBImageSocketGZCmd(int, const char*);
   void loadRGBImageVarCmd(const char*, const char*, LoadMethod);
 
-  void loadArrRGBCubeAllocCmd(const char*, const char*);
-  void loadArrRGBCubeAllocGZCmd(const char*, const char*);
-  void loadArrRGBCubeChannelCmd(const char*, const char*);
-  void loadArrRGBCubeMMapCmd(const char*);
-  void loadArrRGBCubeMMapIncrCmd(const char*);
-  void loadArrRGBCubeShareCmd(ShmType, int, const char*);
-  void loadArrRGBCubeSocketCmd(int, const char*);
-  void loadArrRGBCubeSocketGZCmd(int, const char*);
-  void loadArrRGBCubeVarCmd(const char*, const char*);
+  void loadArrayRGBCubeAllocCmd(const char*, const char*);
+  void loadArrayRGBCubeAllocGZCmd(const char*, const char*);
+  void loadArrayRGBCubeChannelCmd(const char*, const char*);
+  void loadArrayRGBCubeMMapCmd(const char*);
+  void loadArrayRGBCubeMMapIncrCmd(const char*);
+  void loadArrayRGBCubeShareCmd(ShmType, int, const char*);
+  void loadArrayRGBCubeSocketCmd(int, const char*);
+  void loadArrayRGBCubeSocketGZCmd(int, const char*);
+  void loadArrayRGBCubeVarCmd(const char*, const char*);
+
+  void saveFitsRGBImage(OutFitsStream&);
+  void saveFitsRGBImageFileCmd(const char*);
+  void saveFitsRGBImageChannelCmd(const char*);
+  void saveFitsRGBImageSocketCmd(int);
+
+  void saveFitsRGBCube(OutFitsStream&);
+  void saveFitsRGBCubeFileCmd(const char*);
+  void saveFitsRGBCubeChannelCmd(const char*);
+  void saveFitsRGBCubeSocketCmd(int);
+
+  void saveArrayRGBCube(OutFitsStream&, FitsFile::ArchType);
+  void saveArrayRGBCubeFileCmd(const char*, FitsFile::ArchType);
+  void saveArrayRGBCubeChannelCmd(const char*, FitsFile::ArchType);
+  void saveArrayRGBCubeSocketCmd(int, FitsFile::ArchType);
+
+  void savePhotoCmd(const char*);
 
   void setRGBChannelCmd(const char*);
   void setRGBViewCmd(int, int, int);
