@@ -18,13 +18,16 @@ class Grid {
   Coord::CoordSystem system_;
   Coord::SkyFrame sky_;
   Coord::SkyFormat skyFormat_;
+  char* vars_;
 
  public:
-  Grid(Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat, GridType);
-  ~Grid();
+  Grid(Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat, 
+       GridType, const char*);
+  virtual ~Grid();
 
   virtual const char* option() =0;
-  virtual void render() =0;
+
+  virtual void x11() =0;
   virtual void ps(int) =0;
 #ifdef _MACOSX
   virtual void macosx() =0;
@@ -37,6 +40,7 @@ class Grid {
   Coord::CoordSystem system() {return system_;}
   Coord::SkyFrame sky() {return sky_;}
   Coord::SkyFormat skyFormat() {return skyFormat_;}
+  const char* vars() {return vars_;}
 };
 
 #endif
