@@ -17,10 +17,14 @@ class Grid25d : public Grid, public Grid25dBase {
   int doit(RenderMode);
 
  public:
-  Grid25d(Widget*, Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat, GridType, const char*);
+  Grid25d(Widget*, Coord::CoordSystem, Coord::SkyFrame, 
+	  Coord::SkyFormat, GridType, 
+	  const char*, const char*);
+  ~Grid25d();
 
-  const char* option() {return Grid25dBase::option();}
-  void render() {doit(X11);}
+  const char* option() {return GridBase::option();}
+
+  void x11() {doit(X11);}
   void ps(int mode) {mode_=mode; doit(PS);}
 #ifdef _MACOSX
   void macosx() {doit(MACOSX);}
