@@ -17,10 +17,14 @@ class Grid2d : public Grid, public Grid2dBase {
   int doit(RenderMode);
 
  public:
-  Grid2d(Widget*, Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat, GridType, const char*);
+  Grid2d(Widget*, Coord::CoordSystem, Coord::SkyFrame, 
+	 Coord::SkyFormat, GridType, 
+	 const char*, const char*);
+  ~Grid2d();
 
-  const char* option() {return Grid2dBase::option();}
-  void render() {doit(X11);}
+  const char* option() {return GridBase::option();}
+
+  void x11() {doit(X11);}
   void ps(int mode) {mode_=mode; doit(PS);}
 #ifdef _MACOSX
   void macosx() {doit(MACOSX);}
