@@ -40,8 +40,10 @@ public:
   int getP1Arrow() {return p1Arrow;}
   int getP2Arrow() {return p2Arrow;}
 
-  void analysis(AnalysisMethod, int);
-  void analysisPlot2d(char*, char*, char*, char*);
+  void analysis(AnalysisTask, int);
+  void analysisPlot2d(char*, char*, char*, char*, 
+		      Coord::CoordSystem, Coord::SkyFrame, 
+		      Marker::AnalysisMethod);
 
   virtual void list(ostream&, Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat, int, int);
   virtual void listXML(ostream&, Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat);
