@@ -49,8 +49,9 @@ public:
   int isIn(const Vector& vv) {return isIn(vv, Coord::CANVAS);}
   int isIn(const Vector&, Coord::InternalSystem);
 
-  void analysis(AnalysisMethod, int);
-  void analysisPlot3d(char*, char*);
+  void analysis(AnalysisTask, int);
+  void analysisPlot3d(char*, char*, Coord::CoordSystem, Marker::AnalysisMethod);
+  void analysisStats(Coord::CoordSystem);
 
   void createVertex(int, const Vector&);
   void deleteVertex(int);
