@@ -49,8 +49,10 @@ class Projection : public BaseLine {
 
   void edit(const Vector&, int);
 
-  void analysis(AnalysisMethod, int);
-  void analysisPlot2d(char*, char*, char*, char*);
+  void analysis(AnalysisTask, int);
+  void analysisPlot2d(char*, char*, char*, char*, 
+		      Coord::CoordSystem, Coord::SkyFrame, 
+		      Marker::AnalysisMethod);
 
   void set(const Vector&, const Vector&, double);
   void setWidth(double);
