@@ -10,24 +10,27 @@
 #include <signal.h>
 
 static sigjmp_buf crashbuf;
-static struct sigaction osigact, sigact;
+static struct sigaction sigact, osigbus, osigsegv;
 static void crashHandler(int dummy) {
   siglongjmp(crashbuf, 1);
 }
 #define INTERP interp
 #define SETSIGBUS \
   if (sigsetjmp(crashbuf, 1)) { \
-    Tcl_SetVar2(INTERP, "ds9", "msg", "A fatal SIGBUS error has been received. Please exit Immediately.", TCL_GLOBAL_ONLY); \
-    Tcl_SetVar2(INTERP, "ds9", "msg,level", "fatal", TCL_GLOBAL_ONLY); \
+    Tcl_SetVar2(INTERP, "ds9", "msg", "A SIGBUS or SIGSEGV error has been received.", TCL_GLOBAL_ONLY); \
+    Tcl_SetVar2(INTERP, "ds9", "msg,level", "error", TCL_GLOBAL_ONLY); \
   } \
   else { \
     sigact.sa_handler = crashHandler; \
     sigemptyset(&sigact.sa_mask); \
     sigact.sa_flags = 0; \
-    sigaction(SIGBUS, &sigact, &osigact);
+    sigaction(SIGSEGV, &sigact, &osigsegv); \
+    sigaction(SIGBUS, &sigact, &osigbus);
   
 #define CLEARSIGBUS \
   } \
-  sigaction(SIGBUS, &osigact, NULL); \
+  sigaction(SIGSEGV, &osigsegv, NULL); \
+  sigaction(SIGBUS, &osigbus, NULL);
 
 #endif
+
