@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2004
+// Copyright (C) 1999-2012
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -27,13 +27,18 @@ public:
   void insertPrev(T*,T*);
   void append(T*);
   T* pop();
+  T* extract();
   T* extractNext(T*);
   T* extractPrev(T*);
   void deleteAll();
+  T* begin() {return head_;}
+  T* end() {return tail_;}
   T* head() {return current_ = head_;}
   T* tail() {return current_ = tail_;}
   T* next() {return current_ ? current_ = current_->next() : NULL;}
+  int isNext() {return current_->next() ? 1 : 0;}
   T* previous() {return current_ ? current_ = current_->previous() : NULL;}
+  int isPrevious() {return current_->previous() ? 1 : 0;}
   T* current() {return current_;}
   int count() {return count_;}
   int isEmpty() {return (count_==0) ? 1 : 0;}
