@@ -33,8 +33,7 @@ public:
 
   void crosshairCmd(int);
   void getBBoxCmd();
-  void updateCmd(Pixmap);
-  void updateCmd(Pixmap, double, double);
+  void updateCmd(void*);
 };
 
 #endif
