@@ -29,7 +29,6 @@ class Panner : public Widget {
   Vector wcsEast;
   int validWCSCompass;       // flag to indicate wcs data is valid
 
-  int useFont;               // flag to use fonts
   Tk_Font tkfont_;              // Tk font
   Tk_FontMetrics metric;     // Tk font metric
 				  
@@ -67,7 +66,7 @@ class Panner : public Widget {
   void panEndCmd(const Vector&);
   void setCompassCmd(int);
   void setBBoxCmd(int);
-  void updateCmd(Pixmap);
+  void updateCmd(void*);
   void updateBBoxCmd(const Vector&, const Vector&, 
 		     const Vector&, const Vector&);
   void updateImageCompassCmd(Vector, Vector);
