@@ -52,13 +52,11 @@ proc ClearAnalysis {} {
     global ianalysis
 
     # is something loaded?
-
     if {$ianalysis(menu,count) == 0} {
 	return
     }
 
     # delete cascade menus
-
     for {set i 0} {$i<$ianalysis(menu,hmenu,count)} {incr i} {
 	destroy [lindex $ianalysis(menu,hmenu) $i]
     }
@@ -66,7 +64,6 @@ proc ClearAnalysis {} {
     set ianalysis(menu,hmenu,count) 0
 
     # clear menu
-
     $ds9(mb).analysis delete $ds9(menu,size,analysis) end
 
     for {set i 0} {$i<$ianalysis(menu,count)} {incr i} {
@@ -853,7 +850,7 @@ proc AnalysisProcessGetURL {which i result} {
 		       $ianalysis($which,$i,result)}
 	image {
 	    set fn "[string tolower [lindex $ianalysis($which,$i,item) 0]].fits"
-	    LoadVar result $fn {}
+	    LoadVar result $fn {} {}
 	}
 	default {Error $ianalysis($which,$i,result)}
     }
@@ -1670,13 +1667,12 @@ proc ParseURLMacro {cmdname which i} {
     upvar $cmdname cmd
     global ianalysis
 
-    set exp {\$url\((.*)\)}
-#    set exp {\$url\((.*)\) |}
+    set exp {\$url\((.*)\) \|}
     if {[regexp $exp $cmd foo ianalysis($which,$i,start,url)]} {
 	set ianalysis($which,$i,start) url
 	set ianalysis($which,$i,start,fn) [tmpnam ds9ans {.fits}]
 
-	regsub $exp $cmd "cat \{$ianalysis($which,$i,start,fn)\} " cmd
+	regsub $exp $cmd "cat \{$ianalysis($which,$i,start,fn)\} |" cmd
     }
 }
 
@@ -1734,7 +1730,7 @@ proc AnalysisMessage {type message} {
 proc AnalysisEntry {message resultvar} {
     upvar $resultvar result
 
-    return [EntryDialog [msgcat::mc {Entry}] $message 60 result {}]
+    return [EntryDialog [msgcat::mc {Entry}] $message 60 result]
 }
 
 proc AnalysisPrefOpen {varname} {
