@@ -194,7 +194,13 @@ proc CATDialog {varname format catalog title action} {
     $mb.file.samp.send add separator
 
     # edit
-    EditMenu $mb $varname
+    menu $mb.edit
+    $mb.edit add command -label [msgcat::mc {Cut}] \
+	-command "CATCut $varname" -accelerator "${ds9(ctrl)}X"
+    $mb.edit add command -label [msgcat::mc {Copy}] \
+	-command "CATCopy $varname" -accelerator "${ds9(ctrl)}C"
+    $mb.edit add command -label [msgcat::mc {Paste}] \
+	-command "EntryPaste $var(top)" -accelerator "${ds9(ctrl)}V"
     $mb.edit add separator
     $mb.edit add command -label [msgcat::mc {Clear}] \
 	-command [list ARClear $varname]
@@ -597,7 +603,7 @@ proc CATCopy {varname} {
     if {$w == $var(tbl)} {
 	CATCopyTable $varname
     } else {
-	EntryCopy $varname
+	EntryCopy $var(top)
     }
 }
 
@@ -635,7 +641,7 @@ proc CATCut {varname} {
     if {$w == $var(tbl)} {
 	CATCopyTable $varname
     } else {
-	EntryCut $varname
+	EntryCut $var(top)
     }
 }
 
