@@ -78,14 +78,15 @@ proc ProcessCommand {argv argc} {
     global minmax
     global zscale
     global iis
-    global http
+    global file
+
+    set file(type) fits
+    set file(mode) {}
+    set file(layer) {}
+    set file(mosaic) wcs
 
     set load 0
     set noopts 0
-    set file(mode) fits
-    set file(slice) 0
-    set file(layer) {}
-    set file(mosaic) wcs
     set i 0
 
     # Note: -help is processed previously for fv (temporary)
@@ -109,9 +110,8 @@ proc ProcessCommand {argv argc} {
 	    -3d {incr i; Process3DCmd argv i}
 	    -about {ProcessSendAboutCmd puts stdout {} {} {}}
 	    -align {incr i; ProcessAlignCmd argv i}
-	    -analysis -
-	    -analysismenu {incr i; ProcessAnalysisCmd argv i {} {}}
-	    -array {set file(mode) array}
+	    -analysis {incr i; ProcessAnalysisCmd argv i {} {}}
+	    -array {set file(type) array}
 	    -asinh {set scale(type) asinh; ChangeScale}
 	    -bg -
 	    -background {incr i; ProcessBgCmd argv i}
@@ -125,21 +125,19 @@ proc ProcessCommand {argv argc} {
 	    -cmap {incr i; ProcessCmapCmd argv i}
 	    -colorbar {incr i; ProcessColorbarCmd argv i}
 	    -console {ProcessConsoleCmd argv i}
+	    -contours -
 	    -contour {incr i; ProcessContourCmd argv i}
 	    -nocontour {set contour(view) 0; ContourUpdate}
 	    -crop {incr i; ProcessCropCmd argv i}
 	    -crosshair {incr i; ProcessCrosshairCmd argv i}
 	    -cursor {incr i; ProcessCursorCmd argv i}
-	    -cube -
-	    -datacube {incr i; ProcessCubeCmd argv i}
+	    -datacube -
+	    -cube {incr i; ProcessCubeCmd argv i}
 	    -debug {incr i; ProcessDebugCmd argv i}
 	    -dss -
-	    -dsssao -
-	    -sao {incr i; ProcessSAOCmd argv i}
-	    -dsseso -
-	    -eso {incr i; ProcessESOCmd argv i}
-	    -dssstsci -
-	    -stsci {incr i; ProcessSTSCICmd argv i}
+	    -dsssao {incr i; ProcessSAOCmd argv i}
+	    -dsseso {incr i; ProcessESOCmd argv i}
+	    -dssstsci {incr i; ProcessSTSCICmd argv i}
 	    -export {incr i; ProcessExportCmd argv i}
 	    -exit -
 	    -quit {ProcessQuitCmd argv i}
@@ -161,11 +159,11 @@ proc ProcessCommand {argv argc} {
 	    }
 	    -first {incr i; ProcessFIRSTCmd argv i}
 	    -file -
-	    -fits {set file(mode) fits}
-	    -sfits {set file(mode) sfits}
+	    -fits {set file(type) fits; CommandFitsCmd argv i}
 	    -geometry {
 		# already processed
 	    }
+	    -gif {set file(type) gif}
 	    -green {set current(rgb) green; RGBChannel}
 	    -grid {incr i; ProcessGridCmd argv i}
 	    -nogrid {set grid(view) 0; GridUpdate}
@@ -184,7 +182,6 @@ proc ProcessCommand {argv argc} {
 	    }
 	    -iconify {incr i; ProcessIconifyCmd argv i}
 	    -iis {incr i; ProcessIISCmd argv i}
-	    -photo {set file(mode) photo}
 	    -info {
 		# backward compatibility
 		set view(info) 1
@@ -196,6 +193,8 @@ proc ProcessCommand {argv argc} {
 		UpdateView
 	    }
 	    -invert {set colorbar(invert) 1; InvertColorbar}
+	    -jpg -
+	    -jpeg {set file(type) jpeg}
 	    -language {
 		# already processed
 		incr i
@@ -211,12 +210,11 @@ proc ProcessCommand {argv argc} {
 		UpdateView
 	    }
 	    -mask {incr i; set file(layer) [ProcessMaskCmd argv i]}
+	    -nomask {set file(layer) {}}
 	    -match {incr i; ProcessMatchCmd argv i}
-	    -datacube -
-	    -mecube -
-	    -medatacube {set file(mode) mecube}
+	    -mecube {set file(type) mecube}
 	    -memf -
-	    -multiframe {set file(mode) multiframe}
+	    -multiframe {set file(type) multiframe}
 	    -minmax {incr i; ProcessMinMaxCmd argv i}
 	    -minmaxmode {
 		# backward compatibility
@@ -230,49 +228,43 @@ proc ProcessCommand {argv argc} {
 	    }
 	    -mode {incr i; ProcessModeCmd argv i}
 
-	    -mosaicimage {
-		set file(mode) mosaicimage
-		set aa [lindex $argv [expr $i+1]]
-		switch -- $aa {
-		    wfpc2 {incr i; set file(mosaic) wfpc2}
-		    default {CommandMosaicType $aa file i}
-		}
-	    }
 	    -mosaic {
-		set file(mode) mosaic
-		CommandMosaicType [lindex $argv [expr $i+1]] file i
+		set file(type) mosaic
+		CommandMosaicCmd argv i
 	    }
-	    -smosaic {
-		set file(mode) smosaic
-		CommandMosaicType [lindex $argv [expr $i+1]] file i
+	    -mosaicimage {
+		set file(type) mosaicimage
+		CommandMosaicImageCmd argv i
 	    }
 
 	    -mosaicimageiraf {
 		# backward compatibility
-		set file(mode) mosaicimage
+		set file(type) mosaicimage
 		set file(mosaic) iraf
 	    }
 	    -mosaicimagewcs {
 		# backward compatibility
-		set file(mode) mosaicimage
+		set file(type) mosaicimage
 		set file(mosaic) wcs
 	    }
 	    -mosaicimagewfpc2 {
 		# backward compatibility
-		set file(mode) mosaicimage
+		set file(type) mosaicimage
 		set file(mosaic) wfpc2
 	    }
 
 	    -mosaiciraf {
 		# backward compatibility
-		set file(mode) mosaic
+		set file(type) mosaic
 		set file(mosaic) iraf
 	    }
 	    -mosaicwcs {
 		# backward compatibility
-		set file(mode) mosaic
+		set file(type) mosaic
 		set file(mosaic) wcs
 	    }
+	    -savempeg -
+	    -movie {incr i; ProcessMovieCmd argv i}
 
 	    -msg {
 		# already processed
@@ -280,6 +272,7 @@ proc ProcessCommand {argv argc} {
 	    }
 	    -nameserver {incr i; ProcessNRESCmd argv i}
 	    -nan {incr i; ProcessNanCmd argv i}
+	    -nrrd {set file(type) nrrd}
 	    -nvss {incr i; ProcessNVSSCmd argv i}
 	    -orient {incr i; ProcessOrientCmd argv i}
 	    -pagesetup {incr i; ProcessPageSetupCmd argv i}
@@ -295,9 +288,14 @@ proc ProcessCommand {argv argc} {
 		set view(panner) 0
 		UpdateView
 	    }
+	    -photo {
+		# backward compatibility
+		set file(type) tiff
+	    }
 	    -pixeltable {incr i; ProcessPixelTableCmd argv i}
 	    -nopixeltable {PixelTableDestroyDialog}
 	    -plot {incr i; ProcessPlotCmd argv i {} {}}
+	    -png {set file(type) png}
 	    -port {incr i; set iis(port) [lindex $argv $i]}
 	    -inet_only -
 	    -port_only {
@@ -320,17 +318,18 @@ proc ProcessCommand {argv argc} {
 	    -regionfile {incr i; ProcessRegionsCmd argv i {} {}}
 	    -restore {incr i; ProcessRestoreCmd argv i}
 	    -rgb {incr i; ProcessRGBCmd argv i}
-	    -rgbcube {set file(mode) rgbcube}
-	    -srgbcube {set file(mode) srgbcube}
-	    -rgbimage {set file(mode) rgbimage}
-	    -rgbarray {set file(mode) rgbarray}
+	    -rgbcube {set file(type) rgbcube}
+	    -srgbcube {
+		# backward compatibility
+		set file(type) srgbcube
+	    }
+	    -rgbimage {set file(type) rgbimage}
+	    -rgbarray {set file(type) rgbarray}
 	    -rotate {incr i; ProcessRotateCmd argv i}
 	    -samp {incr i; ProcessSAMPCmd argv i}
-	    -save -
-	    -savefits {incr i; ProcessSaveCmd argv i}
+	    -savefits -
+	    -save {incr i; ProcessSaveCmd argv i}
 	    -saveimage {incr i; ProcessSaveImageCmd argv i}
-	    -movie -
-	    -savempeg {incr i; ProcessMovieCmd argv i}
 	    -scale -
 	    -ztrans {incr i; ProcessScaleCmd argv i}
 	    -scalelims -
@@ -354,21 +353,42 @@ proc ProcessCommand {argv argc} {
 		set scale(scope) [string tolower [lindex $argv $i]]
 		ChangeScaleScope
 	    }
+	    -sfits {
+		# backward compatibility
+		set file(type) sfits
+		CommandSFitsCmd argv i
+	    }
 	    -shm {incr i; ProcessShmCmd argv i 1}
 	    -single {ProcessSingleCmd argv i}
 	    -sinh {set scale(type) sinh; ChangeScale}
 	    -skyview {incr i; ProcessSkyViewCmd argv i}
 	    -sleep {incr i; ProcessSleepCmd argv i}
-	    -slice {set file(slice) 1}
-	    -noslice {set file(slice) 0}
+	    -slice {set file(mode) slice}
+	    -noslice {set file(mode) {}}
 	    -smooth {incr i; ProcessSmoothCmd argv i}
+	    -smosaic {
+		# backward compatibility
+		set file(type) smosaic
+		CommandMosaicCmd argv i
+	    }
+	    -smosaiciraf {
+		# backward compatibility
+		set file(type) smosaic
+		set file(mosaic) iraf
+	    }
+	    -smosaicwcs {
+		# backward compatibility
+		set file(type) smosaic
+		set file(mosaic) wcs
+	    }
 	    -squared {set scale(type) squared; ChangeScale}
 	    -sqrt {set scale(type) sqrt; ChangeScale}
 	    -source {incr i; ProcessSourceCmd argv i}
 	    -tcl {incr i; set pds9(tcl) [FromYesNo [lindex $argv $i]]}
 	    -theme {incr i; ProcessThemeCmd argv i}
-	    -threads -
-	    -thread {incr i; ProcessThreadsCmd argv i}
+	    -threads {incr i; ProcessThreadsCmd argv i}
+	    -tif -
+	    -tiff {set file(type) tiff}
 	    -tile {incr i; ProcessTileCmd argv i}
 	    -title {
 		#already processed
@@ -380,7 +400,7 @@ proc ProcessCommand {argv argc} {
 		set iis(ofifo) none
 		set iis(port) 0
 	    }
-	    -url {set file(mode) url}
+	    -url {set file(type) url}
 	    -update {incr i; ProcessUpdateCmd argv i}
 	    -vertgraph {
 		#backward compatibility
@@ -392,7 +412,6 @@ proc ProcessCommand {argv argc} {
 		set view(graph,vert) 0
 		UpdateView
 	    }
-	    -coords -
 	    -view {incr i; ProcessViewCmd argv i}
 	    -visual {
 		#already processed
@@ -438,17 +457,17 @@ proc ProcessCommand {argv argc} {
 
 		switch $ds9(wm) {
 		    x11 -
-		    aqua {CommandLineLoad $item file argv i}
+		    aqua {CommandLineLoad $item argv i}
 		    win32 {
 			# if win32 and envoked via DOS shell
 			# we must expand wildcards ourselves
 			if {[catch {glob $item} fns]} {
 			    # cygwin/double click/DOS Shell no wildcards
-			    CommandLineLoad $item file argv i
+			    CommandLineLoad $item argv i
 			} else {
 			    # DOS Shell with wildcards
 			    foreach fn $fns {
-				CommandLineLoad $fn file argv i
+				CommandLineLoad $fn argv i
 			    }
 			}
 		    }
@@ -465,287 +484,381 @@ proc ProcessCommand {argv argc} {
     }
 }
 
-proc CommandLineLoad {item filename argvname iname} {
-    upvar $filename file
+proc CommandLineLoad {item argvname iname} {
     upvar $argvname argv
     upvar $iname i
 
+    global file
     global current
 
     if {$current(frame) != {}} {
 	switch -- [$current(frame) get type] {
-	    base {CommandLineLoadBase $item $filename $argvname $iname}
-	    rgb {CommandLineLoadRGB $item $filename $argvname $iname}
-	    3d {CommandLineLoad3D $item $filename $argvname $iname}
+	    base {CommandLineLoadBase $item $argvname $iname}
+	    rgb {CommandLineLoadRGB $item $argvname $iname}
+	    3d {CommandLineLoad3D $item $argvname $iname}
 	}
     } else {
-	CommandLineLoadBase $item $filename $argvname $iname
+	CommandLineLoadBase $item $argvname $iname
     }
 
-    switch -- $file(mode) {
-	array {FileLast arrayfbox $item}
-	photo {FileLast photofbox $item}
-	url {}
-	default {FileLast fitsfbox $item}
-    }
+    SetFileLast $file(type) $item
 }
 
-proc CommandLineLoadBase {item filename argvname iname} {
-    upvar 2 $filename file
+proc CommandLineLoadBase {item argvname iname} {
     upvar 2 $argvname argv
     upvar 2 $iname i
 
+    global file
     global ds9
 
-    switch -- $file(mode) {
-	array {
-	    MultiLoad $file(layer)
-	    LoadArray $item $file(layer)
-	}
+    switch -- $file(type) {
 	fits {
-	    if {$file(slice)} {
-		LoadSliceFits $item
-	    } else {
-		# under windows, a double click on a 
-		# data file comes here
-		switch $ds9(wm) {
-		    x11 {}
-		    aqua {}
-		    win32 {
-			# normalize for "abc" but not "-abc", "-", and "-[foo]"
-			# otherwise, things get weird
-			if {![regexp -- {^-} $item]} {
-			    set item [file normalize [file nativename $item]]
-			}				
-		    }
+	    # under windows, a double click on a 
+	    # data file comes here
+	    switch $ds9(wm) {
+		x11 {}
+		aqua {}
+		win32 {
+		    # normalize for "abc" but not "-abc", "-", and "-[foo]"
+		    # otherwise, things get weird
+		    if {![regexp -- {^-} $item]} {
+			set item [file normalize [file nativename $item]]
+		    }				
 		}
-		MultiLoad $file(layer)
-		LoadFits $item $file(layer)
 	    }
+	    MultiLoad $file(layer) $file(mode)
+	    LoadFitsFile $item $file(layer) $file(mode)
 	}
-	sfits {
-	    MultiLoad $file(layer)
-	    incr i
-	    LoadSFits $item [lindex $argv $i] $file(layer)
+	url {
+	    MultiLoad $file(layer) $file(mode)
+	    LoadURLFits $item $file(layer) $file(mode)
 	}
+
+
+	rgbimage {
+	    CreateRGBFrame
+	    LoadRGBImageFile $item
+	}
+	rgbcube {
+	    CreateRGBFrame
+	    LoadRGBCubeFile $item
+	}
+
 	mecube {
 	    MultiLoad
-	    LoadMECubeFits $item
+	    LoadMECubeFile $item
 	}
 	multiframe {
 	    MultiLoad
-	    LoadMultiFrameFits $item
+	    LoadMultiFrameFile $item
 	}
+
 	mosaicimage {
 	    MultiLoad $file(layer)
 	    switch -- $file(mosaic) {
-		iraf {LoadMosaicImageIRAFFits $item $file(layer)}
-		wfpc2 {LoadMosaicImageWFPC2Fits $item}
-		default {LoadMosaicImageWCSFits $file(mosaic) \
-			     $item $file(layer)}
+		iraf {LoadMosaicImageIRAFFile $item $file(layer)}
+		wfpc2 {LoadMosaicImageWFPC2File $item}
+		default {LoadMosaicImageWCSFile $item $file(layer) $file(mosaic)}
 	    }
 	}
 	mosaic {
 	    switch -- $file(mosaic) {
-		iraf {LoadMosaicIRAFFits $item $file(layer)}
-		default {LoadMosaicWCSFits $file(mosaic) \
-			     $item $file(layer)}
-	    }
-	}
-	smosaic {
-	    incr i
-	    switch -- $file(mosaic) {
-		iraf {LoadMosaicIRAFSFits $item [lindex $argv $i] $file(layer)}
-		default {LoadMosaicWCSSFits $file(mosaic) \
-			     $item [lindex $argv $i] $file(layer)}
+		iraf {LoadMosaicIRAFFile $item $file(layer)}
+		default {LoadMosaicWCSFile $item $file(layer) $file(mosaic)}
 	    }
 	}
 
-	rgbcube {
-	    CreateRGBFrame
-	    LoadRGBCubeFits $item
+	sfits {
+	    #backward compatibility
+	    incr i
+	    MultiLoad $file(layer) $file(mode)
+	    LoadSFitsFile $item [lindex $argv $i] $file(layer) $file(mode)
 	}
 	srgbcube {
+	    #backward compatibility
 	    CreateRGBFrame
 	    incr i
-	    LoadRGBCubeSFits $item [lindex $argv $i]
+	    LoadSRGBCubeFile $item [lindex $argv $i]
 	}
-	rgbimage {
-	    CreateRGBFrame
-	    LoadRGBImageFits $item
+	smosaic {
+	    #backward compatibility
+	    incr i
+	    switch -- $file(mosaic) {
+		iraf {LoadSMosaicIRAFFile $item [lindex $argv $i] $file(layer)}
+		default {LoadSMosaicWCSFile $item [lindex $argv $i] $file(layer) $file(mosaic)}
+	    }
+	}
+
+	array {
+	    MultiLoad $file(layer)
+	    ImportArrayFile $item $file(layer)
 	}
 	rgbarray {
 	    CreateRGBFrame
-	    LoadRGBArray $item
+	    ImportRGBArrayFile $item
 	}
-
-	url {
+	nrrd {
 	    MultiLoad $file(layer)
-	    LoadURL $item
+	    ImportNRRDFile $item $file(layer)
 	}
-
-	photo {
-	    if {$file(slice)} {
-		LoadSlicePhoto $item
-	    } else {
-		MultiLoad
-		LoadPhoto $item
-	    }
+	gif -
+	tiff -
+	jpeg -
+	png {
+	    MultiLoad {} $file(mode)
+	    ImportPhotoFile $item $file(mode)
 	}
     }
 }
 
-proc CommandLineLoadRGB {item filename argvname iname} {
-    upvar 2 $filename file
+proc CommandLineLoadRGB {item argvname iname} {
     upvar 2 $argvname argv
     upvar 2 $iname i
 
-    switch -- $file(mode) {
-	array {LoadArray $item}
-	fits {LoadFits $item}
-	sfits {
-	    incr i
-	    LoadSFits $item [lindex $argv $i]
+    global file
+
+    switch -- $file(type) {
+	fits {LoadFitsFile $item {} $file(mode)}
+	url {LoadURLFits $item {} $file(mode)}
+
+	rgbimage {
+	    MultiLoadRGB
+	    LoadRGBImageFile $item
 	}
-	mecube {LoadMECubeFits $item}
+	rgbcube {
+	    MultiLoadRGB
+	    LoadRGBCubeFile $item
+	}
+
+	mecube {LoadMECubeFile $item}
 	multiframe {
 	    # not supported
 	}
+
 	mosaicimage {
 	    switch -- $file(mosaic) {
-		iraf {LoadMosaicImageIRAFFits $item}
-		wfpc2 {LoadMosaicImageWFPC2Fits $item}
-		default {LoadMosaicImageWCSFits $file(mosaic) $item}
+		iraf {LoadMosaicImageIRAFFile $item {}}
+		wfpc2 {LoadMosaicImageWFPC2File $item}
+		default {LoadMosaicImageWCSFile $item {} $file(mosaic)}
 	    }
 	}
 	mosaic {
 	    switch -- $file(mosaic) {
-		iraf {LoadMosaicIRAFFits $item}
-		default {LoadMosaicWCSFits $file(mosaic) $item}
-	    }
-	}
-	smosaic {
-	    incr i
-	    switch -- $file(mosaic) {
-		iraf {LoadMosaicIRAFSFits $item [lindex $argv $i]}
-		default {LoadMosaicWCSSFits $file(mosaic) \
-			     $item [lindex $argv $i]}
+		iraf {LoadMosaicIRAFFile $item {}}
+		default {LoadMosaicWCSFile $item {} $file(mosaic)}
 	    }
 	}
 
-	rgbcube {
-	    MultiLoadRGB
-	    LoadRGBCubeFits $item
+	sfits {
+	    #backward compatibility
+	    incr i
+	    LoadSFitsFile $item [lindex $argv $i] {} $file(mode)
 	}
 	srgbcube {
+	    #backward compatibility
 	    MultiLoadRGB
 	    incr i
-	    LoadRGBCubeSFits $item [lindex $argv $i]
+	    LoadSRGBCubeFile $item [lindex $argv $i]
 	}
-	rgbimage {
-	    MultiLoadRGB
-	    LoadRGBImageFits $item
+	smosaic {
+	    #backward compatibility
+	    incr i
+	    switch -- $file(mosaic) {
+		iraf {LoadMosaicIRAFSFitsFile $item [lindex $argv $i] {}}
+		default {LoadMosaicWCSSFitsFile $item [lindex $argv $i] {} $file(mosaic)}
+	    }
 	}
+
+	array {ImportArrayFile $item {}}
 	rgbarray {
 	    MultiLoadRGB
-	    LoadRGBArray $item
+	    ImportRGBArrayFile $item
 	}
-
-	url {LoadURL $item}
-
-	photo {
+	nrrd {ImportNRRDFile $item {}}
+	gif -
+	tiff -
+	jpeg -
+	png {
 	    MultiLoadRGB
-	    LoadPhoto $item
+	    ImportPhotoFile $item $file(mode)
 	}
+
     }
 }
 
-proc CommandLineLoad3D {item filename argvname iname} {
-    upvar 2 $filename file
+proc CommandLineLoad3D {item argvname iname} {
     upvar 2 $argvname argv
     upvar 2 $iname i
 
-    switch -- $file(mode) {
+    global file
+
+    switch -- $file(type) {
+	fits {
+	    MultiLoad {} $file(mode)
+	    LoadFitsFile $item {} $file(mode)
+	}
+	url {
+	    MultiLoad {} $file(mode)
+	    LoadURLFits $item {} $file(mode)
+	}
+
+	rgbimage {
+	    CreateRGBFrame
+	    LoadRGBImageFile $item
+	}
+	rgbcube {
+	    CreateRGBFrame
+	    LoadRGBCubeFile $item
+	}
+
+	mecube {
+	    MultiLoad
+	    LoadMECubeFile $item
+	}
+	multiframe {
+	    MultiLoad
+	    LoadMultiFrameFile $item
+	}
+
+	mosaicimage {
+	    MultiLoad
+	    switch -- $file(mosaic) {
+		iraf {LoadMosaicImageIRAFFile $item {}}
+		wfpc2 {LoadMosaicImageWFPC2File $item}
+		default {LoadMosaicImageWCSFile $item {} $file(mosaic)}
+	    }
+	}
+	mosaic {
+	    switch -- $file(mosaic) {
+		iraf {LoadMosaicIRAFFile $item {}}
+		default {LoadMosaicWCSFile $item {} $file(mosaic)}
+	    }
+	}
+
+	sfits {
+	    #backward compatibility
+	    incr i
+	    MultiLoad {} $file(mode)
+	    LoadSFitsFile $item [lindex $argv $i] {} $file(mode)
+	}
+	srgbcube {
+	    #backward compatibility
+	    CreateRGBFrame
+	    incr i
+	    LoadSRGBCubeFile $item [lindex $argv $i]
+	}
+	smosaic {
+	    #backward compatibility
+	    incr i
+	    switch -- $file(mosaic) {
+		iraf {LoadMosaicIRAFSFitsFile $item [lindex $argv $i] {}}
+		default {LoadMosaicWCSSFitsFile $item [lindex $argv $i] {} $file(mosaic)}
+	    }
+	}
+
 	array {
 	    MultiLoad
-	    LoadArray $item
-	}
-	fits {
-	    if {$file(slice)} {
-		LoadSliceFits $item
-	    } else {
-		MultiLoad
-		LoadFits $item
-	    }
-	}
-	sfits {
-	    MultiLoad
-	    incr i
-	    LoadSFits $item [lindex $argv $i]
-	}
-	mecube {
-	    MultiLoad
-	    LoadMECubeFits $item
-	}
-	multiframe {
-	    MultiLoad
-	    LoadMultiFrameFits $item
-	}
-	mosaicimage {
-	    MultiLoad
-	    switch -- $file(mosaic) {
-		iraf {LoadMosaicImageIRAFFits $item}
-		wfpc2 {LoadMosaicImageWFPC2Fits $item}
-		default {LoadMosaicImageWCSFits $file(mosaic) $item}
-	    }
-	}
-	mosaic {
-	    switch -- $file(mosaic) {
-		iraf {LoadMosaicIRAFFits $item}
-		default {LoadMosaicWCSFits $file(mosaic) $item}
-	    }
-	}
-	smosaic {
-	    incr i
-	    switch -- $file(mosaic) {
-		iraf {LoadMosaicIRAFSFits $item [lindex $argv $i]}
-		default {LoadMosaicWCSSFits $file(mosaic) $item \
-			     [lindex $argv $i]}
-	    }
-	}
-
-	rgbcube {
-	    # not supported
-	}
-	srgbcube {
-	    # not supported
-	}
-	rgbimage {
-	    # not supported
+	    ImportArrayFile $item {}
 	}
 	rgbarray {
-	    # not supported
+	    CreateRGBFrame
+	    ImportRGBArrayFile $item
 	}
-
-	url {
+	nrrd {
 	    MultiLoad
-	    LoadURL $item
+	    ImportNRRDFile $item {}
 	}
-
-	photo {
-	    if {$file(slice)} {
-		LoadSlicePhoto $item
-	    } else {
-		MultiLoad
-		LoadPhoto $item
-	    }
+	gif -
+	tiff -
+	jpeg -
+	png {
+	    MultiLoad {} $file(mode)
+	    ImportPhotoFile $item $file(mode)
 	}
     }
 }
 
-proc CommandMosaicType {sys filename iname} {
+proc CommandFitsCmd {varname iname} {
+    upvar $varname var
     upvar $iname i
-    upvar $filename file
+
+    global file
+
+    set item [string tolower [lindex $var [expr $i+1]]]
+    switch -- $item {
+	mosaicimage -
+	mosaic {
+	    set file(type) $item
+	    incr i
+
+	    set item [string tolower [lindex $var [expr $i+1]]]
+	    switch -- $item {
+		wfpc2 {incr i; set file(mosaic) wfpc2}
+		default {CommandMosaicType $item $iname}
+	    }
+	}
+	mecube -
+	multiframe -
+	rgbcube -
+	rgbimage {
+	    set file(type) $item
+	    incr i
+	}
+    }
+}
+
+proc CommandSFitsCmd {varname iname} {
+    upvar $varname var
+    upvar $iname i
+
+    global file
+
+    set item [string tolower [lindex $var [expr $i+1]]]
+    switch -- $item {
+	mosaic {
+	    set file(type) smosaic
+	    incr i
+
+	    set item [string tolower [lindex $var [expr $i+1]]]
+	    switch -- $item {
+		wfpc2 {incr i; set file(mosaic) wfpc2}
+		default {CommandMosaicType $item $iname}
+	    }
+	}
+	rgbcube {
+	    set file(type) srgbcube
+	    incr i
+	}
+    }
+}
+
+proc CommandMosaicImageCmd {varname iname} {
+    upvar $varname var
+    upvar $iname i
+
+    global file
+
+    set item [string tolower [lindex $var [expr $i+1]]]
+    switch -- $item {
+	wfpc2 {incr i; set file(mosaic) wfpc2}
+	default {CommandMosaicType $item $iname}
+    }
+}
+
+proc CommandMosaicCmd {varname iname} {
+    upvar $varname var
+    upvar $iname i
+
+    global file
+
+    set item [string tolower [lindex $var [expr $i+1]]]
+    CommandMosaicType $item $iname
+}
+
+proc CommandMosaicType {sys iname} {
+    upvar 2 $iname i
+
+    global file
 
     switch $sys {
 	iraf -
@@ -777,8 +890,8 @@ proc CommandMosaicType {sys filename iname} {
 	wcsy -
 	wcsz {
 	    incr i
-	    set ${filename}(mosaic) $sys
+	    set file(mosaic) $sys
 	}
-	default {set ${filename}(mosaic) wcs}
+	default {set file(mosaic) wcs}
     }
 }
