@@ -345,11 +345,13 @@ proc ContourCutDialog {} {
     global icontour
     global dcontour
 
-    set w [focus -displayof $icontour(top)]
-    if {$w == $dcontour(txt)} {
-	tk_textCut $w
-    } else {
-	EntryCut icontour
+    if {[winfo exists $icontour(top)]} {
+	set w [focus -displayof $icontour(top)]
+	if {$w == $dcontour(txt)} {
+	    tk_textCut $w
+	} else {
+	    EntryCut $icontour(top)
+	}
     }
 }
 
@@ -357,11 +359,13 @@ proc ContourCopyDialog {} {
     global icontour
     global dcontour
 
-    set w [focus -displayof $icontour(top)]
-    if {$w == $dcontour(txt)} {
-	tk_textCopy $w
-    } else {
-	EntryCopy icontour
+    if {[winfo exists $icontour(top)]} {
+	set w [focus -displayof $icontour(top)]
+	if {$w == $dcontour(txt)} {
+	    tk_textCopy $w
+	} else {
+	    EntryCopy $icontour(top)
+	}
     }
 }
 
@@ -369,11 +373,13 @@ proc ContourPasteDialog {} {
     global icontour
     global dcontour
 
-    set w [focus -displayof $icontour(top)]
-    if {$w == $dcontour(txt)} {
-	tk_textPaste $w
-    } else {
-	EntryPaste icontour
+    if {[winfo exists $icontour(top)]} {
+	set w [focus -displayof $icontour(top)]
+	if {$w == $dcontour(txt)} {
+	    tk_textPaste $w
+	} else {
+	    EntryPaste $icontour(top)
+	}
     }
 }
 
@@ -599,15 +605,13 @@ proc UpdateContourDialog {} {
 proc ContourLogDialog {} {
     global contour
 
-    EntryDialog [msgcat::mc {Scale}] [msgcat::mc {Log Exponent}] \
-	10 contour(log) {}
+    EntryDialog [msgcat::mc {Scale}] [msgcat::mc {Log Exponent}] 10 contour(log)
 }
 
 proc ContourParamsDialog {action fn} {
     global ds9
     global current
     global contour
-    global icontour
     global ed
     global wcs
 
@@ -1084,10 +1088,12 @@ proc ProcessContourFix {sysname skyname colorname widthname dashname} {
 	magenta -
 	yellow {}
 	default {
-	    set dash $width
-	    set width $color
-	    set color green
-	    incr rr -1
+	    if {[string range $color 0 0] != "#"} {
+		set dash $width
+		set width $color
+		set color green
+		incr rr -1
+	    }
 	}
     }
 
