@@ -7,7 +7,7 @@ proc DS9Def {} {
     global pds9
 
     set ds9(title) "$ds9(app)"
-    set ds9(version) {7.1}
+    set ds9(version) {7.2}
 
     set ds9(top) .
     set ds9(mb) .mb
@@ -65,7 +65,7 @@ proc DS9Def {} {
     }
     set ds9(menu,size,frame,goto) [expr $ds9(menu,start)+0]
     set ds9(menu,size,frame,active) [expr $ds9(menu,start)+3]
-    set ds9(menu,size,analysis) [expr $ds9(menu,start)+28]
+    set ds9(menu,size,analysis) [expr $ds9(menu,start)+31]
     set ds9(menu,size,wrap) 20
 
     set ds9(display) single
@@ -110,8 +110,6 @@ proc DS9Def {} {
 
     set ds9(prefs) 0
 
-    set ds9(fileProcs) {Stdin ExternalFits GzipFits BZip2Fits CompressFits PackFits FTZFits}
-
     switch $ds9(wm) {
 	x11 {
 	    set ds9(ctrl) "Control-"
@@ -151,6 +149,7 @@ proc DS9Def {} {
 	win32 {set pds9(dialog) native}
 	aqua {set pds9(dialog) native}
     }
+    set pds9(dialog,center) 0
     set pds9(dialog,all) 0
     set pds9(language) locale
     set pds9(language,name) [LanguageToName $pds9(language)]
@@ -276,7 +275,7 @@ PSDef
 RGBDef
 SAMPDef
 SAODef
-SaveFitsDef
+SaveDef
 SaveImageDef
 ScaleDef
 SkyViewDef
