@@ -43,7 +43,6 @@ proc HV {varname title url {init {}} {sync 0}} {
 	set var(status) {}
 	set var(sync) $sync
 	set var(frame) new
-	set var(file,mode) { }
 	set var(save) 0
 	set var(title) "$title"
 	set var(copy) {}
@@ -76,7 +75,6 @@ proc HV {varname title url {init {}} {sync 0}} {
 	$mb add cascade -label [msgcat::mc {Edit}] -menu $mb.edit
 	$mb add cascade -label [msgcat::mc {View}] -menu $mb.view
 	$mb add cascade -label [msgcat::mc {Frame}] -menu $mb.frame
-	$mb add cascade -label [msgcat::mc {Open Fits As}] -menu $mb.open
 
 	menu $mb.file
 	$mb.file add command -label [msgcat::mc {Open URL}] \
@@ -128,7 +126,7 @@ proc HV {varname title url {init {}} {sync 0}} {
 
 	menu $mb.frame 
 	$mb.frame add checkbutton \
-	    -label [msgcat::mc {Save FITS on download}] \
+	    -label [msgcat::mc {Save Image on Download}] \
 	    -variable ${varname}(save)
 	$mb.frame add separator
 	$mb.frame add radiobutton \
@@ -138,31 +136,6 @@ proc HV {varname title url {init {}} {sync 0}} {
 	    -label [msgcat::mc {Use Current Frame on Download}] \
 	    -variable ${varname}(frame) -value current
 
-	menu $mb.open
-	$mb.open add radiobutton -label {Fits} \
-	    -variable ${varname}(file,mode) -value { }
-	$mb.open add separator
-	$mb.open add radiobutton -labe {RGB Fits Image} \
-	    -variable ${varname}(file,mode) -value {rbg image}
-	$mb.open add radiobutton -labe {RGB Fits Cube} \
-	    -variable ${varname}(file,mode) -value {rbg cube}
-	$mb.open add separator
-	$mb.open add radiobutton -labe {Multi Ext Cube} \
-	    -variable ${varname}(file,mode) -value {ext cube}
-	$mb.open add separator
-	$mb.open add radiobutton -label {Mosaic IRAF} \
-	    -variable ${varname}(file,mode) -value {mosaic image iraf}
-	$mb.open add radiobutton -label {Mosaic IRAF Segment} \
-	    -variable ${varname}(file,mode) -value {mosaic iraf}
-	$mb.open add separator
-	$mb.open add radiobutton -label {Mosaic WCS} \
-	    -variable ${varname}(file,mode) -value {mosaic image wcs}
-	$mb.open add radiobutton -label {Mosaic WCS Segment} \
-	    -variable ${varname}(file,mode) -value {mosaic wcs}
-	$mb.open add separator
-	$mb.open add radiobutton -label {Mosaic Image WFPC2} \
-	    -variable ${varname}(file,mode) -value {mosaic image wfpc2}
-
 	image create photo $var(images,back) -data {R0lGODlhDwANAKL/AM///8DAwJD//y/I/y+X/y9n/wAAAAAAACH5BAEAAAEALAAAAAAPAA0AAAM0GLq2/qE0+AqYVFmB6eZFKEoRIAyCaaYCYWxDLM9uYBAxoe/7dA8ug3AoZOg6mRsyuUxmEgA7}
 	image create photo $var(images,forward) -data {R0lGODlhDwANAKL/AM///8DAwJD//y/I/y+X/y9n/wAAAAAAACH5BAEAAAEALAAAAAAPAA0AAAM3GLpa/K8YSMuYlBVwV/kgCAhdsAFoig7ktA1wLA9SQdw4DkuB4f8/Ag2TMRB4GYUBmewRm09FAgA7}
 	image create photo $var(images,stop) -data {R0lGODlhDQANALP/AP///1Lq81I5Of+EhCEAAHsAAMYAAP+UQv9zCHuMjP8AMf8AKf+MnK1CSv8QIQAAACH5BAEAAAEALAAAAAANAA0AAARWMMjUTC1J6ubOQYdiCBuIIMuiiCT1OWu6Ys05AMPC4ItBGB8dYMdI+RoHR4qY6v1CwlvRcEQ4brndwFAgJAwIRdPIzVTEYiqXJBEU1FQCW5Mg2O0ZSQQAOw==}
@@ -410,7 +383,7 @@ proc HVURLDialogCmd {varname} {
     global debug
 
     set url "$var(url)"
-    if {[EntryDialog [msgcat::mc {URL}] [msgcat::mc {Enter World Wide Web Location (URL)}] 80 url {}]} {
+    if {[EntryDialog [msgcat::mc {URL}] [msgcat::mc {Enter URL}] 80 url]} {
 	if {[string length $url] == 0} {
 	    return
 	}
@@ -560,7 +533,7 @@ proc HVFindCmd {varname} {
     global $varname
 
     set result "$var(search)"
-    if {[EntryDialog [msgcat::mc {Search}] [msgcat::mc {Enter Search Expression}] 40 result {}]} {
+    if {[EntryDialog [msgcat::mc {Search}] [msgcat::mc {Enter Search Expression}] 40 result]} {
 	set var(search) "$result"
 	set var(search,start) 0
 	$var(widget) selection clear
