@@ -711,7 +711,6 @@ proc HVLoadFile {varname path} {
 	.tiff -
 	.tif {set var(mime) "image/tiff"}
 	.png {set var(mime) "image/png"}
-	.ppm {set var(mime) "image/ppm"}
 
 	.fits -
 	.fit -
@@ -968,7 +967,6 @@ proc HVParseSingle {varname} {
 		.tiff -
 		.tif {set var(mime) "image/tiff"}
 		.png {set var(mime) "image/png"}
-		.ppm {set var(mime) "image/ppm"}
 
 		.fits -
 		.fit -
@@ -1000,10 +998,7 @@ proc HVParseSingle {varname} {
 	"image/gif" -
 	"image/jpeg" -
 	"image/tiff" -
-	"image/png" -
-	"image/ppm" -
-	"image/x-portable-pixmap" -
-	"image/x-xbitmap" {HVParseImg $varname}
+	"image/png" {HVParseImg $varname}
 
 	"image/fits" -
 	"application/fits" {HVParseFITS $varname}
@@ -1260,7 +1255,28 @@ proc HVParseImg {varname} {
 	puts stderr "HVParseImg $var(url)"
     }
 
-    LoadPhoto $var(fn)
+    if {$var(save)} {
+	switch -- $var(mime) {
+	    "image/gif" {set fn [SaveFileDialog giffbox]}
+	    "image/jpeg" {set fn [SaveFileDialog jpegfbox]}
+	    "image/tiff" {set fn [SaveFileDialog tifffbox]}
+	    "image/png" {set fn [SaveFileDialog pngfbox]}
+	}
+	
+	if {[string length "$fn"] != 0} {
+	    if {![catch {file rename -force "$var(fn)" "$fn"}]} {
+		set var(fn) "$fn"
+		set var(delete) 0
+	    }
+	}
+    }
+
+    switch -- $var(frame) {
+	new {MultiLoadBase}
+	current {}
+    }
+
+    ImportPhotoFile $var(fn) {}
 
     HVClearTmpFile $varname
     HVClearAll $varname
@@ -1274,7 +1290,7 @@ proc HVParseFITS {varname} {
     global ds9
     global debug
 
-    if {$var(delete) && $var(save)} {
+    if {$var(save)} {
 	switch -- $var(encoding) {
 	    gzip {FileLast savefitsfbox "ds9.fits.gz"}
 	    bzip2 {FileLast savefitsfbox "ds9.fits.bz2"}
@@ -1302,7 +1318,7 @@ proc HVParseFITS {varname} {
     set loadParam(load,type) allocgz
     set loadParam(load,layer) {}
     set loadParam(file,type) fits
-    set loadParam(file,mode) "$var(file,mode)"
+    set loadParam(file,mode) {}
     set loadParam(file,name) "$var(fn)"
     set loadParam(file,fn) $loadParam(file,name)
 
