@@ -381,6 +381,32 @@ proc EnterInfoBox {which x y sys} {
     }
 }
 
+proc EnterInfoBoxFrame {which} {
+    global infobox
+    global ds9
+
+    global debug
+    if {$debug(tcl,events)} {
+	puts stderr "EnterInfoBoxFrame $which"
+    }
+
+    UpdateFrameInfoBox [$which get type]
+    UpdateWCSInfoBox $which
+    ClearInfoBoxCoords
+
+    set infobox(frame) "[msgcat::mc {Frame}] [string range $which 5 end]"
+    set infobox(angle) [$which get rotate fixed]
+
+    set z [$which get zoom fixed]
+    set z1 [lindex $z 0]
+    set z2 [lindex $z 1]
+    if {$z1 != $z2} {
+	set infobox(zoom) "$z1  $z2"
+    } else {
+	set infobox(zoom) $z1
+    }
+}
+
 proc LeaveInfoBox {} {
     global ds9
     global current
@@ -464,14 +490,14 @@ proc RefreshInfoBox {which} {
 
     if {$which != {}} {
 	switch -- $current(mode) {
-	    none -
-	    pointer {}
 	    crosshair {
 		set coord [$which get crosshair canvas]
 		set x [lindex $coord 0]
 		set y [lindex $coord 1]
 		EnterInfoBox $which $x $y canvas
 	    }
+	    none -
+	    pointer -
 	    catalog -
 	    colorbar -
 	    pan -
@@ -479,7 +505,7 @@ proc RefreshInfoBox {which} {
 	    rotate -
 	    crop -
 	    examine -
-	    imexam {EnterInfoBox $which $ds9(x) $ds9(y) canvas}
+	    imexam {EnterInfoBoxFrame $which}
 	}
     }
     return
