@@ -4,219 +4,7 @@
 
 package provide DS9 1.0
 
-proc OpenURL {} {
-    global http
-
-    set fn {}
-    if {[EntryDialog [msgcat::mc {URL}] [msgcat::mc {Enter World Wide Web Location (URL)}] 80 fn {}]} {
-	StartLoad
-	LoadURL $fn
-	FinishLoad
-    }
-}
-
-proc LoadURL {url} {
-    if {[string length $url] == 0} {
-	return
-    }
-
-    ParseURL $url r
-    switch -- $r(scheme) {
-	ftp {LoadURLFTP $r(authority) $r(path)}
-	file {LoadURLFile $r(path)}
-	http -
-	default {LoadURLHTTP $url}
-    }
-}
-
-proc LoadURLFTP {host path} {
-    global loadParam
-    global ds9
-    global debug
-
-    set ftp [ftp::Open $host "ftp" "-ds9@" -mode passive]
-    if {$ftp > -1} {
-	set fn "$ds9(tmpdir)/[file tail $path]"
-	set ftp::VERBOSE $debug(tcl,ftp)
-	set "ftp::ftp${ftp}(Output)" FTPLog
-	ftp::Type $ftp binary
-	if [ftp::Get $ftp $path $fn] {
-	    # alloc it because we are going to delete it after load
-	    set loadParam(load,type) allocgz
-	    set loadParam(load,layer) {}
-	    set loadParam(file,type) fits
-	    set loadParam(file,mode) {}
-	    set loadParam(file,name) $fn
-	    set loadParam(file,fn) $fn
-	    ConvertFile
-	    ProcessLoad
-	}
-
-	ftp::Close $ftp
-
-	if [file exists $fn] {
-	    catch {file delete -force $fn}
-	}
-    }
-}
-
-proc LoadURLFile {path} {
-    global loadParam
-    global ds9
-
-    # alloc it because we can't assume it will last
-    set loadParam(load,type) allocgz
-    set loadParam(load,layer) {}
-    set loadParam(file,type) fits
-    set loadParam(file,mode) {}
-    set loadParam(file,name) $path
-    set loadParam(file,fn) $path
-    ConvertFile
-    ProcessLoad
-}
-
-proc LoadURLHTTP {url} {
-    global ds9
-    global ihttp
-
-    ParseURL $url r
-    set fn "$ds9(tmpdir)/[file tail $r(path)]"
-
-    set code 200
-    set meta {}
-    set mime "application/fits"
-    set encoding {}
-
-    set ch [open $fn w]
-    set token [http::geturl $url \
-		   -protocol 1.0 \
-		   -timeout $ihttp(timeout) \
-		   -channel $ch \
-		   -binary 1 \
-		   -headers "[ProxyHTTP]"]
-
-    # reset errorInfo (may be set in http::geturl)
-    global errorInfo
-    set errorInfo {}
-
-    catch {close $ch}
-
-    upvar #0 $token t
-
-    # Code
-    set code [http::ncode $token]
-
-    # Meta
-    set meta $t(meta)
-
-    # Mime-type
-    # we want to strip and extra info after ';'
-    regexp -nocase {([^;])*} $t(type) mime
-
-    # Content-Encoding
-    foreach {name value} $meta {
-	if {[regexp -nocase ^content-encoding $name]} {
-	    switch -- [string tolower $value] {
-		gzip -
-		x-gzip {set encoding gzip}
-		compress -
-		bzip2 {set encoding bzip2}
-		Z {set encoding compress}
-		pack -
-		z {set encoding pack}
-		default {}
-	    }
-	}
-    }
-
-    HTTPLog $token
-    # Result?
-    switch -- $code {
-	200 {}
-	default {
-	    Error "HTTP [msgcat::mc {Error}] $code"
-	    return
-	}
-    }
-
-    http::cleanup $token
-
-    global debug
-    if {$debug(tcl,hv)} {
-	puts stderr "Load HTTP: fn $fn : code $code : meta $meta : mime $mime : encoding $encoding"
-    }
-
-    # NOTE: error notices may come as text/html
-    switch -- [string tolower $mime] {
-	"image/fits" -
-	"application/fits" {}
-
-	"application/fits-image" -
-	"application/fits-table" -
-	"application/fits-group" {}
-
-	"image/x-fits" -
-	"binary/x-fits" -
-	"application/x-fits" {}
-
-	"image/x-gfits" -
-	"binary/x-gfits" -
-	"image/gz-fits" -
-	"display/gz-fits" {set encoding gzip}
-
-	"image/bz2-fits" -
-	"display/bz2-fits" {set encoding bzip2}
-
-	"image/x-cfits" -
-	"binary/x-cfits" {set encoding compress}
-
-	"image/x-zfits" -
-	"binary/x-zfits" {set encoding pack}
-
-	default {
-	    Error "[msgcat::mc {File not Found or Unable to load FITS data MIME type}] $mime"
-	    return
-	}
-    }
-
-    # alloc it because we are going to delete it after load
-    StartLoad
-    global loadParam
-    set loadParam(load,type) allocgz
-    set loadParam(load,layer) {}
-    set loadParam(file,type) fits
-    set loadParam(file,mode) {}
-    set loadParam(file,name) $fn
-    set loadParam(file,fn) $fn
-
-    # may have to convert the file, based on content-encoding
-    switch -- "$encoding" {
-	bzip2 {
-	    catch {set ch [open "| bunzip2 < $fn " r]}
-	    set loadParam(load,type) channel
-	    set loadParam(channel,name) $ch
-	}
-	compress {
-	    catch {set ch [open "| uncompress < $fn " r]}
-	    set loadParam(load,type) channel
-	    set loadParam(channel,name) $ch
-	}
-	pack {
-	    catch {set ch [open "| pcat $fn " r]}
-	    set loadParam(load,type) channel
-	    set loadParam(channel,name) $ch
-	}
-    }
-
-    ProcessLoad
-    FinishLoad
-
-    if {[file exists $fn]} {
-	catch {file delete -force $fn}
-    }
-}
-
-proc MultiLoad {{layer {}}} {
+proc MultiLoad {{layer {}} {mode {}}} {
     global ds9
     global current
 
@@ -225,7 +13,7 @@ proc MultiLoad {{layer {}}} {
 	puts stderr "MultiLoad"
     }
 
-    if {$layer != {}} {
+    if {$layer != {} || $mode != {}} {
 	return
     }
 
@@ -234,9 +22,9 @@ proc MultiLoad {{layer {}}} {
 	    return
 	}
 	switch -- [$current(frame) get type] {
-	    base {CreateFrame}
+	    base -
+	    3d {CreateFrame}
 	    rgb {}
-	    3d {Create3DFrame}
 	}
     } else {
 	CreateFrame
@@ -381,6 +169,7 @@ proc ProcessLoad {{err 1}} {
 	if {$err} {
 	    Error "[msgcat::mc {Unable to load}] $loadParam(file,type) $loadParam(file,mode) $loadParam(file,name)"
 	}
+	return 0
     }
 
     # save loadParam
@@ -402,7 +191,7 @@ proc ProcessLoad {{err 1}} {
     }
 
     unset loadParam
-    return $rr
+    return 1
 }
 
 proc ProcessLoadSaveParams {varname} {
@@ -475,11 +264,40 @@ proc FinishLoad {} {
     FinishLoadPost
 }
 
-proc ConvertFile {} {
-    global ds9
+proc IsLocalFile {fn} {
+    # strip any brackets
+    set aa [string first "\[" $fn]
+    if {$aa > 0} {
+ 	set fn [string range $fn 0 [expr $aa-1]]
+    }
+    
+    if {![file exists $fn]} {
+	return 0
+    }
+    if {![file isfile $fn]} {
+	return 0
+    }
+    if {[file isdirectory $fn]} {
+	return 0
+    }
+    if {[file readable $fn]} {
+	return 1
+    } else {
+	return 0
+    }
+}
 
-    foreach t $ds9(fileProcs) {
-	if [$t] {
+proc ConvertFitsFile {} {
+    foreach t {Stdin ExternalFits GzipFile BZip2File CompressFile PackFile} {
+	if {[$t]} {
+	    return
+	}
+    }
+}
+
+proc ConvertArrayFile {} {
+    foreach t {Stdin GzipFile BZip2File CompressFile PackFile} {
+	if {[$t]} {
 	    return
 	}
     }
@@ -503,11 +321,10 @@ proc Stdin {} {
 	set loadParam(file,fn) $loadParam(file,name)
 	return 1
     }
-
     return 0
 }
 
-proc BZip2Fits {} {
+proc BZip2File {} {
     global loadParam
 
     if { [regexp {(.*)\.bz2($|\[)} $loadParam(file,name) matched root] } {
@@ -518,11 +335,10 @@ proc BZip2Fits {} {
 	set loadParam(channel,name) $ch
 	return 1
     }
-
     return 0
 }
 
-proc CompressFits {} {
+proc CompressFile {} {
     global loadParam
 
     if { [regexp {(.*)\.Z($|\[)} $loadParam(file,name) matched root] } {
@@ -533,11 +349,10 @@ proc CompressFits {} {
 	set loadParam(channel,name) $ch
 	return 1
     }
-
     return 0
 }
 
-proc PackFits {} {
+proc PackFile {} {
     global loadParam
 
     if { [regexp {(.*)\.z($|\[)} $loadParam(file,name) matched root] } {
@@ -548,31 +363,30 @@ proc PackFits {} {
 	set loadParam(channel,name) $ch
 	return 1
     }
-
     return 0
 }
 
-proc GzipFits {} {
+proc GzipFile {} {
     global loadParam
 
-    if { [regexp {(.*)\.gz($|\[)} $loadParam(file,name) matched root] } {
-	set loadParam(load,type) allocgz
-	set loadParam(file,fn) $loadParam(file,name)
-	return 1
+    set fn $loadParam(file,name)
+    set id [string first "\[" $fn]
+    if {$id > 0} {
+	set fn [string range $fn 0 [expr $id-1]]
     }
 
-    return 0
-}
-
-proc FTZFits {} {
-    global loadParam
-
-    if { [regexp -nocase {(.*)\.(ftz)($|\[)} $loadParam(file,name) matched root ext] } {
-	set loadParam(load,type) allocgz
-	set loadParam(file,fn) $loadParam(file,name)
-	return 1
+    catch {
+	set ch [open $fn r]
+	fconfigure $ch -encoding binary -translation binary
+	set bb [read $ch 2]
+	close $ch
+	binary scan $bb H4 cc
+	if {$cc == {1f8b}} {
+	    set loadParam(load,type) allocgz
+	    set loadParam(file,fn) $loadParam(file,name)
+	    return 1
+	}
     }
-
     return 0
 }
 
