@@ -42,15 +42,19 @@ proc AnalysisMainMenu {} {
     $ds9(mb).analysis add cascade -label [msgcat::mc {Catalogs}] \
 	-menu $ds9(mb).analysis.cat
     $ds9(mb).analysis add separator
-    $ds9(mb).analysis add command \
-	-label "[msgcat::mc {Virtual Observatory}]..."\
+    $ds9(mb).analysis add command -label "[msgcat::mc {Catalog Tool}]..." \
+	-command CATTool
+    $ds9(mb).analysis add command -label "[msgcat::mc {Line Plot Tool}]..." \
+	-command PlotLineTool
+    $ds9(mb).analysis add command -label "[msgcat::mc {Bar Plot Tool}]..." \
+	-command PlotBarTool
+    $ds9(mb).analysis add command -label "[msgcat::mc {Scatter Plot Tool}]..." \
+	-command PlotScatterTool
+    $ds9(mb).analysis add separator
+    $ds9(mb).analysis add command -label "[msgcat::mc {Virtual Observatory}]..."\
 	-command VODialog
-    $ds9(mb).analysis add command -label "[msgcat::mc {Plot Tool}]..." \
-	-command AnalysisPlotTool
     $ds9(mb).analysis add command -label "[msgcat::mc {Web Browser}]..." \
 	-command {HV web Web {}}
-    $ds9(mb).analysis add command -label "[msgcat::mc {Catalog Tool}]..." \
-	-command CATOther
     $ds9(mb).analysis add separator
     $ds9(mb).analysis add checkbutton \
 	-label [msgcat::mc {Analysis Command Log}] \
@@ -84,7 +88,9 @@ proc AnalysisMainMenu {} {
 	-label [msgcat::mc {Search for Catalogs}] \
 	-command "CATCDSSrchDialog catcdssrch1"
     $ds9(mb).analysis.cat add command -label [msgcat::mc {Clear All}] \
-	-command CATClearCurrentFrame
+	-command CATClearFrame
+    $ds9(mb).analysis.cat add command -label [msgcat::mc {Match}] \
+	-command CATMatchFrame
     $ds9(mb).analysis.cat add separator
     CATCatalogMenu
 
@@ -415,24 +421,22 @@ proc PrefsDialogPlot {} {
     # Grid
     set f [ttk::labelframe $w.plot.grid -text [msgcat::mc {Grid}]]
 
-    ttk::checkbutton $f.show -text [msgcat::mc {Show}] \
-	-variable pap(grid)
-    ttk::radiobutton $f.linearlinear \
-	-text "[msgcat::mc {Linear}]-[msgcat::mc {Linear}]" \
-	-variable pap(grid,log) -value linearlinear
-    ttk::radiobutton $f.linearlog \
-	-text "[msgcat::mc {Linear}]-[msgcat::mc {Log}]" \
-	-variable pap(grid,log) -value linearlog
-    ttk::radiobutton $f.loglinear \
-	-text "[msgcat::mc {Log}]-[msgcat::mc {Linear}]" \
-	-variable pap(grid,log) -value loglinear
-    ttk::radiobutton $f.loglog \
-	-text "[msgcat::mc {Log}]-[msgcat::mc {Log}]" \
-	-variable pap(grid,log) -value loglog
+    ttk::checkbutton $f.x -text [msgcat::mc {X Axis}] \
+	-variable pap(grid,x)
+    ttk::radiobutton $f.xlinear -text [msgcat::mc {Linear}] \
+	-variable pap(grid,xlog) -value 0
+    ttk::radiobutton $f.xlog -text [msgcat::mc {Log}] \
+	-variable pap(grid,xlog) -value 1
 
-    grid $f.show -padx 2 -pady 2 -sticky w
-    grid $f.linearlinear $f.linearlog $f.loglinear $f.loglog \
-	-padx 2 -pady 2 -sticky w
+    ttk::checkbutton $f.y -text [msgcat::mc {Y Axis}] \
+	-variable pap(grid,y)
+    ttk::radiobutton $f.ylinear -text [msgcat::mc {Linear}] \
+	-variable pap(grid,ylog) -value 0
+    ttk::radiobutton $f.ylog -text [msgcat::mc {Log}] \
+	-variable pap(grid,ylog) -value 1
+
+    grid $f.x $f.xlinear $f.xlog -padx 2 -pady 2 -sticky w
+    grid $f.y $f.ylinear $f.ylog -padx 2 -pady 2 -sticky w
 
     # Font
     set f [ttk::labelframe $w.plot.font -text [msgcat::mc {Font}]]
@@ -463,10 +467,14 @@ proc PrefsDialogPlot {} {
     ttk::menubutton $f.symbol -textvariable pap(discrete,symbol) \
 	-menu $f.symbol.menu
 
-    grid $f.show -padx 2 -pady 2 -sticky w
-    grid $f.ctitle $f.color $f.stitle $f.symbol -padx 2 -pady 2 -sticky w
+    ttk::checkbutton $f.fill -text [msgcat::mc {Fill}] \
+	-variable pap(discrete,fill)
 
-    APLineSymbolMenu $f.symbol.menu pap(discrete,symbol)
+    grid $f.show -padx 2 -pady 2 -sticky w
+    grid $f.ctitle $f.color $f.stitle $f.symbol $f.fill \
+	-padx 2 -pady 2 -sticky w
+
+    PlotLineSymbolMenu $f.symbol.menu pap(discrete,symbol)
 
     # Line
     set f [ttk::labelframe $w.plot.linear -text [msgcat::mc {Linear}]]
@@ -486,8 +494,8 @@ proc PrefsDialogPlot {} {
     grid $f.ctitle $f.color $f.wtitle $f.width 	$f.dtitle $f.dash \
 	-padx 2 -pady 2 -sticky w
 
-    APLineWidthMenu $f.width.menu pap(linear,width)
-    APLineDashMenu $f.dash.menu pap(linear,dash)
+    PlotLineWidthMenu $f.width.menu pap(linear,width)
+    PlotLineDashMenu $f.dash.menu pap(linear,dash)
 
     # Step
     set f [ttk::labelframe $w.plot.step -text [msgcat::mc {Step}]]
@@ -507,8 +515,8 @@ proc PrefsDialogPlot {} {
     grid $f.ctitle $f.color $f.wtitle $f.width $f.dtitle $f.dash \
 	-padx 2 -pady 2 -sticky w
 
-    APLineWidthMenu $f.width.menu pap(step,width)
-    APLineDashMenu $f.dash.menu pap(step,dash)
+    PlotLineWidthMenu $f.width.menu pap(step,width)
+    PlotLineDashMenu $f.dash.menu pap(step,dash)
 
     # Quadratic
     set f [ttk::labelframe $w.plot.quadratic -text [msgcat::mc {Quadratic}]]
@@ -529,8 +537,8 @@ proc PrefsDialogPlot {} {
     grid $f.ctitle $f.color $f.wtitle $f.width $f.dtitle $f.dash \
 	-padx 2 -pady 2 -sticky w
 
-    APLineWidthMenu $f.width.menu pap(quadratic,width)
-    APLineDashMenu $f.dash.menu pap(quadratic,dash)
+    PlotLineWidthMenu $f.width.menu pap(quadratic,width)
+    PlotLineDashMenu $f.dash.menu pap(quadratic,dash)
 
     # Error
     set f [ttk::labelframe $w.plot.error -text [msgcat::mc {Error}]]
@@ -543,21 +551,12 @@ proc PrefsDialogPlot {} {
 
     ttk::label $f.wtitle -text [msgcat::mc {Width}]
     ttk::menubutton $f.width -textvariable pap(error,width) -menu $f.width.menu
-    ttk::label $f.stitle -text [msgcat::mc {Style}]
-    ttk::menubutton $f.style -textvariable pap(error,style) -menu $f.style.menu
 
     grid $f.show -padx 2 -pady 2 -sticky w
-    grid $f.ctitle $f.color $f.wtitle $f.width $f.stitle $f.style \
+    grid $f.ctitle $f.color $f.wtitle $f.width \
 	-padx 2 -pady 2 -sticky w
 
-    APLineWidthMenu $f.width.menu pap(error,width)
-
-    set m $f.style.menu 
-    menu $m
-    $m add radiobutton -label "[msgcat::mc {Style}] 1" \
-	-variable pap(error,style) -value 1
-    $m add radiobutton -label "[msgcat::mc {Style}] 2" \
-	-variable pap(error,style) -value 2
+    PlotLineWidthMenu $f.width.menu pap(error,width)
 
     pack $w.plot.grid $w.plot.font $w.plot.discrete $w.plot.linear \
 	$w.plot.step $w.plot.quadratic $w.plot.error \
