@@ -45,7 +45,9 @@ proc MarkerDef {} {
     set marker(copy,system) {}
     set marker(maxdialog) 48
     set marker(load) current
+
     set marker(format) ds9
+    # these are only used for save/load/list and are set from current wcs values
     set marker(system) physical
     set marker(sky) fk5
     set marker(skyformat) degrees
@@ -580,10 +582,10 @@ proc MarkerCreateShape {which x y} {
     global current
     global wcs
 
+    # for compass/ruler
     global ed
     set ed(system) $wcs(system)
     set ed(sky) $wcs(sky)
-    set ed(skyformat) $wcs(skyformat)
     set ed(format) degrees
     AdjustCoordSystem ed system
 
@@ -603,7 +605,7 @@ proc MarkerCreateShape {which x y} {
 	vector {append cmd " $x $y"}
 	text {
 	    set txt "Region"
-	    set r [EntryDialog "Text Region" "Enter Text:" 40 txt {}]
+	    set r [EntryDialog "Text Region" "Enter Text:" 40 txt]
 	    if {$r == 1 && $txt != {}} {
 		append cmd " 0 text = \{\{$txt\}\}"
 	    } else {
