@@ -211,7 +211,12 @@ proc MarkerAnalysisPlot2dXAxisTitle {frame id} {
 	    }
 	}
     }
-    $vvar(graph) xaxis configure -title $title
+
+    # set for plot code
+    set vvar(graph,xaxis) $title
+
+    # update now (may not make it into plot code)
+    $vvar(graph) xaxis configure -title $vvar(graph,xaxis)
 }
 
 proc MarkerAnalysisPlot2dYAxisTitle {frame id} {
@@ -219,7 +224,11 @@ proc MarkerAnalysisPlot2dYAxisTitle {frame id} {
     upvar #0 $vvarname vvar
     global $vvarname
 
-    $vvar(graph) yaxis configure -title "Counts [string totitle $vvar(method)]"
+    # set for plot code
+    set vvar(graph,yaxis) "Counts [string totitle $vvar(method)]"
+
+    # update now (may not make it into plot code)
+    $vvar(graph) yaxis configure -title $vvar(graph,yaxis)
 }
 
 proc MarkerAnalysisPlot2dXAxis {frame id w xx} {
