@@ -457,8 +457,9 @@ proc ColorMenuOther {varname color cmd} {
     upvar #0 $varname var
     global $varname
 
-    EntryDialog [msgcat::mc {Color}] [msgcat::mc {Enter Color}] \
-	20 ${varname}($color) $cmd
+    if {[EntryDialog [msgcat::mc {Color}] [msgcat::mc {Enter Color}] 20 ${varname}($color)]} {
+	eval $cmd
+    }
 }
 
 proc ColorMenuButton {w varname color cmd} {
@@ -533,8 +534,9 @@ proc FontMenuSize {varname size cmd} {
     upvar #0 $varname var
     global $varname
 
-    EntryDialog [msgcat::mc {Font Size}] [msgcat::mc {Enter Font Size}] \
-	20 ${varname}($size) $cmd
+    if {[EntryDialog [msgcat::mc {Font Size}] [msgcat::mc {Enter Font Size}] 20 ${varname}($size)]} {
+	eval $cmd
+    }
 }
 
 proc FontMenuButton {w varname font size weight slant cmd} {
