@@ -11,36 +11,40 @@ proc FileMainMenu {} {
 
     menu $ds9(mb).file 
     $ds9(mb).file add command -label "[msgcat::mc {Open}]..." \
-	-command OpenFits -accelerator "${ds9(ctrl)}O"
-    $ds9(mb).file add cascade -label [msgcat::mc {Open Other}] \
+	-command [list OpenDialog fits] -accelerator "${ds9(ctrl)}O"
+    $ds9(mb).file add cascade -label [msgcat::mc {Open as}] \
 	-menu $ds9(mb).file.open
     $ds9(mb).file add separator
     $ds9(mb).file add command -label "[msgcat::mc {Save}]..." \
-	-command SaveFits -accelerator "${ds9(ctrl)}S"
-    $ds9(mb).file add command -label "[msgcat::mc {Export}]..." \
-	-command ExportDialog
+	-command [list SaveDialog fits] -accelerator "${ds9(ctrl)}S"
+    $ds9(mb).file add cascade -label [msgcat::mc {Save as}] \
+	-menu $ds9(mb).file.save
     $ds9(mb).file add separator
-    $ds9(mb).file add command -label "[msgcat::mc {Save Image}]..." \
-	-command SaveImageDialog
+    $ds9(mb).file add cascade -label [msgcat::mc {Import}] \
+	-menu $ds9(mb).file.import
+    $ds9(mb).file add cascade -label [msgcat::mc {Export}] \
+	-menu $ds9(mb).file.export
+    $ds9(mb).file add separator
+    $ds9(mb).file add cascade -label [msgcat::mc {Save Image}] \
+	-menu $ds9(mb).file.saveimage
     $ds9(mb).file add command -label "[msgcat::mc {Create Movie}]..." \
 	-command MovieDialog
     $ds9(mb).file add separator
-    $ds9(mb).file add cascade -label [msgcat::mc {Preserve During Load}] \
-	-menu $ds9(mb).file.preserve
-    $ds9(mb).file add separator
-    $ds9(mb).file add command -label "[msgcat::mc {Display Header}]..." \
-	-command DisplayHeaderMenu 
-    $ds9(mb).file add separator
-    $ds9(mb).file add cascade -label [msgcat::mc {XPA}] \
-	-menu $ds9(mb).file.xpa
-    $ds9(mb).file add cascade -label [msgcat::mc {SAMP}] \
-	-menu $ds9(mb).file.samp
-    $ds9(mb).file add separator
     $ds9(mb).file add command -label "[msgcat::mc {Backup}]..." \
 	-command BackupDialog
     $ds9(mb).file add command -label "[msgcat::mc {Restore}]..." \
 	-command RestoreDialog
     $ds9(mb).file add separator
+    $ds9(mb).file add command -label "[msgcat::mc {Display Header}]..." \
+	-command DisplayHeaderMenu 
+    $ds9(mb).file add cascade -label [msgcat::mc {Preserve During Load}] \
+	-menu $ds9(mb).file.preserve
+    $ds9(mb).file add separator
+    $ds9(mb).file add cascade -label [msgcat::mc {XPA}] \
+	-menu $ds9(mb).file.xpa
+    $ds9(mb).file add cascade -label [msgcat::mc {SAMP}] \
+	-menu $ds9(mb).file.samp
+    $ds9(mb).file add separator
     $ds9(mb).file add command -label "[msgcat::mc {Open TCL Console}]..." \
 	-command OpenConsole
     $ds9(mb).file add command -label "[msgcat::mc {Source TCL}]..." \
@@ -92,52 +96,132 @@ proc FileMainMenu {} {
 
     # File Open Menu
     menu $ds9(mb).file.open
-    $ds9(mb).file.open add command -label "[msgcat::mc {Open Array}]..." \
-	-command OpenArray
-    $ds9(mb).file.open add command -label "[msgcat::mc {Open Photo}]..." \
-	-command OpenPhoto
-    $ds9(mb).file.open add command -label "[msgcat::mc {Open URL}]..." \
-	-command OpenURL
+    $ds9(mb).file.open add command -label "[msgcat::mc {Slice}]..." \
+	-command [list OpenDialog fits {} slice]
     $ds9(mb).file.open add separator
     $ds9(mb).file.open add command \
-	-label "[msgcat::mc {Open RGB Fits Image}]..." \
-	-command OpenRGBImageFits
+	-label "[msgcat::mc {RGB Image}]..." \
+	-command [list OpenDialog rgbimage]
     $ds9(mb).file.open add command \
-	-label "[msgcat::mc {Open RGB Fits Cube}]..."\
-	-command OpenRGBCubeFits
-    $ds9(mb).file.open add command \
-	-label "[msgcat::mc {Open RGB Array}]..." \
-	-command OpenRGBArray
-    $ds9(mb).file.open add separator
-    $ds9(mb).file.open add command -label "[msgcat::mc {Open Slice}]..." \
-	-command OpenSliceFits
-    $ds9(mb).file.open add command -label "[msgcat::mc {Open Photo Slice}]..." \
-	-command OpenSlicePhoto
+	-label "[msgcat::mc {RGB Cube}]..."\
+	-command [list OpenDialog rgbcube]
     $ds9(mb).file.open add separator
     $ds9(mb).file.open add command \
-	-label "[msgcat::mc {Open Multi Ext Cube}]..." \
-	-command OpenMECubeFits
+	-label "[msgcat::mc {Multiple Extension Cube}]..." \
+	-command [list OpenDialog mecube]
     $ds9(mb).file.open add command \
-	-label "[msgcat::mc {Open Multi Ext Multi Frames}]..." \
-	-command {OpenMultiFrameFits}
+	-label "[msgcat::mc {Multiple Extension Frames}]..." \
+	-command [list OpenDialog multiframe]
     $ds9(mb).file.open add separator
     $ds9(mb).file.open add command \
-	-label "[msgcat::mc {Open Mosaic IRAF}]..." \
-	-command OpenMosaicImageIRAFFits
+	-label "[msgcat::mc {Mosaic WCS}]..." \
+	-command [list OpenDialog mosaicimagewcs]
     $ds9(mb).file.open add command \
-	-label "[msgcat::mc {Open Mosaic IRAF Segment}]..." \
-	-command OpenMosaicIRAFFits
+	-label "[msgcat::mc {Mosaic WCS Segment}]..." \
+	-command [list OpenDialog mosaicwcs]
+    $ds9(mb).file.open add command \
+	-label "[msgcat::mc {Mosaic IRAF}]..." \
+	-command [list OpenDialog mosaicimageiraf]
+    $ds9(mb).file.open add command \
+	-label "[msgcat::mc {Mosaic IRAF Segment}]..." \
+	-command [list OpenDialog mosaiciraf]
+    $ds9(mb).file.open add command \
+	-label "[msgcat::mc {Mosaic WFPC2}]..." \
+	-command [list OpenDialog mosaicimagewfpc2]
     $ds9(mb).file.open add separator
     $ds9(mb).file.open add command \
-	-label "[msgcat::mc {Open Mosaic WCS}]..." \
-	-command OpenMosaicImageWCSFits
-    $ds9(mb).file.open add command \
-	-label "[msgcat::mc {Open Mosaic WCS Segment}]..." \
-	-command OpenMosaicWCSFits
-    $ds9(mb).file.open add separator
-    $ds9(mb).file.open add command \
-	-label "[msgcat::mc {Open Mosaic WFPC2}]..." \
-	-command OpenMosaicImageWFPC2Fits
+	-label "[msgcat::mc {URL}]..." \
+	-command [list OpenURLFits]
+
+    # File Save Menu
+    menu $ds9(mb).file.save
+    $ds9(mb).file.save add command -label "[msgcat::mc {Slice}]..." \
+	-command [list SaveDialog slice]
+    $ds9(mb).file.save add separator
+    $ds9(mb).file.save add command \
+	-label "[msgcat::mc {RGB Image}]..." \
+	-command [list SaveDialog rgbimage]
+    $ds9(mb).file.save add command \
+	-label "[msgcat::mc {RGB Cube}]..."\
+	-command [list SaveDialog rgbcube]
+    $ds9(mb).file.save add separator
+    $ds9(mb).file.save add command \
+	-label "[msgcat::mc {Multiple Extension Cube}]..." \
+	-command [list SaveDialog mecube]
+    $ds9(mb).file.save add separator
+    $ds9(mb).file.save add command \
+	-label "[msgcat::mc {Mosaic WCS}]..." \
+	-command [list SaveDialog mosaicimagewcs]
+    $ds9(mb).file.save add command \
+	-label "[msgcat::mc {Mosaic WCS Segment}]..." \
+	-command [list SaveDialog mosaicwcs]
+
+    # File Import Menu
+    menu $ds9(mb).file.import
+    $ds9(mb).file.import add cascade -label [msgcat::mc {Slice}] \
+	-menu $ds9(mb).file.import.slice
+    $ds9(mb).file.import add separator
+    $ds9(mb).file.import add command -label "[msgcat::mc {Array}]..." \
+	-command [list ImportDialog array]
+    $ds9(mb).file.import add command -label {NRRD...} \
+	-command [list ImportDialog nrrd]
+    $ds9(mb).file.import add separator
+    $ds9(mb).file.import add command -label "[msgcat::mc {RGB Array}]..." \
+	-command [list ImportDialog rgbarray]
+    $ds9(mb).file.import add separator
+    $ds9(mb).file.import add command -label {GIF...} \
+	-command [list ImportDialog gif]
+    $ds9(mb).file.import add command -label {TIFF...} \
+	-command [list ImportDialog tiff]
+    $ds9(mb).file.import add command -label {JPEG...} \
+	-command [list ImportDialog jpeg]
+    $ds9(mb).file.import add command -label {PNG...} \
+	-command [list ImportDialog png]
+
+    # File Import Slice Menu
+    menu $ds9(mb).file.import.slice
+    $ds9(mb).file.import.slice add command -label {GIF...} \
+	-command [list ImportDialog gif {} slice]
+    $ds9(mb).file.import.slice add command -label {TIFF...} \
+	-command [list ImportDialog tiff {} slice]
+    $ds9(mb).file.import.slice add command -label {JPEG...} \
+	-command [list ImportDialog jpeg {} slice]
+    $ds9(mb).file.import.slice add command -label {PNG...} \
+	-command [list ImportDialog png {} slice]
+
+    # File Export Menu
+    menu $ds9(mb).file.export
+    $ds9(mb).file.export add command -label "[msgcat::mc {Array}]..." \
+	-command [list ExportDialog array]
+    $ds9(mb).file.export add command -label {NRRD...} \
+	-command [list ExportDialog nrrd]
+    $ds9(mb).file.export add separator
+    $ds9(mb).file.export add command -label "[msgcat::mc {RGB Array}]..." \
+	-command [list ExportDialog rgbarray]
+    $ds9(mb).file.export add separator
+    $ds9(mb).file.export add command -label {GIF...} \
+	-command [list ExportDialog gif]
+    $ds9(mb).file.export add command -label {TIFF...} \
+	-command [list ExportDialog tiff]
+    $ds9(mb).file.export add command -label {JPEG...} \
+	-command [list ExportDialog jpeg]
+    $ds9(mb).file.export add command -label {PNG...} \
+	-command [list ExportDialog png]
+
+    # File Saveimage Menu
+    menu $ds9(mb).file.saveimage
+    $ds9(mb).file.saveimage add command -label {FITS...} \
+	-command [list SaveImageDialog fits]
+    $ds9(mb).file.saveimage add command -label {EPS...} \
+	-command [list SaveImageDialog eps]
+    $ds9(mb).file.saveimage add command -label {GIF...} \
+	-command [list SaveImageDialog gif]
+    $ds9(mb).file.saveimage add command -label {TIFF...} \
+	-command [list SaveImageDialog tiff]
+    $ds9(mb).file.saveimage add command -label {JPEG...} \
+	-command [list SaveImageDialog jpeg]
+    $ds9(mb).file.saveimage add command -label {PNG...} \
+	-command [list SaveImageDialog png]
 
     # File Preserve Menu
     menu $ds9(mb).file.preserve
@@ -170,7 +254,7 @@ proc FileMainMenu {} {
     $ds9(mb).file.samp.table add separator
 
     menu $ds9(mb).file.xpa
-    $ds9(mb).file.xpa add command -label [msgcat::mc {Information}] \
+    $ds9(mb).file.xpa add command -label "[msgcat::mc {Information}]..." \
 	-command XPAInfo
     $ds9(mb).file.xpa add separator
     $ds9(mb).file.xpa add command -label [msgcat::mc {Connect}] \
@@ -179,7 +263,7 @@ proc FileMainMenu {} {
 	-command XPADisconnect
 
     # Bindings
-    bind $ds9(top) <<Open>> OpenFits
+    bind $ds9(top) <<Open>> [list OpenDialog fits]
     switch $ds9(wm) {
  	x11 {
 	    bind $ds9(top) <<PageSetup>> PSPageSetup
@@ -231,13 +315,13 @@ proc ButtonsFileDef {} {
     array set pbuttons {
 	file,open 1
 	file,save 1
-	file,export 0
-	file,saveimage 1
 	file,movie 0
+	file,backup 0
+	file,restore 0
 	file,header 1
+	file,xpa,info 0
 	file,samp,image 0
 	file,samp,table 0
-	file,xpa 0
 	file,console 0
 	file,tcl 0
 	file,pspage 0
@@ -255,28 +339,30 @@ proc CreateButtonsFile {} {
     ttk::frame $ds9(buttons).file
 
     ButtonButton $ds9(buttons).file.open \
-	[string tolower [msgcat::mc {Open}]] OpenFits
-
+	[string tolower [msgcat::mc {Open}]] \
+	[list OpenDialog fits]
     ButtonButton $ds9(buttons).file.save \
-	[string tolower [msgcat::mc {Save}]] SaveFits
-    ButtonButton $ds9(buttons).file.export \
-	[string tolower [msgcat::mc {Export}]] ExportDialog
+	[string tolower [msgcat::mc {Save}]] \
+	[list SaveDialog fits]
 
-    ButtonButton $ds9(buttons).file.saveimage \
-	[string tolower [msgcat::mc {Save Image}]] SaveImageDialog
     ButtonButton $ds9(buttons).file.movie \
 	[string tolower [msgcat::mc {Create Movie}]] MovieDialog
 
+    ButtonButton $ds9(buttons).file.backup \
+	[string tolower [msgcat::mc {Backup}]] BackupDialog
+    ButtonButton $ds9(buttons).file.restore \
+	[string tolower [msgcat::mc {Restore}]] RestoreDialog
+
     ButtonButton $ds9(buttons).file.header \
 	[string tolower [msgcat::mc {Header}]] DisplayHeaderMenu
 
+    ButtonButton $ds9(buttons).file.xpainfo \
+	[string tolower {XPA Info}] XPAInfo
     ButtonButton $ds9(buttons).file.sampimage \
 	[string tolower [msgcat::mc {SAMP Image}]] "SAMPSendImageLoadFits {}"
     ButtonButton $ds9(buttons).file.samptable \
 	[string tolower [msgcat::mc {SAMP Table}]] "SAMPSendTableLoadFits {}"
 
-    ButtonButton $ds9(buttons).file.xpa \
-	[string tolower {XPA}] XPAInfo
     ButtonButton $ds9(buttons).file.console \
 	[string tolower [msgcat::mc {Console}]] OpenConsole
     ButtonButton $ds9(buttons).file.tcl \
@@ -314,13 +400,13 @@ proc CreateButtonsFile {} {
     set buttons(file) "
         $ds9(buttons).file.open pbuttons(file,open)
         $ds9(buttons).file.save pbuttons(file,save)
-        $ds9(buttons).file.export pbuttons(file,export)
-        $ds9(buttons).file.saveimage pbuttons(file,saveimage)
         $ds9(buttons).file.movie pbuttons(file,movie)
+        $ds9(buttons).file.backup pbuttons(file,backup)
+        $ds9(buttons).file.restore pbuttons(file,restore)
         $ds9(buttons).file.header pbuttons(file,header)
+        $ds9(buttons).file.xpainfo pbuttons(file,xpa,info)
         $ds9(buttons).file.sampimage pbuttons(file,samp,image)
         $ds9(buttons).file.samptable pbuttons(file,samp,table)
-        $ds9(buttons).file.xpa pbuttons(file,xpa)
         $ds9(buttons).file.console pbuttons(file,console)
         $ds9(buttons).file.tcl pbuttons(file,tcl)
         $ds9(buttons).file.pspage pbuttons(file,pspage)
@@ -334,6 +420,7 @@ proc CreateButtonsFile {} {
 proc PrefsDialogButtonbarFile {f} {
     global buttons
     global pbuttons
+    global ds9
 
     ttk::menubutton $f -text [msgcat::mc {Buttonbar}] -menu $f.menu
     
@@ -341,48 +428,77 @@ proc PrefsDialogButtonbarFile {f} {
     menu $m
     $m add checkbutton -label "[msgcat::mc {Open}]..." \
 	-variable pbuttons(file,open) -command {UpdateButtons buttons(file)}
-
     $m add checkbutton -label "[msgcat::mc {Save}]..." \
 	-variable pbuttons(file,save) -command {UpdateButtons buttons(file)}
     $m add separator
-    $m add checkbutton -label "[msgcat::mc {Export}]..." \
-	-variable pbuttons(file,export) -command {UpdateButtons buttons(file)}
-    $m add separator
-    $m add checkbutton -label "[msgcat::mc {Save Image}]..." \
-	-variable pbuttons(file,saveimage) -command {UpdateButtons buttons(file)}
     $m add checkbutton -label "[msgcat::mc {Create Movie}]..." \
 	-variable pbuttons(file,movie) -command {UpdateButtons buttons(file)}
     $m add separator
+    $m add checkbutton -label "[msgcat::mc {Backup}]..." \
+	-variable pbuttons(file,backup) -command {UpdateButtons buttons(file)}
+    $m add checkbutton -label "[msgcat::mc {Restore}]..." \
+	-variable pbuttons(file,restore) -command {UpdateButtons buttons(file)}
+    $m add separator
     $m add checkbutton -label "[msgcat::mc {Display Header}]..." \
 	-variable pbuttons(file,header) -command {UpdateButtons buttons(file)}
     $m add separator
+    $m add cascade -label [msgcat::mc {XPA}] -menu $m.xpa
     $m add cascade -label [msgcat::mc {SAMP}] -menu $m.samp
     $m add separator
-    $m add checkbutton -label "[msgcat::mc {XPA Information}]..." \
-	-variable pbuttons(file,xpa) -command {UpdateButtons buttons(file)}
     $m add checkbutton -label "[msgcat::mc {Open TCL Console}]..." \
 	-variable pbuttons(file,console) -command {UpdateButtons buttons(file)}
     $m add checkbutton -label "[msgcat::mc {Source TCL}]..." \
 	-variable pbuttons(file,tcl) -command {UpdateButtons buttons(file)}
     $m add separator
-    $m add checkbutton -label "[msgcat::mc {Postscript Page Setup}]..." \
-	-variable pbuttons(file,pspage) -command {UpdateButtons buttons(file)}
-    $m add checkbutton -label "[msgcat::mc {Postscript Print}]..." \
-	-variable pbuttons(file,psprint) -command {UpdateButtons buttons(file)}
-    $m add separator
-    $m add checkbutton -label "[msgcat::mc {Page Setup}]..." \
-	-variable pbuttons(file,page) -command {UpdateButtons buttons(file)}
-    $m add checkbutton -label "[msgcat::mc {Print}]..." \
-	-variable pbuttons(file,print) -command {UpdateButtons buttons(file)}
+
+    switch $ds9(wm) {
+	x11 {
+	    $m add checkbutton \
+		-label "[msgcat::mc {Page Setup}]..." \
+		-variable pbuttons(file,page) \
+		-command {UpdateButtons buttons(file)}
+	    $m add checkbutton \
+		-label "[msgcat::mc {Print}]..." \
+		-variable pbuttons(file,print) \
+		-command {UpdateButtons buttons(file)}
+	}
+	win32 -
+	aqua {
+	    $m add checkbutton \
+		-label "[msgcat::mc {Postscript Page Setup}]..." \
+		-variable pbuttons(file,pspage) \
+		-command {UpdateButtons buttons(file)}
+	    $m add checkbutton \
+		-label "[msgcat::mc {Postscript Print}]..." \
+		-variable pbuttons(file,psprint) \
+		-command {UpdateButtons buttons(file)}
+	    $m add separator
+	    $m add checkbutton \
+		-label "[msgcat::mc {Page Setup}]..." \
+		-variable pbuttons(file,page) \
+		-command {UpdateButtons buttons(file)}
+	    $m add checkbutton \
+		-label "[msgcat::mc {Print}]..." \
+		-variable pbuttons(file,print) \
+		-command {UpdateButtons buttons(file)}
+	}
+    }
+
+
     $m add separator
     $m add checkbutton -label [msgcat::mc {Exit}] \
 	-variable pbuttons(file,exit) -command {UpdateButtons buttons(filew)}
 
+    menu $m.xpa
+    $m.xpa add checkbutton -label "[msgcat::mc {Information}]..." \
+	-variable pbuttons(file,xpa,info) \
+	-command {UpdateButtons buttons(file)}
+
     menu $m.samp
-    $m.samp add checkbutton -label [msgcat::mc {SAMP Image}] \
+    $m.samp add checkbutton -label [msgcat::mc {Image}] \
 	-variable pbuttons(file,samp,image) \
 	-command {UpdateButtons buttons(file)}
-    $m.samp add checkbutton -label [msgcat::mc {SAMP Table}] \
+    $m.samp add checkbutton -label [msgcat::mc {Table}] \
 	-variable pbuttons(file,samp,table) \
 	-command {UpdateButtons buttons(file)}
 }
@@ -400,29 +516,21 @@ proc UpdateFileMenuStatic {} {
     if {$ds9(active,num) > 0} {
 	$ds9(mb).file entryconfig "[msgcat::mc {Open}]..." \
 	    -state normal
-	$ds9(mb).file entryconfig [msgcat::mc {Open Other}] \
+	$ds9(mb).file entryconfig [msgcat::mc {Open as}] \
 	    -state normal
-	$ds9(mb).file entryconfig "[msgcat::mc {Save Image}]..." \
-	    -state normal
-	$ds9(mb).file entryconfig "[msgcat::mc {Create Movie}]..." \
+	$ds9(mb).file entryconfig [msgcat::mc {Import}] \
 	    -state normal
 
 	$ds9(buttons).file.open configure -state normal
-	$ds9(buttons).file.saveimage configure -state normal
-	$ds9(buttons).file.movie configure -state normal
     } else {
 	$ds9(mb).file entryconfig "[msgcat::mc {Open}]..." \
 	    -state disabled
-	$ds9(mb).file entryconfig [msgcat::mc {Open Other}] \
+	$ds9(mb).file entryconfig [msgcat::mc {Open as}] \
 	    -state disabled
-	$ds9(mb).file entryconfig "[msgcat::mc {Save Image}]..." \
-	    -state disabled
-	$ds9(mb).file entryconfig "[msgcat::mc {Create Movie}]..." \
+	$ds9(mb).file entryconfig [msgcat::mc {Import}] \
 	    -state disabled
 
 	$ds9(buttons).file.open configure -state disabled
-	$ds9(buttons).file.saveimage configure -state disabled
-	$ds9(buttons).file.movie configure -state disabled
     }
 }
 
@@ -443,56 +551,78 @@ proc UpdateFileMenu {} {
     if {$current(frame) != {}} {
 	if {[$current(frame) has fits]} {
 	    $mm entryconfig "[msgcat::mc {Save}]..." -state normal
-	    $mm entryconfig "[msgcat::mc {Export}]..." -state normal
-	    $mm entryconfig "[msgcat::mc {Display Header}]..." \
-		-state normal
+	    $mm entryconfig [msgcat::mc {Save as}] -state normal
+	    $mm entryconfig [msgcat::mc {Export}] -state normal
+	    $mm entryconfig [msgcat::mc {Save Image}] -state normal
+	    $mm entryconfig "[msgcat::mc {Create Movie}]..." -state normal
+	    $mm entryconfig "[msgcat::mc {Display Header}]..." -state normal
+
+	    if {[$current(frame) has fits mosaic]} {
+		$mm.save entryconfig "[msgcat::mc {Mosaic WCS}]..." -state normal
+		$mm.save entryconfig "[msgcat::mc {Mosaic WCS Segment}]..." -state normal
+	    } else {
+		$mm.save entryconfig "[msgcat::mc {Mosaic WCS}]..." -state disabled
+		$mm.save entryconfig "[msgcat::mc {Mosaic WCS Segment}]..." -state disabled
+	    }
 
 	    $bb.save configure -state normal
+	    $bb.movie configure -state normal
 	    $bb.header configure -state normal
 	} else {
 	    $mm entryconfig "[msgcat::mc {Save}]..." -state disabled
-	    $mm entryconfig "[msgcat::mc {Export}]..." -state disabled
-	    $mm entryconfig "[msgcat::mc {Display Header}]..." \
-		-state disabled
+	    $mm entryconfig [msgcat::mc {Save as}] -state disabled
+	    $mm entryconfig [msgcat::mc {Export}] -state disabled
+	    $mm entryconfig [msgcat::mc {Save Image}] -state disabled
+	    $mm entryconfig "[msgcat::mc {Create Movie}]..." -state disabled
+	    $mm entryconfig "[msgcat::mc {Display Header}]..." -state disabled
 
 	    $bb.save configure -state disabled
+	    $bb.movie configure -state disabled
 	    $bb.header configure -state disabled
 	}
 
 	switch -- [$current(frame) get type] {
 	    base {
 		$mm.open entryconfig \
-		    "[msgcat::mc {Open RGB Fits Image}]..." -state disabled
+		    "[msgcat::mc {RGB Image}]..." -state disabled
 		$mm.open entryconfig \
-		    "[msgcat::mc {Open RGB Fits Cube}]..." -state disabled
-		$mm.open entryconfig \
-		    "[msgcat::mc {Open RGB Array}]..." -state disabled
-
-		$bb.export configure -state normal
+		    "[msgcat::mc {RGB Cube}]..." -state disabled
+		$mm.save entryconfig \
+		    "[msgcat::mc {RGB Image}]..." -state disabled
+		$mm.save entryconfig \
+		    "[msgcat::mc {RGB Cube}]..." -state disabled
+		$mm.import entryconfig \
+		    "[msgcat::mc {RGB Array}]..." -state disabled
+		$mm.export entryconfig \
+		    "[msgcat::mc {RGB Array}]..." -state disabled
 	    }
 	    rgb {
 		$mm.open entryconfig \
-		    "[msgcat::mc {Open RGB Fits Image}]..." -state normal
+		    "[msgcat::mc {RGB Image}]..." -state normal
 		$mm.open entryconfig \
-		    "[msgcat::mc {Open RGB Fits Cube}]..." -state normal
-		$mm.open entryconfig \
-		    "[msgcat::mc {Open RGB Array}]..." -state normal
-		# override above
-		$mm entryconfig "[msgcat::mc {Export}]..." -state disabled
-
-		$bb.export configure -state disabled
+		    "[msgcat::mc {RGB Cube}]..." -state normal
+		$mm.save entryconfig \
+		    "[msgcat::mc {RGB Image}]..." -state normal
+		$mm.save entryconfig \
+		    "[msgcat::mc {RGB Cube}]..." -state normal
+		$mm.import entryconfig \
+		    "[msgcat::mc {RGB Array}]..." -state normal
+		$mm.export entryconfig \
+		    "[msgcat::mc {RGB Array}]..." -state normal
 	    }
 	    3d {
 		$mm.open entryconfig \
-		    "[msgcat::mc {Open RGB Fits Image}]..." -state disabled
+		    "[msgcat::mc {RGB Image}]..." -state disabled
 		$mm.open entryconfig \
-		    "[msgcat::mc {Open RGB Fits Cube}]..." -state disabled
-		$mm.open entryconfig \
-		    "[msgcat::mc {Open RGB Array}]..." -state disabled
-		# override above
-		$mm entryconfig "[msgcat::mc {Export}]..." -state disabled
-
-		$bb.export configure -state disabled
+		    "[msgcat::mc {RGB Cube}]..." -state disabled
+		$mm.save entryconfig \
+		    "[msgcat::mc {RGB Image}]..." -state disabled
+		$mm.save entryconfig \
+		    "[msgcat::mc {RGB Cube}]..." -state disabled
+		$mm.import entryconfig \
+		    "[msgcat::mc {RGB Array}]..." -state disabled
+		$mm.export entryconfig \
+		    "[msgcat::mc {RGB Array}]..." -state disabled
 	    }
 	}
 
@@ -544,9 +674,15 @@ proc UpdateFileMenu {} {
 	    $bb.samptable configure -state disabled
 	}
     } else {
-	$mm entryconfig "[msgcat::mc {Display Header}]..." \
-	    -state disabled
+	$mm entryconfig "[msgcat::mc {Save}]..." -state disabled
+	$mm entryconfig [msgcat::mc {Save as}] -state disabled
+	$mm entryconfig [msgcat::mc {Export}] -state disabled
+	$mm entryconfig [msgcat::mc {Save Image}] -state disabled
+	$mm entryconfig "[msgcat::mc {Create Movie}]..." -state disabled
+	$mm entryconfig "[msgcat::mc {Display Header}]..." -state disabled
 
+	$bb.save configure -state disabled
+	$bb.movie configure -state disabled
 	$bb.header configure -state disabled
 
 	$mm.samp entryconfig [msgcat::mc {Image}] -state disabled
@@ -557,10 +693,10 @@ proc UpdateFileMenu {} {
 
     # XPA
     if [info exists xpa] {
-	$mm.xpa entryconfig [msgcat::mc {Information}] -state normal
+	$mm.xpa entryconfig "[msgcat::mc {Information}]..." -state normal
 	$mm.xpa entryconfig [msgcat::mc {Disconnect}] -state normal
     } else {
-	$mm.xpa entryconfig [msgcat::mc {Information}] -state disabled
+	$mm.xpa entryconfig "[msgcat::mc {Information}]..." -state disabled
 	$mm.xpa entryconfig [msgcat::mc {Disconnect}] -state disabled
     }
 
