@@ -82,8 +82,10 @@ proc FrameMainMenu {} {
 	-command MatchBinCurrent
     $ds9(mb).frame.match add command -label [msgcat::mc {Scale}] \
 	-command MatchScaleCurrent
-    $ds9(mb).frame.match add command -label [msgcat::mc {Color}] \
+    $ds9(mb).frame.match add command -label [msgcat::mc {Colorbar}] \
 	-command MatchColorCurrent
+    $ds9(mb).frame.match add command -label [msgcat::mc {Smooth}] \
+	-command MatchSmoothCurrent
 
     menu $ds9(mb).frame.match.frame
     $ds9(mb).frame.match.frame add command -label [msgcat::mc {WCS}] \
@@ -138,8 +140,10 @@ proc FrameMainMenu {} {
 	-variable bin(lock) -command {LockBinCurrent}
     $ds9(mb).frame.lock add checkbutton -label [msgcat::mc {Scale}] \
 	-variable scale(lock) -command {LockScaleCurrent}
-    $ds9(mb).frame.lock add checkbutton -label [msgcat::mc {Color}] \
+    $ds9(mb).frame.lock add checkbutton -label [msgcat::mc {Colorbar}] \
 	-variable colorbar(lock) -command {LockColorCurrent}
+    $ds9(mb).frame.lock add checkbutton -label [msgcat::mc {Smooth}] \
+	-variable smooth(lock) -command {LockSmoothCurrent}
 
     menu $ds9(mb).frame.lock.frame
     $ds9(mb).frame.lock.frame add radiobutton -label [msgcat::mc {None}] \
@@ -222,7 +226,7 @@ proc FrameMainMenu {} {
 	-menu $ds9(mb).frame.params.tile
     $ds9(mb).frame.params add cascade -label [msgcat::mc {Blink Interval}] \
 	-menu $ds9(mb).frame.params.blink
-    $ds9(mb).frame.params add command -label [msgcat::mc {Set Display Size}] \
+    $ds9(mb).frame.params add command -label [msgcat::mc {Display Size}] \
 	-command DisplayDefaultDialog
 
     menu $ds9(mb).frame.params.tile
@@ -335,6 +339,7 @@ proc ButtonsFrameDef {} {
 	frame,match,bin 0
 	frame,match,scale 0
 	frame,match,color 0
+	frame,match,smooth 0
 
 	frame,match,frame,wcs 0
 	frame,match,frame,image 0
@@ -358,6 +363,7 @@ proc ButtonsFrameDef {} {
 	frame,lock,bin 0
 	frame,lock,scale 0
 	frame,lock,color 0
+	frame,lock,smooth 0
 
 	frame,lock,frame,none 0
 	frame,lock,frame,wcs 0
@@ -439,6 +445,8 @@ proc CreateButtonsFrame {} {
 	[string tolower [msgcat::mc {Match Scale}]] MatchScaleCurrent
     ButtonButton $ds9(buttons).frame.matchcolor \
 	[string tolower [msgcat::mc {Match Color}]] MatchColorCurrent
+    ButtonButton $ds9(buttons).frame.matchsmooth \
+	[string tolower [msgcat::mc {Match Smooth}]] MatchSmoothCurrent
 
     ButtonButton $ds9(buttons).frame.matchframewcs \
 	[string tolower [msgcat::mc {Match Frame WCS}]] \
@@ -491,11 +499,13 @@ proc CreateButtonsFrame {} {
     CheckButton $ds9(buttons).frame.lockcube \
 	[string tolower [msgcat::mc {Lock Slice}]] cube(lock) LockCubeCurrent
     CheckButton $ds9(buttons).frame.lockbin \
-	[string tolower [msgcat::mc {Lock Bin}]] cube(lock) LockBinCurrent
+	[string tolower [msgcat::mc {Lock Bin}]] bin(lock) LockBinCurrent
     CheckButton $ds9(buttons).frame.lockscale \
 	[string tolower [msgcat::mc {Lock Scale}]] scale(lock) LockScaleCurrent
     CheckButton $ds9(buttons).frame.lockcolor \
-	[string tolower [msgcat::mc {Lock Color}]] scale(lock) LockColorCurrent
+	[string tolower [msgcat::mc {Lock Color}]] color(lock) LockColorCurrent
+    CheckButton $ds9(buttons).frame.locksmooth \
+	[string tolower [msgcat::mc {Lock Smooth}]] smooth(lock) LockSmoothCurrent
 
     RadioButton $ds9(buttons).frame.lockframenone \
 	[string tolower [msgcat::mc {Lock Frame None}]] \
@@ -599,6 +609,7 @@ proc CreateButtonsFrame {} {
         $ds9(buttons).frame.matchbin pbuttons(frame,match,bin)
         $ds9(buttons).frame.matchscale pbuttons(frame,match,scale)
         $ds9(buttons).frame.matchcolor pbuttons(frame,match,color)
+        $ds9(buttons).frame.matchsmooth pbuttons(frame,match,smooth)
 
         $ds9(buttons).frame.matchframewcs pbuttons(frame,match,frame,wcs)
         $ds9(buttons).frame.matchframeimage pbuttons(frame,match,frame,image)
@@ -622,6 +633,7 @@ proc CreateButtonsFrame {} {
         $ds9(buttons).frame.lockbin pbuttons(frame,lock,bin)
         $ds9(buttons).frame.lockscale pbuttons(frame,lock,scale)
         $ds9(buttons).frame.lockcolor pbuttons(frame,lock,color)
+        $ds9(buttons).frame.locksmooth pbuttons(frame,lock,smooth)
 
         $ds9(buttons).frame.lockframenone pbuttons(frame,lock,frame,none)
         $ds9(buttons).frame.lockframewcs pbuttons(frame,lock,frame,wcs)
@@ -737,6 +749,9 @@ proc PrefsDialogButtonbarFrame {f} {
     $m.match add checkbutton -label [msgcat::mc {Color}] \
 	-variable pbuttons(frame,match,color) \
 	-command {UpdateButtons buttons(frame)}
+    $m.match add checkbutton -label [msgcat::mc {Smooth}] \
+	-variable pbuttons(frame,match,smooth) \
+	-command {UpdateButtons buttons(frame)}
 
     menu $m.match.frame
     $m.match.frame add checkbutton -label [msgcat::mc {WCS}] \
@@ -812,6 +827,9 @@ proc PrefsDialogButtonbarFrame {f} {
     $m.lock add checkbutton -label [msgcat::mc {Color}] \
 	-variable pbuttons(frame,lock,color) \
 	-command {UpdateButtons buttons(frame)}
+    $m.lock add checkbutton -label [msgcat::mc {Smooth}] \
+	-variable pbuttons(frame,lock,smooth) \
+	-command {UpdateButtons buttons(frame)}
 
     menu $m.lock.frame
     $m.lock.frame add checkbutton -label [msgcat::mc {None}] \
@@ -896,7 +914,7 @@ proc PrefsDialogButtonbarFrame {f} {
 
     # params
     menu $m.params
-    $m.params add checkbutton -label [msgcat::mc {Set Display Size}] \
+    $m.params add checkbutton -label [msgcat::mc {Display Size}] \
 	-variable pbuttons(frame,size) -command {UpdateButtons buttons(frame)}
 }
 
