@@ -180,10 +180,10 @@ proc RegionMainMenu {} {
 
     menu $ds9(mb).region.params
     $ds9(mb).region.params add checkbutton \
-	-label [msgcat::mc {Show Regions}] \
+	-label [msgcat::mc {Show}] \
 	-variable marker(show) -command MarkerShow
     $ds9(mb).region.params add checkbutton \
-	-label [msgcat::mc {Show Regions Text}] \
+	-label [msgcat::mc {Show Text}] \
 	-variable marker(show,text) -command MarkerShowText
     $ds9(mb).region.params add separator
     $ds9(mb).region.params add checkbutton -label [msgcat::mc {Auto Plot 2D}] \
@@ -307,9 +307,9 @@ proc PrefsDialogRegionMenu {w} {
     FontMenu $m.font pmarker font font,size font,weight font,slant {}
 
     menu $m.params
-    $m.params add checkbutton -label [msgcat::mc {Show Regions}] \
+    $m.params add checkbutton -label [msgcat::mc {Show}] \
 	-variable pmarker(show)
-    $m.params add checkbutton -label [msgcat::mc {Show Regions Text}] \
+    $m.params add checkbutton -label [msgcat::mc {Show Text}] \
 	-variable pmarker(show,text)
     $m.params add separator
     $m.params add checkbutton -label [msgcat::mc {Auto Centroid}] \
@@ -350,6 +350,23 @@ proc PrefsDialogRegion {} {
     $f.format.menu add radiobutton -label {X Y} \
 	-variable pmarker(format) -value xy
 
+    # Length
+    set f [ttk::labelframe $w.region.dformat \
+	       -text [msgcat::mc {Default Length}]]
+
+    ttk::menubutton $f.dformat -textvariable pmarker(dformat) \
+	-menu $f.dformat.menu
+
+    grid $f.dformat -padx 2 -pady 2 -sticky w
+
+    menu $f.dformat.menu
+    $f.dformat.menu add radiobutton -label {Degrees} \
+	-variable pmarker(dformat) -value degrees
+    $f.dformat.menu add radiobutton -label {ArcMin} \
+	-variable pmarker(dformat) -value arcmin
+    $f.dformat.menu add radiobutton -label {ArcSec} \
+	-variable pmarker(dformat) -value arcsec
+
     # Centroid
     set f [ttk::labelframe $w.region.centroid -text [msgcat::mc {Centroid}]]
 
@@ -423,7 +440,7 @@ proc PrefsDialogRegion {} {
     
     grid $f.title $f.size $f.unit -padx 2 -pady 2 -sticky w
 
-    pack $w.region.format $w.region.centroid $w.region.plot \
+    pack $w.region.format $w.region.dformat $w.region.centroid $w.region.plot \
 	$w.region.circle $w.region.ellipse \
 	$w.region.box $w.region.projection $w.region.point \
 	-side top -fill both -expand true
@@ -954,10 +971,10 @@ proc PrefsDialogButtonbarRegion {f} {
 	-command {UpdateButtons buttons(region)}
 
     menu $m.params
-    $m.params add checkbutton -label [msgcat::mc {Show Regions}] \
+    $m.params add checkbutton -label [msgcat::mc {Show}] \
 	-variable pbuttons(region,show) \
 	-command {UpdateButtons buttons(region)}
-    $m.params add checkbutton -label [msgcat::mc {Show Regions Text}] \
+    $m.params add checkbutton -label [msgcat::mc {Show Text}] \
 	-variable pbuttons(region,showtext) \
 	-command {UpdateButtons buttons(region)}
     $m.params add separator
