@@ -378,7 +378,7 @@ proc PanZoomDialog {} {
 
     menu $mb.zoom
     $mb.zoom add checkbutton -label [msgcat::mc {Align}] \
-	-variable wcs(align) -command AlignWCSFrame
+	-variable current(align) -command AlignWCSFrame
     $mb.zoom add separator
     $mb.zoom add command -label [msgcat::mc {Zoom In}] -command {Zoom 2 2}
     $mb.zoom add command -label [msgcat::mc {Zoom Out}] -command {Zoom .5 .5}
@@ -560,11 +560,10 @@ proc UpdatePanZoomDialog {} {
 
 proc AlignWCSFrame {} {
     global current
-    global wcs
     global ds9
 
     if {$current(frame) != {}} {
-	$current(frame) wcs align $wcs(align)
+	$current(frame) wcs align $current(align)
 
 	LockFrameCurrent
 	UpdateGraphXAxis $current(frame)
@@ -582,7 +581,6 @@ proc MatchFrameCurrent {sys} {
 
 proc MatchFrame {which sys} {
     global ds9
-    global wcs
     global current
 
     # NO-make sure matrices have been updated
@@ -594,7 +592,7 @@ proc MatchFrame {which sys} {
 	physical -
 	amplifier -
 	detector {
-	    set wcs(align) 0
+	    set current(align) 0
 	    $which wcs align 0
 
 	    set pan [$which get cursor $sys scientific]
@@ -618,7 +616,7 @@ proc MatchFrame {which sys} {
 	    set sys [lindex $www 0]
 	    set sky [lindex $www 1]
 	    if {[$which has wcs $sys]} {
-		set wcs(align) 1
+		set current(align) 1
 		$which wcs align 1
 		set align [$which get wcs align pointer]
 		set pan [$which get cursor $sys FK5 scientific]
