@@ -374,9 +374,17 @@ proc FixPrefs {version} {
 	7.0 {
 	    FixPrefs7.0to7.1
 	}
+	7.1 {
+	    FixPrefs7.1to7.2
+	}
     }
 }
 
+proc FixPrefs7.1to7.2 {} {
+    FixVar pbuttons(file,xpa,info) pbuttons(file,xpa)
+    FixVar pcurrent(align) pwcs(align)
+}
+
 proc FixPrefs7.0to7.1 {} {
     global pap
 
