@@ -288,9 +288,12 @@ proc PrefsDialogGeneral {} {
 	}
     }
 
+    ttk::checkbutton $f.center -text [msgcat::mc {Center Non-modal Dialogs}] \
+	-variable pds9(dialog,center)
     ttk::checkbutton $f.all -text [msgcat::mc {Default All Files}] \
 	-variable pds9(dialog,all)
 
+    grid $f.center - -padx 2 -pady 2 -sticky w
     grid $f.all - -padx 2 -pady 2 -sticky w
 
     pack $w.general.misc $w.general.theme $w.general.lang \
