@@ -160,12 +160,98 @@ proc PostScript {} {
     }
 }
 
+proc EPS {fn} {
+    global ds9
+    global ps
+    global view
+    global canvas
+    global colorbar
+    global current
+
+    # we need to be realized
+    RealizeDS9
+    # need the colorbar levels updated
+    UpdateColormapLevel
+
+    set color rgb
+    set level 2
+    set resolution 72
+
+    set options {}
+
+    # Page size
+    set width [winfo width $ds9(canvas)]
+    set height [winfo height $ds9(canvas)]
+    append options " -pagex 0 -pagey 0 -pageanchor sw"
+    if ($width>$height) {
+	append options " -pagewidth $width"
+    } else {
+	append options " -pageheight $height"
+    }
+
+    # File
+    append options " -file \{$fn\}"
+
+    # set color specific postscript options
+    switch -- $ds9(visual) {
+	pseudocolor {
+	    colorbar postscript level $level
+	    colorbar postscript colorspace $color
+	    colorbar postscript resolution $resolution
+	}
+	truecolor {
+	    colorbar postscript level $level
+	    colorbar postscript colorspace $color
+	    colorbar postscript resolution $resolution
+
+	    colorbarrgb postscript level $level
+	    colorbarrgb postscript colorspace $color
+	    colorbarrgb postscript resolution $resolution
+	}
+    }
+
+    # set frame specific postscript options
+    foreach f $ds9(frames) {
+	$f postscript level $level
+	$f postscript colorspace $color
+	$f postscript resolution $resolution
+    }
+
+    # setting the scale for one widget sets it for the entire print run
+    if {$current(frame) != {}} {
+	$current(frame) postscript scale 1.0
+    }
+
+    # graphs
+    if {$view(graph,vert)} {
+	$ds9(graph,vert) configure -plotbackground white -bg white
+    }
+    if {$view(graph,horz)} {
+	$ds9(graph,horz) configure -plotbackground white -bg white
+    }
+
+    # now invoke canvas postscript command
+    if [catch {eval $ds9(canvas) postscript $options} rr] {
+	Error "[msgcat::mc {A postscript generation error has occurred}] $rr"
+    }
+
+    # reset graphs
+    if {$view(graph,vert)} {
+	$ds9(graph,vert) configure -plotbackground $ds9(bg) -bg $ds9(bg)
+    }
+    if {$view(graph,horz)} {
+	$ds9(graph,horz) configure -plotbackground $ds9(bg) -bg $ds9(bg)
+    }
+}
+
 proc PostScriptPageSize {x y w h optname} {
     upvar $optname options
 
     global ds9
     global ps
 
+    append options " -pagex $x -pagey $y"
+
     set width [winfo width $ds9(canvas)]
     set height [winfo height $ds9(canvas)]
     set wo [string trim $w "icmp"]
@@ -187,8 +273,6 @@ proc PostScriptPageSize {x y w h optname} {
 	    }
 	}
     }
-
-    append options " -pagex $x -pagey $y"
 }
 
 # Print Dialog procs
