@@ -691,6 +691,10 @@ proc SAMPSend {method params resultVar} {
 	return 0
     }
 
+    # reset error if needed
+    # xmlrpc leaves error msgs
+    InitError samp
+
     if {$debug(tcl,samp)} {
 	puts stderr "SAMPSend Result: $result"
     }
@@ -916,7 +920,7 @@ proc SAMPParseHub {} {
 
     if {[info exists env(SAMP_HUB)]} {
 	if {$env(SAMP_HUB) != {}} {
-	    set exp {std-url:(.*)}
+	    set exp {std-lockurl:(.*)}
 	    if {[regexp $exp $env(SAMP_HUB) dummy url]} {
 
 		ParseURL $url rr
@@ -1151,7 +1155,7 @@ proc SAMPRcvdImageLoadFits {varname} {
 
     if {$url != {}} {
 	MultiLoad
-	LoadURL $url
+	LoadURLFits $url {} {}
     }
 }
 
@@ -1194,7 +1198,7 @@ proc SAMPRcvdTableLoadFits {varname} {
 
     if {$url != {}} {
 	MultiLoad
-	LoadURL $url
+	LoadURLFits $url {} {}
     }
 }
 
