@@ -575,8 +575,9 @@ proc ScaleXAxisDialog {} {
 proc ScaleLogDialog {} {
     global scale
 
-    EntryDialog [msgcat::mc {Scale}] [msgcat::mc {Log Exponent}] \
-	10 scale(log) ChangeScale
+    if {[EntryDialog [msgcat::mc {Scale}] [msgcat::mc {Log Exponent}] 10 scale(log)]} {
+	ChangeScale
+    }
 }
 
 proc MinMaxDialog {} {
