@@ -60,6 +60,7 @@ source $ds9(root)/src/eso.tcl
 source $ds9(root)/src/examine.tcl
 source $ds9(root)/src/export.tcl
 source $ds9(root)/src/external.tcl
+source $ds9(root)/src/file.tcl
 source $ds9(root)/src/fits.tcl
 source $ds9(root)/src/first.tcl
 source $ds9(root)/src/frame.tcl
@@ -75,6 +76,7 @@ source $ds9(root)/src/hvsup.tcl
 source $ds9(root)/src/iis.tcl
 source $ds9(root)/src/imexam.tcl
 source $ds9(root)/src/imgsvr.tcl
+source $ds9(root)/src/import.tcl
 source $ds9(root)/src/info.tcl
 source $ds9(root)/src/layout.tcl
 source $ds9(root)/src/line.tcl
@@ -98,25 +100,36 @@ source $ds9(root)/src/mask.tcl
 source $ds9(root)/src/manalysis.tcl
 source $ds9(root)/src/mbin.tcl
 source $ds9(root)/src/mcolor.tcl
+source $ds9(root)/src/mecube.tcl
 source $ds9(root)/src/medit.tcl
 source $ds9(root)/src/menu.tcl
 source $ds9(root)/src/mfile.tcl
 source $ds9(root)/src/mframe.tcl
 source $ds9(root)/src/mhelp.tcl
+source $ds9(root)/src/mosaicimage.tcl
+source $ds9(root)/src/mosaicimageiraf.tcl
+source $ds9(root)/src/mosaicimagewcs.tcl
+source $ds9(root)/src/mosaicimagewfpc2.tcl
+source $ds9(root)/src/mosaic.tcl
+source $ds9(root)/src/mosaiciraf.tcl
+source $ds9(root)/src/mosaicwcs.tcl
 source $ds9(root)/src/movie.tcl
 source $ds9(root)/src/mregion.tcl
 source $ds9(root)/src/mscale.tcl
+source $ds9(root)/src/multiframe.tcl
 source $ds9(root)/src/mview.tcl
 source $ds9(root)/src/mwcs.tcl
 source $ds9(root)/src/mzoom.tcl
 source $ds9(root)/src/nameres.tcl
 source $ds9(root)/src/nsvr.tcl
+source $ds9(root)/src/nrrd.tcl
 source $ds9(root)/src/nvss.tcl
+source $ds9(root)/src/open.tcl
 source $ds9(root)/src/pagesetup.tcl
 source $ds9(root)/src/panner.tcl
 source $ds9(root)/src/panzoom.tcl
-source $ds9(root)/src/pixel.tcl
 source $ds9(root)/src/photo.tcl
+source $ds9(root)/src/pixel.tcl
 source $ds9(root)/src/plot.tcl
 source $ds9(root)/src/plotbar.tcl
 source $ds9(root)/src/plotdialog.tcl
@@ -132,22 +145,33 @@ source $ds9(root)/src/prefsdialog.tcl
 source $ds9(root)/src/print.tcl
 source $ds9(root)/src/projection.tcl
 source $ds9(root)/src/rgb.tcl
+source $ds9(root)/src/rgbarray.tcl
+source $ds9(root)/src/rgbcube.tcl
+source $ds9(root)/src/rgbimage.tcl
 source $ds9(root)/src/ruler.tcl
 source $ds9(root)/src/samp.tcl
 source $ds9(root)/src/sao.tcl
-source $ds9(root)/src/savefits.tcl
+source $ds9(root)/src/save.tcl
 source $ds9(root)/src/saveimage.tcl
 source $ds9(root)/src/scale.tcl
+source $ds9(root)/src/sfits.tcl
+source $ds9(root)/src/shm.tcl
 source $ds9(root)/src/skyview.tcl
 source $ds9(root)/src/slider.tcl
+source $ds9(root)/src/smosaic.tcl
+source $ds9(root)/src/smosaiciraf.tcl
+source $ds9(root)/src/smosaicwcs.tcl
 source $ds9(root)/src/smooth.tcl
+source $ds9(root)/src/srgbcube.tcl
 source $ds9(root)/src/starbase.tcl
 source $ds9(root)/src/stdfbox.tcl
 source $ds9(root)/src/stsci.tcl
 source $ds9(root)/src/template.tcl
 source $ds9(root)/src/text.tcl
 source $ds9(root)/src/tkfbox.tcl
+source $ds9(root)/src/url.tcl
 source $ds9(root)/src/util.tcl
+source $ds9(root)/src/var.tcl
 source $ds9(root)/src/vector.tcl
 source $ds9(root)/src/vo.tcl
 source $ds9(root)/src/wcs.tcl
