@@ -28,8 +28,11 @@ proc InitDialogBox {} {
 	}
     }
 
+    global fitsurl
+    set fitsurl {}
+
     global fitsfbox
-    set fitsfbox(file) {}
+    set fitsfbox(file) {ds9.fits}
     set fitsfbox(types) [list \
 			     [list {FITS} {*.fits}] \
 			     [list {FITS} {*.FITS}] \
@@ -63,16 +66,54 @@ proc InitDialogBox {} {
 				 [list {FITS} {*.fits.z}] \
 				]
 
-    global fitsvarfbox
-    set fitsvarfbox(file) {}
-    set fitsvarfbox(types) [list \
-				]
-
+    global epsfbox
+    set epsfbox(file) {ds9.eps}
+    set epsfbox(types) [list \
+			    [list {EPS} {*.eps}] \
+			   ]
     global arrayfbox
-    set arrayfbox(file) {}
+    set arrayfbox(file) {ds9.arr}
     set arrayfbox(types) [list \
-			      [list {ARR} {*.arr}] \
+			      [list [::msgcat::mc {Array}] {*.arr}] \
 			  ]
+    global rgbarrayfbox
+    set rgbarrayfbox(file) {ds9.rgb}
+    set rgbarrayfbox(types) [list \
+				 [list [::msgcat::mc {RGB Array}] {*.rgb}] \
+				]
+    global nrrdfbox
+    set nrrdfbox(file) {ds9.nrrd}
+    set nrrdfbox(types) [list \
+			     [list {NRRD} {*.nrrd}] \
+			    ]
+    global giffbox
+    set giffbox(file) {ds9.gif}
+    set giffbox(types) [list \
+			    [list {GIF} {*.gif}] \
+			   ]
+    global jpegfbox
+    set jpegfbox(file) {ds9.jpeg}
+    set jpegfbox(types) [list \
+			     [list {JPEG} {*.jpeg}] \
+			     [list {JPEG} {*.jpg}] \
+			    ]
+    global tifffbox
+    set tifffbox(file) {ds9.tiff}
+    set tifffbox(types) [list \
+			     [list {TIFF} {*.tiff}] \
+			     [list {TIFF} {*.tif}] \
+			    ]
+    global pngfbox
+    set pngfbox(file) {ds9.png}
+    set pngfbox(types) [list \
+			    [list {PNG} {*.png}] \
+			   ]
+    global mpegfbox
+    set mpegfbox(file) {ds9.mpeg}
+    set mpegfbox(types) [list \
+				 [list {MPEG} {*.mpeg}] \
+				 [list {MPEG} {*.mpg}] \
+				]
 
     global pixelfbox
     set pixelfbox(file) {ds9.pix}
@@ -94,7 +135,7 @@ proc InitDialogBox {} {
 	[list [list {TPL} {*.tpl}] [list [::msgcat::mc {All}] {*}] ]
 
     global colorbarfbox
-    set colorbarfbox(file) {}
+    set colorbarfbox(file) {ds9.sao}
     set colorbarfbox(types) [list \
 				 [list [::msgcat::mc {Colormap}] {*.sao}] \
 				 [list [::msgcat::mc {Colormap}]  {*.lut}] \
@@ -219,13 +260,13 @@ proc InitDialogBox {} {
 			     ]
 
     global tclfbox
-    set tclfbox(file) {}
+    set tclfbox(file) {ds9.tcl}
     set tclfbox(types) [list \
 			    [list {TCL} {*.tcl}] \
 			    ]
 
     global hvhtmlfbox
-    set hvhtmlfbox(file) {}
+    set hvhtmlfbox(file) {ds9.html}
     set  hvhtmlfbox(types) [list \
 				[list {HTML} {*.html}] \
 				[list {HTML} {*.htm}] \
@@ -243,44 +284,58 @@ proc InitDialogBox {} {
 			       [list {BCK} {*.bck}] \
 			      ]
 
-    global photofbox
-    set photofbox(file) {}
-    set photofbox(types) [list \
-			      [list {GIF} {*.gif}] \
-			      [list {JPEG} {*.jpeg}] \
-			      [list {JPEG} {*.jpg}] \
-			      [list {TIFF} {*.tiff}] \
-			      [list {TIFF} {*.tif}] \
-			      [list {PNG} {*.png}] \
-			      [list {PPM} {*.ppm}] \
-			     ]
+}
 
-    global exportfbox
-    set exportfbox(file) {ds9}
-    set exportfbox(types) [list \
-				  ]
-
-    global saveimagefbox
-    set saveimagefbox(file) {ds9}
-    set saveimagefbox(types) [list \
-				  ]
-
-    global moviefbox
-    set moviefbox(file) {ds9.mpeg}
-    set moviefbox(types) [list \
-				 [list {MPEG} {*.mpeg}] \
-				 [list {MPEG} {*.mpg}] \
-				]
+proc SetFileLast {format item} {
+    global fitsfbox
+    global epsfbox
+    global arrayfbox
+    global rgbarrayfbox
+    global nrrdfbox
+    global giffbox
+    global tifffbox
+    global jpegfbox
+    global pngfbox
+    global mpegfbox
+    switch $format {
+	fits {FileLast fitsfbox $item}
+	eps {FileLast epsfbox $item}
+	rgbarray {FileLast rgbarrayfbox $item}
+	nrrd {FileLast nrrdfbox $item}
+	gif {FileLast giffbox $item}
+	tiff {FileLast tifffbox $item}
+	jpeg {FileLast jpegfbox $item}
+	png {FileLast pngfbox $item}
+	mpeg {FileLast mpegfbox $item}
+    }
 }
 
 proc ExtToFormat {fn} {
     switch -- [file extension $fn] {
 	.fits -
+	.FITS -
 	.fit -
+	.FIT -
 	.fts -
+	.FTS -
+	.ds -
+	.DS -
+	.fits.gz -
+	.fits.bz2 -
+	.fits.Z -
+	.fits.z -
 	.fitz -
+	.FITZ -
 	.ftz -
+	.FTZ -
 	.fz -
+	.FZ {return fits}
+	.arr -
+	.array {return array}
+	.rgb {return rgbarray}
+	.nrrd {return nrrd}
+	.eps -
+	.epsf {return eps}
 	.gif -
 	.giff {return gif}
 	.jpg -
@@ -288,78 +343,11 @@ proc ExtToFormat {fn} {
 	.tif -
 	.tiff {return tiff}
 	.png {return png}
-	.ppm {return ppm}
 	.mpg -
 	.mpeg {return mpeg}
     }
 }
 
-proc FormatToFBox {format} {
-    switch $format {
-	fits {
-	    return \
-		[list \
-		     [list {FITS} {*.fits}] \
-		     [list {FITS} {*.fit}] \
-		     [list {FITS} {*.fts}] \
-		     [list {FITS} {*.fits.gz}] \
-		     [list {FITS} {*.fits.bz2}] \
-		     [list {FITS} {*.fits.Z}] \
-		     [list {FITS} {*.fits.z}] \
-		     [list {FITS} {*.fitz}] \
-		     [list {FITS} {*.ftz}] \
-		     [list {FITS} {*.fz}] \
-		     [list [::msgcat::mc {All}] {*}] \
-		    ]
-	}
-	gif {
-	    return \
-		[list \
-		     [list {GIF} {*.gif}] \
-		     [list [::msgcat::mc {All}] {*}] \
-		    ]
-	}
-	jpeg {
-	    return \
-		[list \
-		     [list {JPEG} {*.jpeg}] \
-		     [list {JPEG} {*.jpg}] \
-		     [list [::msgcat::mc {All}] {*}] \
-		    ]
-	}
-	tiff {
-	    return \
-		[list \
-		     [list {TIFF} {*.tiff}] \
-		     [list {TIFF} {*.tif}] \
-		     [list [::msgcat::mc {All}] {*}] \
-		    ]
-	}
-	png {
-	    return \
-		[list \
-		     [list {PNG} {*.png}] \
-		     [list [::msgcat::mc {All}] {*}] \
-		    ]
-	}
-	ppm	{
-	    return \
-		[list \
-		     [list {PPM} {*.ppm}] \
-		     [list [::msgcat::mc {All}] {*}] \
-		    ]
-	}
-	mpeg {
-	    return \
-		[list \
-		     [list {MPEG} {*.mpeg}] \
-		     [list {MPEG} {*.mpg}] \
-		     
-		 ]
-	}
-    }
-}
-
 # used by backup
 proc OpenFileDialog {varname} {
     return [FileDialog $varname tk_getOpenFile]
