@@ -20,12 +20,14 @@ proc CurrentDef {} {
     set current(zoom) { 1 1 }
     set current(rotate) 0
     set current(orient) none
+    set current(align) 0
 
     set pcurrent(display) $current(display)
     set pcurrent(mode) $current(mode)
     set pcurrent(zoom) $current(zoom)
     set pcurrent(rotate) $current(rotate)
     set pcurrent(orient) $current(orient)
+    set pcurrent(align) $current(align)
 }
 
 proc CursorDef {} {
@@ -102,7 +104,6 @@ proc UpdateDS9 {} {
     UpdateCubeDialog
     UpdateRGBDialog
     Update3DDialog
-    UpdateMaskDialog
     UpdateContourDialog
     UpdateGridDialog
 
@@ -192,6 +193,11 @@ proc Toplevel {w mb style title proc} {
     $w configure -menu $mb
     menu $mb
     AppleMainMenu $mb
+
+    global pds9
+    if {$pds9(dialog,center)} {
+	DialogCenter $w
+    }
 }
 
 proc GetFileURL {url fname} {
@@ -1031,7 +1037,6 @@ proc FTPLog {s msg state} {
 }
 
 proc HTTPLog {token} {
-    global http
     global debug
 
     if {$debug(tcl,http)} {
@@ -1276,6 +1281,7 @@ proc ProcessSendPrefsCmd {proc id param} {
     switch -- [string tolower [lindex $param 0]] {
 	bgcolor {$proc $id "$pds9(bg)\n"}
 	nancolor {$proc $id "$pds9(nan)\n"}
+	threads {$proc $id "$pds9(threads)\n"}
     }
 }
 
@@ -1506,8 +1512,9 @@ proc ProcessSleepCmd {varname iname} {
     upvar $varname var
     upvar $iname i
 
-    # make sure all is visible
-    update
+    # yes, we need this
+    UpdateDS9
+    RealizeDS9
 
     set sec 1
     if {[lindex $var $i] != {} && [string range [lindex $var $i] 0 0] != {-}} {
