@@ -21,7 +21,8 @@ proc VODef {} {
     # prefs only
     set pvo(server) {http://cxc.harvard.edu/chandraed/list.txt}
     set pvo(hv) 1
-    set pvo(method) xpa
+#    set pvo(method) xpa
+    set pvo(method) mime
     set pvo(delay) 15
 }
 
@@ -454,11 +455,12 @@ proc VOCheck {varname ii} {
 		if {[info exists xpa]} {
 		    if {[catch {xparemote $xpa \
 				    [lindex $ivo(server,host) $ii] + -proxy}]} {
-			$b configure -selectcolor {}
-			$b deselect
-			set ivo(b$ii) 0
-			Error [msgcat::mc {Unable to connect to VO server}]
-			return
+# if xpa unavailable, switch to mime 
+#			$b configure -selectcolor {}
+#			$b deselect
+#			set ivo(b$ii) 0
+			Info [msgcat::mc {Unable to connect directly: using Web Proxy}]
+			set pvo(method) mime
 		    }
 		}
 	    }
