@@ -15,7 +15,6 @@ proc WCSDef {} {
     set wcs(system) wcs
     set wcs(sky) fk5
     set wcs(skyformat) sexagesimal
-    set wcs(align) 0
 
     array set pwcs [array get wcs]
 }
@@ -1101,13 +1100,13 @@ proc ProcessWCSCmd {varname iname sock fn} {
 	}
 	align {
 	    incr i
-	    set wcs(align) [FromYesNo [lindex $var $i]]
+	    set current(align) [FromYesNo [lindex $var $i]]
 	    AlignWCSFrame
 	}
 	reset {
 	    set ext 1
 	    set nn [lindex $var [expr $i+1]]
-	    if {$nn != {} && [string is integer $nn]} {
+	    if {[string is integer -strict $nn]} {
 		incr i
 		set ext $nn
 	    }
@@ -1119,7 +1118,7 @@ proc ProcessWCSCmd {varname iname sock fn} {
 	append {
 	    set ext 1
 	    set nn [lindex $var [expr $i+1]]
-	    if {$nn != {} && [string is integer $nn]} {
+	    if {[string is integer -strict $nn]} {
 		incr i
 		set ext $nn
 	    }
@@ -1193,10 +1192,11 @@ proc ProcessWCSCmd {varname iname sock fn} {
 }
 
 proc ProcessSendWCSCmd {proc id param} {
+    global current
     global wcs
 
     switch -- [string tolower $param] {
-	align {$proc $id [ToYesNo $wcs(align)]}
+	align {$proc $id [ToYesNo $current(align)]}
 	system {$proc $id "$wcs(system)\n"}
 	sky  {$proc $id "$wcs(sky)\n"}
 	format -
@@ -1210,7 +1210,7 @@ proc ProcessAlignCmd {varname iname} {
     upvar $varname var
     upvar $iname i
 
-    global wcs
+    global current
     switch -- [string tolower [lindex $var $i]] {
 	yes -
 	true -
@@ -1220,11 +1220,11 @@ proc ProcessAlignCmd {varname iname} {
 	false -
 	off -
 	0 {
-	    set wcs(align) [FromYesNo [lindex $var $i]]
+	    set current(align) [FromYesNo [lindex $var $i]]
 	    AlignWCSFrame
 	}
 	default {
-	    set wcs(align) 1
+	    set current(align) 1
 	    AlignWCSFrame
 	    incr i -1
 	}
@@ -1232,8 +1232,8 @@ proc ProcessAlignCmd {varname iname} {
 }
 
 proc ProcessSendAlignCmd {proc id param} {
-    global wcs
+    global current
 
-    $proc $id [ToYesNo $wcs(align)]
+    $proc $id [ToYesNo $current(align)]
 }
 
