@@ -91,6 +91,11 @@ proc CreateXPA {} {
 	XPASendBin {} {} \
 	XPARcvdBin {} "fillbuf=false"
 
+    xpacmdadd $xpa cat \
+	{} \
+	XPASendCAT {} {} \
+	XPARcvdCAT {} "fillbuf=false"
+
     xpacmdadd $xpa catalog \
 	{} \
 	XPASendCAT {} {} \
@@ -121,6 +126,11 @@ proc CreateXPA {} {
 	XPASendContour {} {} \
 	XPARcvdContour {} "fillbuf=false"
 
+    xpacmdadd $xpa contours \
+	{} \
+	XPASendContour {} {} \
+	XPARcvdContour {} "fillbuf=false"
+
     xpacmdadd $xpa crop \
 	{} \
 	XPASendCrop {} {} \
@@ -201,6 +211,11 @@ proc CreateXPA {} {
 	XPASendFrame {} {} \
 	XPARcvdFrame {} "fillbuf=false"
 
+    xpacmdadd $xpa gif \
+	{} \
+	XPASendGIF {} {} \
+	XPARcvdGIF {} "fillbuf=false"
+
     xpacmdadd $xpa grid \
 	{} \
 	XPASendGrid {} {} \
@@ -231,10 +246,15 @@ proc CreateXPA {} {
 	XPASendImexam {} {} \
 	{} {} {}
 
-    xpacmdadd $xpa photo \
+    xpacmdadd $xpa jpg \
 	{} \
-	XPASendPhoto {} {} \
-	XPARcvdPhoto {} "fillbuf=false"
+	XPASendJPEG {} {} \
+	XPARcvdJPEG {} "fillbuf=false"
+
+    xpacmdadd $xpa jpeg \
+	{} \
+	XPASendJPEG {} {} \
+	XPARcvdJPEG {} "fillbuf=false"
 
     xpacmdadd $xpa lock \
 	{} \
@@ -261,6 +281,16 @@ proc CreateXPA {} {
 	{} {} {} \
 	XPARcvdMatch {} "fillbuf=false"
 
+    xpacmdadd $xpa mecube \
+	{} \
+	XPASendMECube {} "fillbuf=false" \
+	XPARcvdMECube {} "fillbuf=false"
+
+    xpacmdadd $xpa memf \
+	{} \
+	{} {} {} \
+	XPARcvdMultiFrame {} "fillbuf=false"
+
     xpacmdadd $xpa minmax \
 	{} \
 	XPASendMinMax {} {} \
@@ -271,6 +301,51 @@ proc CreateXPA {} {
 	XPASendMode {} {} \
 	XPARcvdMode {} "fillbuf=false"
 
+    xpacmdadd $xpa mosaic \
+	{} \
+	XPASendMosaic {} {} \
+	XPARcvdMosaic {} "fillbuf=false"
+
+    xpacmdadd $xpa mosaicimage \
+	{} \
+	XPASendMosaicImage {} {} \
+	XPARcvdMosaicImage {} "fillbuf=false"
+
+    # backward compatibility
+    xpacmdadd $xpa mosaicwcs \
+	{} \
+	XPASendMosaicWCS {} {} \
+	XPARcvdMosaicWCS {} "fillbuf=false"
+
+    # backward compatibility
+    xpacmdadd $xpa mosaiciraf \
+	{} \
+	{} {} {} \
+	XPARcvdMosaicIRAF {} "fillbuf=false"
+
+    # backward compatibility
+    xpacmdadd $xpa mosaicimagewcs \
+	{} \
+	XPASendMosaicImageWCS {} {} \
+	XPARcvdMosaicImageWCS {} "fillbuf=false"
+
+    # backward compatibility
+    xpacmdadd $xpa mosaicimageiraf \
+	{} \
+	{} {} {} \
+	XPARcvdMosaicImageIRAF {} "fillbuf=false"
+
+    # backward compatibility
+    xpacmdadd $xpa mosaicimagewfpc2 \
+	{} \
+	{} {} {} \
+	XPARcvdMosaicImageWFPC2 {} "fillbuf=false"
+
+    xpacmdadd $xpa multiframe \
+	{} \
+	{} {} {} \
+	XPARcvdMultiFrame {} "fillbuf=false"
+
     xpacmdadd $xpa movie \
 	{} \
 	{} {} {} \
@@ -286,6 +361,11 @@ proc CreateXPA {} {
 	XPASendNan {} {} \
 	XPARcvdNan {} {}
 
+    xpacmdadd $xpa nrrd \
+	{} \
+	XPASendNRRD {} {} \
+	XPARcvdNRRD {} "fillbuf=false"
+
     xpacmdadd $xpa nvss \
 	{} \
 	XPASendNVSS {} {} \
@@ -326,6 +406,11 @@ proc CreateXPA {} {
 	XPASendPlot {} {} \
 	XPARcvdPlot {} {}
 
+    xpacmdadd $xpa png \
+	{} \
+	XPASendPNG {} {} \
+	XPARcvdPNG {} "fillbuf=false"
+
     xpacmdadd $xpa prefs \
 	{} \
 	XPASendPrefs {} {} \
@@ -356,6 +441,11 @@ proc CreateXPA {} {
 	{} {} {} \
 	XPARcvdRaise {} "fillbuf=false"
 
+    xpacmdadd $xpa region \
+	{} \
+	XPASendRegions {} {} \
+	XPARcvdRegions {} "fillbuf=false"
+
     xpacmdadd $xpa regions \
 	{} \
 	XPASendRegions {} {} \
@@ -371,11 +461,31 @@ proc CreateXPA {} {
 	XPASendRGB {} {} \
 	XPARcvdRGB {} "fillbuf=false"
 
+    xpacmdadd $xpa rgbarray \
+	{} \
+	XPASendRGBArray {} {} \
+	XPARcvdRGBArray {} "fillbuf=false"
+
+    xpacmdadd $xpa rgbcube \
+	{} \
+	XPASendRGBCube {} {} \
+	XPARcvdRGBCube {} "fillbuf=false"
+
+    xpacmdadd $xpa rgbimage \
+	{} \
+	XPASendRGBImage {} {} \
+	XPARcvdRGBImage {} "fillbuf=false"
+
     xpacmdadd $xpa rotate \
 	{} \
 	XPASendRotate {} {} \
 	XPARcvdRotate {} "fillbuf=false"
 
+    xpacmdadd $xpa samp \
+	{} \
+	{} {} {} \
+	XPARcvdSAMP {} "fillbuf=false"
+
     xpacmdadd $xpa save \
 	{} \
 	{} {} {} \
@@ -403,6 +513,12 @@ proc CreateXPA {} {
 	XPASendScale {} {} \
 	XPARcvdScale {} "fillbuf=false"
 
+    # backward compatibility
+    xpacmdadd $xpa sfits \
+	{} \
+	{} {} {} \
+	XPARcvdSFits {} "fillbuf=false"
+
     xpacmdadd $xpa single \
 	{} \
 	XPASendSingle {} {} \
@@ -428,6 +544,24 @@ proc CreateXPA {} {
 	XPASendCube {} {} \
 	XPARcvdCube {} "fillbuf=false"
 
+    # backward compatibility
+    xpacmdadd $xpa smosaic \
+	{} \
+	{} {} {} \
+	XPARcvdSMosaic {} "fillbuf=false"
+
+    # backward compatibility
+    xpacmdadd $xpa smosaicwcs \
+	{} \
+	{} {} {} \
+	XPARcvdSMosaicWCS {} "fillbuf=false"
+
+    # backward compatibility
+    xpacmdadd $xpa smosaiciraf \
+	{} \
+	{} {} {} \
+	XPARcvdSMosaicIRAF {} "fillbuf=false"
+
     xpacmdadd $xpa smooth \
 	{} \
 	XPASendSmooth {} {} \
@@ -438,6 +572,12 @@ proc CreateXPA {} {
 	{} {} {} \
 	XPARcvdSource {} "fillbuf=false"
 
+    # backward compatibility
+    xpacmdadd $xpa srgbcube \
+	{} \
+	{} {} {} \
+	XPARcvdSRGBCube {} "fillbuf=false"
+
     xpacmdadd $xpa tcl \
 	{} \
 	{} {} {} \
@@ -453,6 +593,16 @@ proc CreateXPA {} {
 	XPASendThreads {} {} \
 	XPARcvdThreads {} {}
 
+    xpacmdadd $xpa tif \
+	{} \
+	XPASendTIFF {} {} \
+	XPARcvdTIFF {} "fillbuf=false"
+
+    xpacmdadd $xpa tiff \
+	{} \
+	XPASendTIFF {} {} \
+	XPARcvdTIFF {} "fillbuf=false"
+
     xpacmdadd $xpa tile \
 	{} \
 	XPASendTile {} {} \
@@ -463,6 +613,11 @@ proc CreateXPA {} {
 	{} {} {} \
 	XPARcvdUpdate {} "fillbuf=false"
 
+    xpacmdadd $xpa url \
+	{} \
+	{} {} {} \
+	XPARcvdURLFits {} {}
+
     xpacmdadd $xpa version \
 	{} \
 	XPASendVersion {} {} \
@@ -631,8 +786,7 @@ proc XPARcvdCAT {xpa cdata param buf len} {
     XPADebug "XPARcvdCat" $param
     InitError xpa
     catch {set i 0; ProcessCatalogCmd param i}
-    # ignore the invalid event error
-    InitError xpa
+    XPACatchError $xpa
 }
 
 proc XPASendCD {xpa cdata param} {
@@ -808,7 +962,15 @@ proc XPASendFile {xpa cdata param} {
 proc XPARcvdFile {xpa cdata param buf len} {
     XPADebug "XPARcvdFile" $param
     InitError xpa
-    catch {set i 0; ProcessFileCmd param i {} {}}
+    catch {
+	set i 0
+	global ds9
+	switch $ds9(wm) {
+	    x11 -
+	    aqua {ProcessFileCmd param i [xparec $xpa datafd] [xparec $xpa datachan] {}}
+	    win32 {ProcessFileCmd param i [xparec $xpa datafd] dummy {}}
+	}
+    }
     XPACatchError $xpa
 }
 
@@ -851,6 +1013,34 @@ proc XPARcvdFrame {xpa cdata param buf len} {
     XPACatchError $xpa
 }
 
+proc XPASendGIF {xpa cdata param} {
+    InitError xpa
+    catch {
+	global ds9
+	switch $ds9(wm) {
+	    x11 -
+	    aqua {ProcessSendGIFCmd {} {} $param [xparec $xpa datachan] {}}
+	    win32 {ProcessSendGIFCmd {} {} $param dummy {}}
+	}
+    }
+    XPACatchError $xpa
+}
+
+proc XPARcvdGIF {xpa cdata param buf len} {
+    XPADebug "XPARcvdGIF" $param
+    InitError xpa
+    catch {
+	set i 0
+	global ds9
+	switch $ds9(wm) {
+	    x11 -
+	    aqua {ProcessGIFCmd param i [xparec $xpa datachan] {}}
+	    win32 {ProcessGIFCmd param i dummy {}}
+	}
+    }
+    XPACatchError $xpa
+}
+
 proc XPASendGrid {xpa cdata param} {
     InitError xpa
     catch {ProcessSendGridCmd xpasetbuf $xpa $param}
@@ -916,16 +1106,31 @@ proc XPASendImexam {xpa cdata param} {
     XPACatchError $xpa
 }
 
-proc XPASendPhoto {xpa cdata param} {
+proc XPASendJPEG {xpa cdata param} {
     InitError xpa
-    catch {ProcessSendPhotoCmd {} {} $param [xparec $xpa datafd] {}}
+    catch {
+	global ds9
+	switch $ds9(wm) {
+	    x11 -
+	    aqua {ProcessSendJPEGCmd {} {} $param [xparec $xpa datachan] {}}
+	    win32 {ProcessSendJPEGCmd {} {} $param dummy {}}
+	}
+    }
     XPACatchError $xpa
 }
 
-proc XPARcvdPhoto {xpa cdata param buf len} {
-    XPADebug "XPARcvdPhoto" $param
+proc XPARcvdJPEG {xpa cdata param buf len} {
+    XPADebug "XPARcvdJPEG" $param
     InitError xpa
-    catch {set i 0; ProcessPhotoCmd param i [xparec $xpa datafd] {}}
+    catch {
+	set i 0
+	global ds9
+	switch $ds9(wm) {
+	    x11 -
+	    aqua {ProcessJPEGCmd param i [xparec $xpa datachan] {}}
+	    win32 {ProcessJPEGCmd param i dummy {}}
+	}
+    }
     XPACatchError $xpa
 }
 
@@ -982,6 +1187,19 @@ proc XPARcvdMatch {xpa cdata param buf len} {
     XPACatchError $xpa
 }
 
+proc XPASendMECube {xpa cdata param} {
+    InitError xpa
+    catch {ProcessSendMECubeCmd xpasetbuf $xpa $param [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
+proc XPARcvdMECube {xpa cdata param buf len} {
+    XPADebug "XPARcvdMECube" $param
+    InitError xpa
+    catch {set i 0; ProcessMECubeCmd param i [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
 proc XPASendMinMax {xpa cdata param} {
     InitError xpa
     catch {ProcessSendMinMaxCmd xpasetbuf $xpa $param}
@@ -1008,6 +1226,86 @@ proc XPARcvdMode {xpa cdata param buf len} {
     XPACatchError $xpa
 }
 
+proc XPASendMosaic {xpa cdata param} {
+    InitError xpa
+    catch {ProcessSendMosaicCmd {} {} $param [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
+proc XPARcvdMosaic {xpa cdata param buf len} {
+    XPADebug "XPARcvdMosaic" $param
+    InitError xpa
+    catch {set i 0; ProcessMosaicCmd param i [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
+proc XPASendMosaicImage {xpa cdata param} {
+    InitError xpa
+    catch {ProcessSendMosaicImageCmd {} {} $param [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
+proc XPARcvdMosaicImage {xpa cdata param buf len} {
+    XPADebug "XPARcvdMosaicImage" $param
+    InitError xpa
+    catch {set i 0; ProcessMosaicImageCmd param i [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
+# backward compatibility
+proc XPASendMosaicWCS {xpa cdata param} {
+    InitError xpa
+    catch {ProcessSendMosaicWCSCmd {} {} $param [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
+# backward compatibility
+proc XPARcvdMosaicWCS {xpa cdata param buf len} {
+    XPADebug "XPARcvdMosaicWCS" $param
+    InitError xpa
+    catch {set i 0; ProcessMosaicWCSCmd param i [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
+# backward compatibility
+proc XPARcvdMosaicIRAF {xpa cdata param buf len} {
+    XPADebug "XPARcvdMosaicIRAF" $param
+    InitError xpa
+    catch {set i 0; ProcessMosaicIRAFCmd param i [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
+# backward compatibility
+proc XPASendMosaicImageWCS {xpa cdata param} {
+    InitError xpa
+    catch {ProcessSendMosaicImageWCSCmd {} {} $param [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
+# backward compatibility
+proc XPARcvdMosaicImageWCS {xpa cdata param buf len} {
+    XPADebug "XPARcvdMosaicImageWCS" $param
+    InitError xpa
+    catch {set i 0; ProcessMosaicImageWCSCmd param i [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
+# backward compatibility
+proc XPARcvdMosaicImageIRAF {xpa cdata param buf len} {
+    XPADebug "XPARcvdMosaicImageIRAF" $param
+    InitError xpa
+    catch {set i 0; ProcessMosaicImageIRAFCmd param i [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
+# backward compatibility
+proc XPARcvdMosaicImageWFPC2 {xpa cdata param buf len} {
+    XPADebug "XPARcvdMosaicImageWFPC2" $param
+    InitError xpa
+    catch {set i 0; ProcessMosaicImageWFPC2Cmd param i [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
 proc XPARcvdMovie {xpa cdata param buf len} {
     XPADebug "XPARcvdMovie" $param
     InitError xpa
@@ -1015,6 +1313,21 @@ proc XPARcvdMovie {xpa cdata param buf len} {
     XPACatchError $xpa
 }
 
+proc XPARcvdMultiFrame {xpa cdata param buf len} {
+    XPADebug "XPARcvdMultiFrame" $param
+    InitError xpa
+    catch {
+	set i 0
+	global ds9
+	switch $ds9(wm) {
+	    x11 -
+	    aqua {ProcessMultiFrameCmd param i [xparec $xpa datachan] {}}
+	    win32 {ProcessMultiFrameCmd param i dummy {}}
+	}
+    }
+    XPACatchError $xpa
+}
+
 proc XPASendNan {xpa cdata param} {
     InitError xpa
     catch {ProcessSendNanCmd xpasetbuf $xpa $param}
@@ -1041,6 +1354,19 @@ proc XPARcvdNRES {xpa cdata param buf len} {
     XPACatchError $xpa
 }
 
+proc XPASendNRRD {xpa cdata param} {
+    InitError xpa
+    catch {ProcessSendNRRDCmd {} {} $param [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
+proc XPARcvdNRRD {xpa cdata param buf len} {
+    XPADebug "XPARcvdNRRD" $param
+    InitError xpa
+    catch {set i 0; ProcessNRRDCmd param i [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
 proc XPASendNVSS {xpa cdata param} {
     InitError xpa
     catch {ProcessSendNVSSCmd xpasetbuf $xpa $param}
@@ -1132,6 +1458,34 @@ proc XPARcvdPlot {xpa cdata param buf len} {
     XPACatchError $xpa
 }
 
+proc XPASendPNG {xpa cdata param} {
+    InitError xpa
+    catch {
+	global ds9
+	switch $ds9(wm) {
+	    x11 -
+	    aqua {ProcessSendPNGCmd {} {} $param [xparec $xpa datachan] {}}
+	    win32 {ProcessSendPNGCmd {} {} $param dummy {}}
+	}
+    }
+    XPACatchError $xpa
+}
+
+proc XPARcvdPNG {xpa cdata param buf len} {
+    XPADebug "XPARcvdPNG" $param
+    InitError xpa
+    catch {
+	set i 0
+	global ds9
+	switch $ds9(wm) {
+	    x11 -
+	    aqua {ProcessPNGCmd param i [xparec $xpa datachan] {}}
+	    win32 {ProcessPNGCmd param i dummy {}}
+	}
+    }
+    XPACatchError $xpa
+}
+
 proc XPASendPrefs {xpa cdata param} {
     InitError xpa
     catch {ProcessSendPrefsCmd xpasetbuf $xpa $param}
@@ -1224,6 +1578,45 @@ proc XPARcvdRGB {xpa cdata param buf len} {
     XPACatchError $xpa
 }
 
+proc XPASendRGBArray {xpa cdata param} {
+    InitError xpa
+    catch {ProcessSendRGBArrayCmd {} {} $param [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
+proc XPARcvdRGBArray {xpa cdata param buf len} {
+    XPADebug "XPARcvdRGBArray" $param
+    InitError xpa
+    catch {set i 0; ProcessRGBArrayCmd param i [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
+proc XPASendRGBCube {xpa cdata param} {
+    InitError xpa
+    catch {ProcessSendRGBCubeCmd {} {} $param [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
+proc XPARcvdRGBCube {xpa cdata param buf len} {
+    XPADebug "XPARcvdRGBCube" $param
+    InitError xpa
+    catch {set i 0; ProcessRGBCubeCmd param i [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
+proc XPASendRGBImage {xpa cdata param} {
+    InitError xpa
+    catch {ProcessSendRGBImageCmd {} {} $param [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
+proc XPARcvdRGBImage {xpa cdata param buf len} {
+    XPADebug "XPARcvdRGBImage" $param
+    InitError xpa
+    catch {set i 0; ProcessRGBImageCmd param i [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
 proc XPASendRotate {xpa cdata param} {
     InitError xpa
     catch {ProcessSendRotateCmd xpasetbuf $xpa $param}
@@ -1237,6 +1630,13 @@ proc XPARcvdRotate {xpa cdata param buf len} {
     XPACatchError $xpa
 }
 
+proc XPARcvdSAMP {xpa cdata param buf len} {
+    XPADebug "XPARcvdSamp" $param
+    InitError xpa
+    catch {set i 0; ProcessSAMPCmd param i}
+    XPACatchError $xpa
+}
+
 proc XPARcvdSave {xpa cdata param buf len} {
     XPADebug "XPARcvdSave" $param
     InitError xpa
@@ -1264,6 +1664,14 @@ proc XPARcvdScale {xpa cdata param buf len} {
     XPACatchError $xpa
 }
 
+# backward compatibility
+proc XPARcvdSFits {xpa cdata param buf len} {
+    XPADebug "XPARcvdSFits" $param
+    InitError xpa
+    catch {set i 0; ProcessSFitsCmd param i [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
 proc XPASendSingle {xpa cdata param} {
     InitError xpa
     catch {ProcessSendSingleCmd xpasetbuf $xpa $param}
@@ -1310,6 +1718,30 @@ proc XPARcvdSleep {xpa cdata param buf len} {
     XPACatchError $xpa
 }
 
+# backward compatibility
+proc XPARcvdSMosaic {xpa cdata param buf len} {
+    XPADebug "XPARcvdSMosaic" $param
+    InitError xpa
+    catch {set i 0; ProcessSMosaicCmd param i [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
+# backward compatibility
+proc XPARcvdSMosaicWCS {xpa cdata param buf len} {
+    XPADebug "XPARcvdSMosaicWCS" $param
+    InitError xpa
+    catch {set i 0; ProcessSMosaicWCSCmd param i [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
+# backward compatibility
+proc XPARcvdSMosaicIRAF {xpa cdata param buf len} {
+    XPADebug "XPARcvdSMosaicIRAF" $param
+    InitError xpa
+    catch {set i 0; ProcessSMosaicIRAFCmd param i [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
 proc XPASendSmooth {xpa cdata param} {
     InitError xpa
     catch {ProcessSendSmoothCmd xpasetbuf $xpa $param}
@@ -1330,6 +1762,14 @@ proc XPARcvdSource {xpa cdata param buf len} {
     XPACatchError $xpa
 }
 
+# backward compatibility
+proc XPARcvdSRGBCube {xpa cdata param buf len} {
+    XPADebug "XPARcvdSRGBCube" $param
+    InitError xpa
+    catch {set i 0; ProcessSRGBCubeCmd param i [xparec $xpa datafd] {}}
+    XPACatchError $xpa
+}
+
 proc XPARcvdTcl {xpa cdata param buf len} {
     XPADebug "XPARcvdTcl" $param
     InitError xpa
@@ -1363,6 +1803,34 @@ proc XPARcvdThreads {xpa cdata param buf len} {
     XPACatchError $xpa
 }
 
+proc XPASendTIFF {xpa cdata param} {
+    InitError xpa
+    catch {
+	global ds9
+	switch $ds9(wm) {
+	    x11 -
+	    aqua {ProcessSendTIFFCmd {} {} $param [xparec $xpa datachan] {}}
+	    win32 {ProcessSendTIFFCmd {} {} $param dummy {}}
+	}
+    }
+    XPACatchError $xpa
+}
+
+proc XPARcvdTIFF {xpa cdata param buf len} {
+    XPADebug "XPARcvdTIFF" $param
+    InitError xpa
+    catch {
+	set i 0
+	global ds9
+	switch $ds9(wm) {
+	    x11 -
+	    aqua {ProcessTIFFCmd param i [xparec $xpa datachan] {}}
+	    win32 {ProcessTIFFCmd param i dummy {}}
+	}
+    }
+    XPACatchError $xpa
+}
+
 proc XPASendTile {xpa cdata param} {
     InitError xpa
     catch {ProcessSendTileCmd xpasetbuf $xpa $param}
@@ -1383,6 +1851,13 @@ proc XPARcvdUpdate {xpa cdata param buf len} {
     XPACatchError $xpa
 }
 
+proc XPARcvdURLFits {xpa cdata param buf len} {
+    XPADebug "XPARcvdURLFits" $param
+    InitError xpa
+    catch {set i 0; ProcessURLFitsCmd param i}
+    XPACatchError $xpa
+}
+
 proc XPASendVersion {xpa cdata param} {
     InitError xpa
     catch {ProcessSendVersionCmd xpasetbuf $xpa $param}
