@@ -1,17 +1,14 @@
+#io.sh
+
+#xpa.sh
+#command.sh
+#samp.sh
+
+parse.sh
+crop.sh
 regions.sh
 regions3d.sh
-fits.sh
-#fits64.sh
-array.sh
-photo.sh
-rice.sh
-hcompress.sh
-gzip.sh
-plio.sh
-#shared.sh
-xpa.sh
-command.sh
-#samp.sh
+plot.sh
 scale.sh
 lock.sh
 prefs.sh
