@@ -16,7 +16,10 @@ doit() {
     fi
 }
 
-for f in *.prf
+echo
+echo "*** prefs.sh ***"
+
+for f in prefs/*.prf
 do
 echo "Testing $f"
 rm -f ~/.ds9.prf
