@@ -1,7 +1,5 @@
-#! /bin/sh
-
-echo "WCS Tests"
 echo
+echo "*** wcs.sh ***"
 
 echo "Starting DS9..."
 if [ `xpaaccess ds9` = no ]; then
@@ -28,7 +26,7 @@ xpaset -p ds9 wcs skyformat degrees
 for f in wcs/*.fits
 do
 echo $f
-xpaset -p ds9 file $f
+xpaset -p ds9 fits $f
 read
 done
 
