@@ -1,6 +1,5 @@
-#! /bin/sh
-
-echo "WCS2 Tests"
+echo
+echo "*** wcs2.sh ***"
 
 echo "Starting DS9..."
 if [ `xpaaccess ds9` = no ]; then
@@ -20,7 +19,7 @@ fi
 
 testit () {
     echo "Testing $1"
-    xpaset -p ds9 file $1
+    xpaset -p ds9 fits $1
     xpaset -p ds9 wcs sky fk5
     xpaset -p ds9 align yes
     read
@@ -34,51 +33,54 @@ xpaset -p ds9 grid yes
 xpaset -p ds9 wcs skyformat deg
 
 echo "STScI DSS"
-testit wcen.fits.gz
+testit wcs2/wcen.fits.gz
 
 echo "Old SCAMP"
-testit ngc6819.fits
+testit wcs2/ngc6819.fits
 
 echo "TAN+ PV"
-testit paucam_0_0_t7_0_science.fits
+testit wcs2/paucam_0_0_t7_0_science.fits
 
 echo "TAN PV2_1=0 PV2_2=0"
-testit a68.fits
+testit wcs2/a68.fits
 
 echo "ZPN+ PV"
-testit UKIDDS_K_3219_606_17_67_3.fits
+testit wcs2/UKIDDS_K_3219_606_17_67_3.fits
 
 echo "TNX"
-testit 30s_01.fits
+testit wcs2/30s_01.fits
 
 echo "ZPX"
-testit E5.3090.fits
+testit wcs2/E5.3090.fits
 
 echo "TAN-SIP"
-testit sst.fits
-testit mos8.fits
+testit wcs2/sst.fits
+testit wcs2/mos8.fits
 
 echo "SAO Plate"
-testit ac.fits
+testit wcs2/ac.fits
+
+#echo "TAB"
+#testit wcs2/sparse.fits
 
 echo "WCSDEP"
-testit ngc6819.fits
+testit wcs2/ngc6819.fits
 
 echo "HPX"
-testit wmap.fits
+testit wcs2/wmap.fits
 
 echo "GLON-ZEA"
-testit South_galactic.fits
+testit wcs2/South_galactic.fits
 
 echo "RA-CAR"
-testit CAR_model.fits
-testit car_01.fits
+testit wcs2/CAR_model.fits
+testit wcs2/car_01.fits
 
 echo "GLON-CAR"
-testit GLM_00350+0115_mosaic_I4_cutout_14706.fits
+testit wcs2/GLM_00350+0115_mosaic_I4_cutout_14706.fits
 
 echo "IRAF"
-testit obj011.fits
+testit wcs2/obj011.fits
 
 xpaset -p ds9 quit
 
